@@ -278,9 +278,9 @@ class Installer:
 
   def fixConf(self):
     import shutil
-    for file in ['slepc_rules', 'slepc_variables', 'slepcvariables']:
+    for file in ['slepc_rules', 'slepc_variables', 'slepcrules', 'slepcvariables']:
       self.fixConfFile(os.path.join(self.destConfDir,file))
-    self.fixConfFile(os.path.join(self.destLibDir,'pkgconfig','SLEPc.pc'))
+    self.fixConfFile(os.path.join(self.destLibDir,'pkgconfig','slepc.pc'))
     self.fixConfFile(os.path.join(self.destIncludeDir,'slepcconf.h'))
     return
 
