@@ -46,6 +46,7 @@ class Package:
     self.fortran         = False
     self.hasheaders      = False
     self.hasdloadflags   = False
+    self.builtafterslepc = False
 
   def RunCommand(self,instr):
     try:
@@ -62,14 +63,17 @@ class Package:
         result = ex.returncode
       output = output.decode(encoding='UTF-8',errors='replace').rstrip()
     try:
-      self.log.write(output)
+      self.log.write('Output:\n'+output+'\n'+'- '*35)
     except AttributeError: pass
     return (result,output)
 
-  def ProcessArgs(self,argdb):
-    self.requested = False
+  def ProcessArgs(self,argdb,petscpackages=''):
+    if hasattr(self,'petscdepend') and self.petscdepend in petscpackages:
+      self.requested = True
+    else:
+      self.requested = False
     self.havepackage = False
-    if self.installable:
+    if self.installable and not hasattr(self,'petscdepend'):
       string,found = argdb.PopPath('with-'+self.packagename+'-dir',exist=True)
       if found:
         self.requested = True
@@ -83,6 +87,7 @@ class Package:
         if found:
           self.requested = True
           self.packageincludes = string.split(',')
+    if self.installable:
       value,found = argdb.PopBool('with-'+self.packagename)
       if found:
         self.requested = value
@@ -101,30 +106,38 @@ class Package:
           self.log.Exit('--download-'+self.packagename+'-cflags must be used together with --download-'+self.packagename)
         self.buildflags = string
 
-  def Process(self,conf,vars,slepc,petsc,archdir=''):
+  def Process(self,slepcconf,slepcvars,slepcrules,slepc,petsc,archdir=''):
     self.make = petsc.make
     if petsc.buildsharedlib:
       self.slflag = petsc.slflag
     if self.requested:
       name = self.packagename.upper()
-      if self.downloadpackage:
+      if self.downloadpackage and self.builtafterslepc:
+        self.log.NewSection('Downloading '+name+'...')
+        self.Precondition(slepc,petsc)
+        self.DownloadOnly(slepcconf,slepcvars,slepcrules,slepc,petsc,archdir,slepc.prefixdir)
+      elif self.downloadpackage:
         if hasattr(self,'version'):
           self.log.NewSection('Installing '+name+' version '+self.version+'...')
         else:
           self.log.NewSection('Installing '+name+'...')
-        self.Precondition(petsc)
-        self.DownloadAndInstall(conf,vars,slepc,petsc,archdir,slepc.prefixdir)
+        self.Precondition(slepc,petsc)
+        self.DownloadAndInstall(slepcconf,slepcvars,slepc,petsc,archdir,slepc.prefixdir)
       elif self.installable:
         self.log.NewSection('Checking '+name+'...')
-        self.Precondition(petsc)
-        self.Check(conf,vars,petsc,archdir)
+        self.Precondition(slepc,petsc)
+        self.Check(slepcconf,slepcvars,petsc,archdir)
+        if not self.havepackage: self.log.setLastFailed()
       try:
-        self.LoadVersion(conf)
+        self.LoadVersion(slepcconf)
         self.log.write('Version number for '+name+' is '+self.iversion)
       except AttributeError:
         pass
+    else: # not requested
+      if hasattr(self,'SkipInstall'):
+        self.SkipInstall(slepcrules)
 
-  def Precondition(self,petsc):
+  def Precondition(self,slepc,petsc):
     package = self.packagename.upper()
     if petsc.scalar == 'complex':
       if 'complex' not in self.supportsscalar:
@@ -142,6 +155,16 @@ class Package:
     if self.downloadpackage and self.fortran and not hasattr(petsc,'fc'):
       self.log.Exit('Option --download-'+self.packagename+' requires a Fortran compiler')
 
+  def MissingTarball(self,downloaddir):
+    '''Check if tarball is missing in downloaddir'''
+    if self.downloadable and hasattr(self,'download') and self.download and hasattr(self,'archive'):
+      localFile = os.path.join(downloaddir,self.archive)
+      if not os.path.exists(localFile):
+        url = self.packageurl
+        if url=='':
+          url = self.url
+        return self.packagename+': '+url+' --> '+localFile
+
   def Download(self,externdir,downloaddir):
     # Check if source is already available
     if os.path.exists(os.path.join(externdir,self.dirname)):
@@ -253,7 +276,8 @@ Downloaded package %s from: %s is not a tarball.
       if self.hasdloadflags:
         print(('  --download-'+self.packagename+'-cflags=<flags>').ljust(wd)+': Indicate extra flags to compile '+self.packagename.upper())
     if self.installable:
-      print(('  --with-'+self.packagename+'=<bool>').ljust(wd)+': Indicate if you wish to test for '+self.packagename.upper())
+      print(('  --with-'+self.packagename+'=<bool>').ljust(wd)+': Test for '+self.packagename.upper()+(' (requires PETSc with %s)'%self.petscdepend.upper() if hasattr(self,'petscdepend') else ''))
+    if self.installable and not hasattr(self,'petscdepend'):
       print(('  --with-'+self.packagename+'-dir=<dir>').ljust(wd)+': Indicate the root directory of the '+self.packagename.upper()+' installation')
       print(('  --with-'+self.packagename+'-lib=<libraries>').ljust(wd)+': Indicate comma-separated libraries and link flags for '+self.packagename.upper())
       if self.hasheaders:
@@ -261,14 +285,17 @@ Downloaded package %s from: %s is not a tarball.
 
   def ShowInfo(self):
     if self.havepackage:
-      self.log.Println(self.packagename.upper()+' library flags:')
-      self.log.Println(' '+' '.join(self.packageflags))
-
-  def TestRuns(self,petsc):
-    if self.havepackage:
-      return [self.packagename.upper()]
-    else:
-      return []
+      if hasattr(self,'version'):
+        packagename = self.packagename.upper()+' version '+self.version
+      else:
+        packagename = self.packagename.upper()
+      if hasattr(self,'petscdepend'):
+        self.log.Println(packagename+' from %s linked by PETSc' % self.petscdepend.upper())
+      elif self.builtafterslepc:
+        self.log.Println(packagename+' to be built after SLEPc')
+      else:
+        self.log.Println(packagename+' library flags:')
+        self.log.Println(' '+' '.join(self.packageflags))
 
   def Link(self,functions,callbacks,flags,givencode='',cflags='',clanguage='c',logdump=True):
 
@@ -314,7 +341,7 @@ Downloaded package %s from: %s is not a tarball.
     else:
       code = givencode
 
-    cfile = open(os.path.join(tmpdir,'checklink.c'),'w')
+    cfile = open(os.path.join(tmpdir,'checklink.cxx' if clanguage=='c++' else 'checklink.c'),'w')
     cfile.write(code)
     cfile.close()
     if logdump:
@@ -376,10 +403,11 @@ Downloaded package %s from: %s is not a tarball.
     dirs = [''] + dirs + [os.path.join(archdir,word)]
     return dirs
 
-  def FortranLib(self,conf,vars,dirs,libs,functions,callbacks = []):
+  def FortranLib(self,slepcconf,slepcvars,dirs,libs,functions,callbacks = []):
     name = self.packagename.upper()
     error = ''
     mangling = ''
+    flags = ['']
     for d in dirs:
       for l in libs:
         if d:
@@ -400,8 +428,8 @@ Downloaded package %s from: %s is not a tarball.
       self.log.write(error)
       self.log.Exit('Unable to link with '+name+' library in directories '+' '.join(dirs)+' with libraries and link flags '+' '.join(flags))
 
-    conf.write('#define SLEPC_HAVE_' + name + ' 1\n#define SLEPC_' + name + '_HAVE_'+mangling+' 1\n')
-    vars.write(name + '_LIB = '+' '.join(flags)+'\n')
+    slepcconf.write('#define SLEPC_HAVE_' + name + ' 1\n#define SLEPC_' + name + '_HAVE_'+mangling+' 1\n')
+    slepcvars.write(name + '_LIB = '+' '.join(flags)+'\n')
     self.havepackage = True
     self.packageflags = flags
 
