@@ -22,12 +22,12 @@ class Arpack(package.Package):
     self.archive        = 'arpack-ng-'+self.version+'.tar.gz'
     self.dirname        = 'arpack-ng-'+self.version
     self.supportssingle = True
-    self.supports64bint = True
     self.fortran        = True
+    self.hasheaders     = True   # the option --with-arpack-include=... is simply ignored
     self.ProcessArgs(argdb)
 
   def Functions(self,petsc):
-    if petsc.mpiuni:
+    if petsc.mpiuni or petsc.msmpi:
       if petsc.scalar == 'real':
         if petsc.precision == 'single':
           functions = ['snaupd','sneupd','ssaupd','sseupd']
@@ -52,24 +52,24 @@ class Arpack(package.Package):
     return functions
 
 
-  def Check(self,conf,vars,petsc,archdir):
+  def Check(self,slepcconf,slepcvars,petsc,archdir):
     functions = self.Functions(petsc)
     if self.packagelibs:
       libs = [self.packagelibs]
     else:
-      if petsc.mpiuni:
+      if petsc.mpiuni or petsc.msmpi:
         libs = [['-larpack'],['-larpack_LINUX'],['-larpack_SUN4']]
       else:
         libs = [['-lparpack','-larpack'],['-lparpack_MPI','-larpack'],['-lparpack_MPI-LINUX','-larpack_LINUX'],['-lparpack_MPI-SUN4','-larpack_SUN4']]
 
     if self.packagedir:
-      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
+      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir,os.path.join(self.packagedir,'lib64')]
     else:
       dirs = self.GenerateGuesses('Arpack',archdir)
-    self.FortranLib(conf,vars,dirs,libs,functions)
+    self.FortranLib(slepcconf,slepcvars,dirs,libs,functions)
 
 
-  def DownloadAndInstall(self,conf,vars,slepc,petsc,archdir,prefixdir):
+  def DownloadAndInstall(self,slepcconf,slepcvars,slepc,petsc,archdir,prefixdir):
     externdir = slepc.CreateDir(archdir,'externalpackages')
     builddir  = self.Download(externdir,slepc.downloaddir)
 
@@ -79,8 +79,9 @@ class Arpack(package.Package):
       self.log.Exit('--download-arpack requires that the command autoreconf is available on your PATH')
 
     # Build package
-    confopt = '--prefix='+prefixdir+' CC="'+petsc.cc+'" CFLAGS="'+petsc.cc_flags+'" F77="'+petsc.fc+'" FFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+'" FC="'+petsc.fc+'" FCFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+'"'
-    if not petsc.mpiuni:
+    extra_fcflags = ' -fallow-argument-mismatch' if petsc.isGfortran100plus() else ''
+    confopt = '--prefix='+prefixdir+' CC="'+petsc.cc+'" CFLAGS="'+petsc.cc_flags+'" F77="'+petsc.fc+'" FFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+extra_fcflags+'" FC="'+petsc.fc+'" FCFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+extra_fcflags+'" LIBS="'+petsc.blaslapack_lib+'"'
+    if not petsc.mpiuni and not petsc.msmpi:
       confopt = confopt+' --enable-mpi MPICC="'+petsc.cc+'" MPIF77="'+petsc.fc+'" MPIFC="'+petsc.fc+'"'
     if not petsc.buildsharedlib:
       confopt = confopt+' --disable-shared'
@@ -94,11 +95,10 @@ class Arpack(package.Package):
 
     # Check build
     functions = self.Functions(petsc)
-    if petsc.mpiuni:
+    if petsc.mpiuni or petsc.msmpi:
       libs = [['-larpack']]
     else:
       libs = [['-lparpack','-larpack']]
-    libdir = os.path.join(prefixdir,'lib')
-    dirs = [libdir]
-    self.FortranLib(conf,vars,dirs,libs,functions)
+    dirs = [os.path.join(prefixdir,'lib'),os.path.join(prefixdir,'lib64')]
+    self.FortranLib(slepcconf,slepcvars,dirs,libs,functions)
 
