@@ -40,7 +40,7 @@ class Blopex(package.Package):
     code += '  return 0;\n}\n'
     return code
 
-  def Check(self,conf,vars,petsc,archdir):
+  def Check(self,slepcconf,slepcvars,petsc,archdir):
     code = self.SampleCode(petsc)
     if self.packagedir:
       dirs = [os.path.join(self.packagedir,'blopex_abstract','lib')]
@@ -68,9 +68,9 @@ class Blopex(package.Package):
         f = ['-I' + includes[0]]
       (result, output) = self.Link([],[],l+f,code,' '.join(f),petsc.language)
       if result:
-        conf.write('#define SLEPC_HAVE_BLOPEX 1\n')
-        vars.write('BLOPEX_LIB = ' + ' '.join(l) + '\n')
-        vars.write('BLOPEX_INCLUDE = ' + ' '.join(f) + '\n')
+        slepcconf.write('#define SLEPC_HAVE_BLOPEX 1\n')
+        slepcvars.write('BLOPEX_LIB = ' + ' '.join(l) + '\n')
+        slepcvars.write('BLOPEX_INCLUDE = ' + ' '.join(f) + '\n')
         self.havepackage = True
         self.packageflags = l+f
         self.location = includes[0] if self.packageincludes else i
@@ -78,20 +78,23 @@ class Blopex(package.Package):
 
     self.log.Exit('Unable to link with BLOPEX library in directories'+' '.join(dirs)+' with libraries and link flags '+' '.join(libs))
 
-  def DownloadAndInstall(self,conf,vars,slepc,petsc,archdir,prefixdir):
+  def DownloadAndInstall(self,slepcconf,slepcvars,slepc,petsc,archdir,prefixdir):
     externdir = slepc.CreateDir(archdir,'externalpackages')
     downloadd = self.Download(externdir,slepc.downloaddir)
     builddir  = os.path.join(downloadd,'blopex_abstract')
 
-    # Configure
-    g = open(os.path.join(builddir,'Makefile.inc'),'w')
-    g.write('CC          = '+petsc.cc+'\n')
-    g.write('CFLAGS      = '+petsc.cc_flags.replace('-Wall','').replace('-Wshadow','')+'\n')
-    g.write('AR          = '+petsc.ar+' '+petsc.ar_flags+'\n')
-    g.write('AR_LIB_SUFFIX = '+petsc.ar_lib_suffix+'\n')
-    g.write('RANLIB      = '+petsc.ranlib+'\n')
-    g.write('TARGET_ARCH = \n')
-    g.close()
+    # Makefile
+    cont  = 'CC            = '+petsc.cc+'\n'
+    cont += 'CFLAGS        = '+petsc.cc_flags.replace('-Wall','').replace('-Wshadow','')+'\n'
+    cont += 'AR            = '+petsc.ar+' '+petsc.ar_flags+'\n'
+    cont += 'AR_LIB_SUFFIX = '+petsc.ar_lib_suffix+'\n'
+    cont += 'RANLIB        = '+petsc.ranlib+'\n'
+    cont += 'TARGET_ARCH   =\n'
+    self.log.write('Using makefile definitions:\n')
+    self.log.write(cont)
+    mfile = open(os.path.join(builddir,'Makefile.inc'),'w')
+    mfile.write(cont)
+    mfile.close()
 
     # Build package
     (result,output) = self.RunCommand('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make)
@@ -119,9 +122,9 @@ class Blopex(package.Package):
       self.log.Exit('Unable to link with downloaded BLOPEX')
 
     # Write configuration files
-    conf.write('#define SLEPC_HAVE_BLOPEX 1\n')
-    vars.write('BLOPEX_LIB = ' + l + '\n')
-    vars.write('BLOPEX_INCLUDE = ' + f + '\n')
+    slepcconf.write('#define SLEPC_HAVE_BLOPEX 1\n')
+    slepcvars.write('BLOPEX_LIB = ' + l + '\n')
+    slepcvars.write('BLOPEX_INCLUDE = ' + f + '\n')
 
     self.havepackage = True
     self.packageflags = [l] + [f]
