@@ -18,8 +18,8 @@ class Elpa(package.Package):
     self.installable    = True
     self.downloadable   = True
     self.version        = '2020.05.001'
-    self.url            = 'https://elpa.mpcdf.mpg.de/html/Releases/'+self.version+'/elpa-'+self.version+'.tar.gz'
     self.archive        = 'elpa-'+self.version+'.tar.gz'
+    self.url            = 'https://elpa.mpcdf.mpg.de/html/Releases/'+self.version+'/'+self.archive
     self.dirname        = 'elpa-'+self.version
     self.supportssingle = True
     self.fortran        = True
@@ -53,7 +53,7 @@ class Elpa(package.Package):
   def Check(self,slepcconf,slepcvars,petsc,archdir):
     code = self.SampleCode(petsc)
     if self.packagedir:
-      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
+      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir,os.path.join(self.packagedir,'lib64')]
       incdirs = [os.path.join(self.packagedir,'include'),self.packagedir]
     else:
       dirs = self.GenerateGuesses('elpa',archdir)
@@ -111,13 +111,16 @@ class Elpa(package.Package):
 
     # Check build
     code = self.SampleCode(petsc)
-    if petsc.buildsharedlib:
-      l = petsc.slflag + libdir + ' -L' + libdir + ' -lelpa'
-    else:
-      l = '-L' + libdir + ' -lelpa'
-    f = '-I' + os.path.join(incdir,self.dirname)
+    altlibdir = os.path.join(prefixdir,'lib64')
+    for ldir in [libdir,altlibdir]:
+      if petsc.buildsharedlib:
+        l = petsc.slflag + ldir + ' -L' + ldir + ' -lelpa'
+      else:
+        l = '-L' + ldir + ' -lelpa'
+      f = '-I' + os.path.join(incdir,self.dirname)
+      (result, output) = self.Link([],[],[l]+[f],code,f,petsc.language)
+      if result: break
 
-    (result, output) = self.Link([],[],[l]+[f],code,f,petsc.language)
     if not result:
       self.log.Exit('Unable to link with downloaded ELPA')
 
