@@ -1,7 +1,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -12,15 +12,18 @@ import log, package
 
 class Feast(package.Package):
 
-  def __init__(self,argdb,log):
+  def __init__(self,argdb,log,petscpackages):
     package.Package.__init__(self,argdb,log)
     self.packagename    = 'feast'
     self.installable    = True
-    self.supportsscalar = ['complex']
+    self.petscdepend    = 'mkl'
     self.supportssingle = True
-    self.ProcessArgs(argdb)
+    self.supports64bint = True
+    self.ProcessArgs(argdb,petscpackages)
 
-  def Check(self,conf,vars,cmake,petsc):
+  def Check(self,slepcconf,slepcvars,petsc,archdir):
+    if not 'mkl' in petsc.packages:
+      self.log.Exit('The FEAST interface requires that PETSc has been built with Intel MKL')
     functions = ['feastinit']
     if petsc.scalar == 'real':
       if petsc.precision == 'single':
@@ -33,18 +36,12 @@ class Feast(package.Package):
       else:
         functions += ['zfeast_hrci']
 
-    if self.packagelibs:
-      libs = [self.packagelibs]
+    (result,output) = self.Link(functions,[],[])
+    if not result:
+      self.log.write('WARNING: Unable to link with FEAST, maybe your MKL version does not contain it')
+      self.log.write('If you do not want to check for FEAST, rerun configure adding --with-feast=0')
+      self.havepackage = False
     else:
-      if petsc.mpiuni:
-        libs = [['-lfeast']]
-      else:
-        libs = [['-lpfeast']]
-
-    if self.packagedir:
-      dirs = [self.packagedir]
-    else:
-      dirs = self.GenerateGuesses('Feast')
-
-    self.FortranLib(conf,vars,cmake,dirs,libs,functions)
+      slepcconf.write('#define SLEPC_HAVE_FEAST 1\n')
+      self.havepackage = True
 
