@@ -22,7 +22,7 @@ class PETSc(package.Package):
 
   def InitDir(self,prefixdir):
     if 'PETSC_DIR' in os.environ:
-      self.dir = os.environ['PETSC_DIR']
+      self.dir = os.path.normpath(os.environ['PETSC_DIR'])
       if not os.path.exists(self.dir):
         self.log.Exit('PETSC_DIR enviroment variable is not valid')
     else:
@@ -124,12 +124,17 @@ class PETSc(package.Package):
           self.sl_suffix = v
         elif k == 'RANLIB':
           self.ranlib = v
+        elif k == 'BLASLAPACK_LIB':
+          self.blaslapack_lib = v
+        elif k == 'SCALAPACK_LIB':
+          self.scalapack_lib = v
       f.close()
     except:
       self.log.Exit('Cannot process file ' + petscvariables)
 
     self.ind64 = False
     self.mpiuni = False
+    self.msmpi = False
     self.debug = False
     self.singlelib = False
     self.blaslapackmangling = ''
@@ -137,7 +142,7 @@ class PETSc(package.Package):
     self.fortran = False
     self.language = 'c'
     self.cxxdialectcxx11 = False
-    self.hpddm = False
+    self.packages = []
     try:
       f = open(petscconf_h)
       for l in f.readlines():
@@ -146,6 +151,8 @@ class PETSc(package.Package):
           self.ind64 = True
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_MPIUNI' and l[2]=='1':
           self.mpiuni = True
+        elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_MSMPI' and l[2]=='1':
+          self.msmpi = True
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_USE_DEBUG' and l[2]=='1':
           self.debug = True
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_USE_SINGLE_LIBRARY' and l[2]=='1':
@@ -162,10 +169,12 @@ class PETSc(package.Package):
           self.language = 'c++'
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_CXX_DIALECT_CXX11' and l[2]=='1':
           self.cxxdialectcxx11 = True
-        elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_HPDDM' and l[2]=='1':
-          self.hpddm = True
         elif self.isinstall and len(l)==3 and l[0]=='#define' and l[1]=='PETSC_ARCH':
           self.arch = l[2].strip('"')
+        else:
+          for p in ['hpddm','mkl','elemental','scalapack','slepc']:
+            if len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_'+p.upper() and l[2]=='1':
+              self.packages.append(p)
       f.close()
     except:
       if self.isinstall:
@@ -173,3 +182,16 @@ class PETSc(package.Package):
       else:
         self.log.Exit('Cannot process file ' + petscconf_h)
 
+  def isGfortran100plus(self):
+    '''returns true if the compiler is gfortran-10.0.x or later'''
+    try:
+      (result, output) = self.RunCommand(self.fc+' --version',)
+      import re
+      strmatch = re.match('GNU Fortran\s+\(.*\)\s+(\d+)\.(\d+)',output)
+      if strmatch:
+        VMAJOR,VMINOR = strmatch.groups()
+        if (int(VMAJOR),int(VMINOR)) >= (10,0):
+          return 1
+    except RuntimeError:
+      pass
+
