@@ -17,7 +17,7 @@ class Primme(package.Package):
     self.packagename    = 'primme'
     self.installable    = True
     self.downloadable   = True
-    self.version        = '3.1.1'
+    self.version        = '3.2'
     self.url            = 'https://github.com/primme/primme/archive/v'+self.version+'.tar.gz'
     self.archive        = 'primme-'+self.version+'.tar.gz'
     self.dirname        = 'primme-'+self.version
@@ -62,7 +62,7 @@ class Primme(package.Package):
   def Check(self,slepcconf,slepcvars,petsc,archdir):
     code = self.SampleCode(petsc)
     if self.packagedir:
-      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
+      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir,os.path.join(self.packagedir,'lib64')]
       incdirs = [os.path.join(self.packagedir,'include'),self.packagedir]
     else:
       dirs = self.GenerateGuesses('Primme',archdir)
@@ -105,7 +105,7 @@ class Primme(package.Package):
     # Makefile
     cont =  'export LIBRARY       = libprimme.'+petsc.ar_lib_suffix+'\n'
     cont += 'export SOLIBRARY     = libprimme.'+petsc.sl_suffix+'\n'
-    cont += 'export SONAMELIBRARY = libprimme.'+petsc.sl_suffix+self.version+'\n'
+    cont += 'export SONAMELIBRARY = libprimme.'+petsc.sl_suffix+'.'+self.version+'\n'
     cont += 'export CC            = '+petsc.cc+'\n'
     if hasattr(petsc,'fc'):
       cont += 'export F77           = '+petsc.fc+'\n'
