@@ -18,8 +18,8 @@ class Trlan(package.Package):
     self.installable    = True
     self.downloadable   = True
     self.version        = '201009'
-    self.url            = 'https://codeforge.lbl.gov/frs/download.php/210/trlan-'+self.version+'.tar.gz'
     self.archive        = 'trlan-'+self.version+'.tar.gz'
+    self.url            = 'https://codeforge.lbl.gov/frs/download.php/210/'+self.archive
     self.dirname        = 'trlan-'+self.version
     self.supportsscalar = ['real']
     self.fortran        = True
@@ -36,7 +36,7 @@ class Trlan(package.Package):
         libs = [['-ltrlan_mpi']]
 
     if self.packagedir:
-      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
+      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir,os.path.join(self.packagedir,'lib64')]
     else:
       dirs = self.GenerateGuesses('TRLan',archdir)
 
