@@ -1,21 +1,21 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2018, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-#if !defined(_RGIMPL)
-#define _RGIMPL
+#if !defined(SLEPCRGIMPL_H)
+#define SLEPCRGIMPL_H
 
 #include <slepcrg.h>
 #include <slepc/private/slepcimpl.h>
 
-PETSC_EXTERN PetscBool RGRegisterAllCalled;
-PETSC_EXTERN PetscErrorCode RGRegisterAll(void);
+SLEPC_EXTERN PetscBool RGRegisterAllCalled;
+SLEPC_EXTERN PetscErrorCode RGRegisterAll(void);
 
 typedef struct _RGOps *RGOps;
 
