@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -40,6 +40,13 @@ typedef enum { SVD_STATE_INITIAL,
                SVD_STATE_SOLVED,
                SVD_STATE_VECTORS } SVDStateType;
 
+/*
+   To check for unsupported features at SVDSetUp_XXX()
+*/
+typedef enum { SVD_FEATURE_CONVERGENCE=16,  /* convergence test selected by user */
+               SVD_FEATURE_STOPPING=32      /* stopping test */
+             } SVDFeatureType;
+
 /*
    Defines the SVD data structure.
 */
@@ -104,11 +111,32 @@ struct _p_SVD {
 
 #define SVDCheckSolved(h,arg) \
   do { \
-    if (h->state<SVD_STATE_SOLVED) SETERRQ1(PetscObjectComm((PetscObject)h),PETSC_ERR_ARG_WRONGSTATE,"Must call SVDSolve() first: Parameter #%d",arg); \
+    if ((h)->state<SVD_STATE_SOLVED) SETERRQ1(PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"Must call SVDSolve() first: Parameter #%d",arg); \
   } while (0)
 
 #endif
 
+/* Check for unsupported features */
+#define SVDCheckUnsupportedCondition(svd,mask,condition,msg) \
+  do { \
+    if (condition) { \
+      if (((mask) & SVD_FEATURE_CONVERGENCE) && (svd)->converged!=SVDConvergedRelative) SETERRQ2(PetscObjectComm((PetscObject)(svd)),PETSC_ERR_SUP,"The solver '%s'%s only supports the default convergence test",((PetscObject)(svd))->type_name,(msg)); \
+      if (((mask) & SVD_FEATURE_STOPPING) && (svd)->stopping!=SVDStoppingBasic) SETERRQ2(PetscObjectComm((PetscObject)(svd)),PETSC_ERR_SUP,"The solver '%s'%s only supports the default stopping test",((PetscObject)(svd))->type_name,(msg)); \
+    } \
+  } while (0)
+#define SVDCheckUnsupported(svd,mask) SVDCheckUnsupportedCondition(svd,mask,PETSC_TRUE,"")
+
+/* Check for ignored features */
+#define SVDCheckIgnoredCondition(svd,mask,condition,msg) \
+  do { \
+    PetscErrorCode __ierr; \
+    if (condition) { \
+      if (((mask) & SVD_FEATURE_CONVERGENCE) && (svd)->converged!=SVDConvergedRelative) { __ierr = PetscInfo2((svd),"The solver '%s'%s ignores the convergence test settings\n",((PetscObject)(svd))->type_name,(msg)); } \
+      if (((mask) & SVD_FEATURE_STOPPING) && (svd)->stopping!=SVDStoppingBasic) { __ierr = PetscInfo2((svd),"The solver '%s'%s ignores the stopping test settings\n",((PetscObject)(svd))->type_name,(msg)); } \
+    } \
+  } while (0)
+#define SVDCheckIgnored(svd,mask) SVDCheckIgnoredCondition(svd,mask,PETSC_TRUE,"")
+
 PETSC_STATIC_INLINE PetscErrorCode SVDMatMult(SVD svd,PetscBool trans,Vec x,Vec y)
 {
   PetscErrorCode ierr;
