@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -91,7 +91,7 @@ SLEPC_EXTERN const char *BVOrthogBlockTypes[];
    Notes:
    Allowed values are
 +  BV_MATMULT_VECS - perform a matrix-vector multiply per each column
-.  BV_MATMULT_MAT - carry out a MatMatMult() product with a dense matrix
+.  BV_MATMULT_MAT - carry out a Mat-Mat product with a dense matrix
 -  BV_MATMULT_MAT_SAVE - this case is deprecated
 
    The default is BV_MATMULT_MAT except in the case of BVVECS.
@@ -115,7 +115,7 @@ SLEPC_EXTERN PetscErrorCode BVGetSizes(BV,PetscInt*,PetscInt*,PetscInt*);
 SLEPC_EXTERN PetscErrorCode BVResize(BV,PetscInt,PetscBool);
 SLEPC_EXTERN PetscErrorCode BVSetFromOptions(BV);
 SLEPC_EXTERN PetscErrorCode BVView(BV,PetscViewer);
-PETSC_STATIC_INLINE PetscErrorCode BVViewFromOptions(BV bv,PetscObject obj,const char name[]) {return PetscObjectViewFromOptions((PetscObject)bv,obj,name);}
+SLEPC_EXTERN PetscErrorCode BVViewFromOptions(BV,PetscObject,const char[]);
 
 SLEPC_EXTERN PetscErrorCode BVGetColumn(BV,PetscInt,Vec*);
 SLEPC_EXTERN PetscErrorCode BVRestoreColumn(BV,PetscInt,Vec*);
@@ -154,9 +154,15 @@ SLEPC_EXTERN PetscErrorCode BVMultColumn(BV,PetscScalar,PetscScalar,PetscInt,Pet
 SLEPC_EXTERN PetscErrorCode BVMultInPlace(BV,Mat,PetscInt,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVMultInPlaceTranspose(BV,Mat,PetscInt,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVMatMult(BV,Mat,BV);
+SLEPC_EXTERN PetscErrorCode BVMatMultTranspose(BV,Mat,BV);
 SLEPC_EXTERN PetscErrorCode BVMatMultHermitianTranspose(BV,Mat,BV);
 SLEPC_EXTERN PetscErrorCode BVMatMultColumn(BV,Mat,PetscInt);
+SLEPC_EXTERN PetscErrorCode BVMatMultTransposeColumn(BV,Mat,PetscInt);
+SLEPC_EXTERN PetscErrorCode BVMatMultHermitianTransposeColumn(BV,Mat,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVMatProject(BV,Mat,BV,Mat);
+SLEPC_EXTERN PetscErrorCode BVMatArnoldi(BV,Mat,PetscScalar*,PetscInt,PetscInt,PetscInt*,PetscReal*,PetscBool*);
+SLEPC_EXTERN PetscErrorCode BVMatLanczos(BV,Mat,PetscReal*,PetscReal*,PetscInt,PetscInt*,PetscBool*);
+
 SLEPC_EXTERN PetscErrorCode BVDot(BV,BV,Mat);
 SLEPC_EXTERN PetscErrorCode BVDotVec(BV,Vec,PetscScalar*);
 SLEPC_EXTERN PetscErrorCode BVDotVecBegin(BV,Vec,PetscScalar*);
@@ -173,6 +179,7 @@ SLEPC_EXTERN PetscErrorCode BVNormVecEnd(BV,Vec,NormType,PetscReal*);
 SLEPC_EXTERN PetscErrorCode BVNormColumn(BV,PetscInt,NormType,PetscReal*);
 SLEPC_EXTERN PetscErrorCode BVNormColumnBegin(BV,PetscInt,NormType,PetscReal*);
 SLEPC_EXTERN PetscErrorCode BVNormColumnEnd(BV,PetscInt,NormType,PetscReal*);
+SLEPC_EXTERN PetscErrorCode BVNormalize(BV,PetscScalar*);
 SLEPC_EXTERN PetscErrorCode BVSetRandom(BV);
 SLEPC_EXTERN PetscErrorCode BVSetRandomColumn(BV,PetscInt);
 SLEPC_EXTERN PetscErrorCode BVSetRandomCond(BV,PetscReal);
