@@ -57,6 +57,10 @@ typedef const char* EPSType;
 #define EPSTRLAN       "trlan"
 #define EPSBLOPEX      "blopex"
 #define EPSPRIMME      "primme"
+#define EPSFEAST       "feast"
+#define EPSSCALAPACK   "scalapack"
+#define EPSELPA        "elpa"
+#define EPSELEMENTAL   "elemental"
 
 /* Logging support */
 SLEPC_EXTERN PetscClassId EPS_CLASSID;
@@ -196,8 +200,10 @@ SLEPC_EXTERN PetscErrorCode EPSViewFromOptions(EPS,PetscObject,const char[]);
 SLEPC_EXTERN PetscErrorCode EPSErrorView(EPS,EPSErrorType,PetscViewer);
 PETSC_DEPRECATED_FUNCTION("Use EPSErrorView()") PETSC_STATIC_INLINE PetscErrorCode EPSPrintSolution(EPS eps,PetscViewer v) {return EPSErrorView(eps,EPS_ERROR_RELATIVE,v);}
 SLEPC_EXTERN PetscErrorCode EPSErrorViewFromOptions(EPS);
-SLEPC_EXTERN PetscErrorCode EPSReasonView(EPS,PetscViewer);
-SLEPC_EXTERN PetscErrorCode EPSReasonViewFromOptions(EPS);
+SLEPC_EXTERN PetscErrorCode EPSConvergedReasonView(EPS,PetscViewer);
+SLEPC_EXTERN PetscErrorCode EPSConvergedReasonViewFromOptions(EPS);
+PETSC_DEPRECATED_FUNCTION("Use EPSConvergedReasonView() (since version 3.14)") PETSC_STATIC_INLINE PetscErrorCode EPSReasonView(EPS eps,PetscViewer v) {return EPSConvergedReasonView(eps,v);}
+PETSC_DEPRECATED_FUNCTION("Use EPSConvergedReasonViewFromOptions() (since version 3.14)") PETSC_STATIC_INLINE PetscErrorCode EPSReasonViewFromOptions(EPS eps) {return EPSConvergedReasonViewFromOptions(eps);}
 SLEPC_EXTERN PetscErrorCode EPSValuesView(EPS,PetscViewer);
 SLEPC_EXTERN PetscErrorCode EPSValuesViewFromOptions(EPS);
 SLEPC_EXTERN PetscErrorCode EPSVectorsView(EPS,PetscViewer);
@@ -469,5 +475,8 @@ SLEPC_EXTERN PetscErrorCode EPSLyapIIGetRanks(EPS,PetscInt*,PetscInt*);
 SLEPC_EXTERN PetscErrorCode EPSBLOPEXSetBlockSize(EPS,PetscInt);
 SLEPC_EXTERN PetscErrorCode EPSBLOPEXGetBlockSize(EPS,PetscInt*);
 
+SLEPC_EXTERN PetscErrorCode EPSFEASTSetNumPoints(EPS,PetscInt);
+SLEPC_EXTERN PetscErrorCode EPSFEASTGetNumPoints(EPS,PetscInt*);
+
 #endif
 
