@@ -33,6 +33,8 @@
 #include <slepc/private/epsimpl.h>                /*I "slepceps.h" I*/
 #include <slepcblaslapack.h>
 
+PetscLogEvent EPS_CISS_SVD;
+
 typedef struct {
   /* parameters */
   PetscInt          N;          /* number of integration points (32) */
@@ -356,17 +358,23 @@ static PetscErrorCode SolveLinearSystem(EPS eps,Mat A,Mat B,BV V,PetscInt L_star
 {
   PetscErrorCode ierr;
   EPS_CISS       *ctx = (EPS_CISS*)eps->data;
-  PetscInt       i,j,p_id;
-  Mat            Fz,kspMat;
-  Vec            Bvj,vj,yj;
+  PetscInt       i,p_id;
+  Mat            Fz,kspMat,MV,BMV=NULL,MC;
   KSP            ksp;
 
   PetscFunctionBegin;
   if (!ctx->ksp) { ierr = EPSCISSGetKSPs(eps,&ctx->num_solve_point,&ctx->ksp);CHKERRQ(ierr); }
-  ierr = BVCreateVec(V,&Bvj);CHKERRQ(ierr);
   if (ctx->usest) {
     ierr = MatDuplicate(A,MAT_DO_NOT_COPY_VALUES,&Fz);CHKERRQ(ierr);
   }
+  ierr = BVSetActiveColumns(V,L_start,L_end);CHKERRQ(ierr);
+  ierr = BVGetMat(V,&MV);CHKERRQ(ierr);
+  if (B) {
+    ierr = MatProductCreate(B,MV,NULL,&BMV);CHKERRQ(ierr);
+    ierr = MatProductSetType(BMV,MATPRODUCT_AB);CHKERRQ(ierr);
+    ierr = MatProductSetFromOptions(BMV);CHKERRQ(ierr);
+    ierr = MatProductSymbolic(BMV);CHKERRQ(ierr);
+  }
   for (i=0;i<ctx->num_solve_point;i++) {
     p_id = i*ctx->subcomm->n + ctx->subcomm_id;
     if (!ctx->usest && initksp) {
@@ -382,30 +390,28 @@ static PetscErrorCode SolveLinearSystem(EPS eps,Mat A,Mat B,BV V,PetscInt L_star
       ierr = STSetShift(eps->st,ctx->omega[p_id]);CHKERRQ(ierr);
       ierr = STGetKSP(eps->st,&ksp);CHKERRQ(ierr);
     }
-    for (j=L_start;j<L_end;j++) {
-      ierr = BVGetColumn(V,j,&vj);CHKERRQ(ierr);
-      ierr = BVGetColumn(ctx->Y,i*ctx->L_max+j,&yj);CHKERRQ(ierr);
-      if (B) {
-        ierr = MatMult(B,vj,Bvj);CHKERRQ(ierr);
-        if (ctx->usest) {
-          ierr = KSPSolve(ksp,Bvj,yj);CHKERRQ(ierr);
-        } else {
-          ierr = KSPSolve(ctx->ksp[i],Bvj,yj);CHKERRQ(ierr);
-        }
+    ierr = BVSetActiveColumns(ctx->Y,i*ctx->L_max+L_start,i*ctx->L_max+L_end);CHKERRQ(ierr);
+    ierr = BVGetMat(ctx->Y,&MC);CHKERRQ(ierr);
+    if (B) {
+      ierr = MatProductNumeric(BMV);CHKERRQ(ierr);
+      if (ctx->usest) {
+        ierr = KSPMatSolve(ksp,BMV,MC);CHKERRQ(ierr);
       } else {
-        if (ctx->usest) {
-          ierr = KSPSolve(ksp,vj,yj);CHKERRQ(ierr);
-        } else {
-          ierr = KSPSolve(ctx->ksp[i],vj,yj);CHKERRQ(ierr);
-        }
+        ierr = KSPMatSolve(ctx->ksp[i],BMV,MC);CHKERRQ(ierr);
+      }
+    } else {
+      if (ctx->usest) {
+        ierr = KSPMatSolve(ksp,MV,MC);CHKERRQ(ierr);
+      } else {
+        ierr = KSPMatSolve(ctx->ksp[i],MV,MC);CHKERRQ(ierr);
       }
-      ierr = BVRestoreColumn(V,j,&vj);CHKERRQ(ierr);
-      ierr = BVRestoreColumn(ctx->Y,i*ctx->L_max+j,&yj);CHKERRQ(ierr);
     }
     if (ctx->usest && i<ctx->num_solve_point-1) { ierr = KSPReset(ksp);CHKERRQ(ierr); }
+    ierr = BVRestoreMat(ctx->Y,&MC);CHKERRQ(ierr);
   }
+  ierr = MatDestroy(&BMV);CHKERRQ(ierr);
+  ierr = BVRestoreMat(V,&MV);CHKERRQ(ierr);
   if (ctx->usest) { ierr = MatDestroy(&Fz);CHKERRQ(ierr); }
-  ierr = VecDestroy(&Bvj);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -504,7 +510,7 @@ static PetscErrorCode CalcMu(EPS eps,PetscScalar *Mu)
   }
   for (i=0;i<2*ctx->M*ctx->L*ctx->L;i++) temp2[i] /= sub_size;
   ierr = PetscMPIIntCast(2*ctx->M*ctx->L*ctx->L,&len);CHKERRQ(ierr);
-  ierr = MPI_Allreduce(temp2,Mu,len,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)eps));CHKERRQ(ierr);
+  ierr = MPIU_Allreduce(temp2,Mu,len,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)eps));CHKERRQ(ierr);
   ierr = PetscFree3(temp,temp2,ppk);CHKERRQ(ierr);
   ierr = MatDestroy(&M);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -535,6 +541,7 @@ static PetscErrorCode SVD_H0(EPS eps,PetscScalar *S,PetscInt *K)
 #endif
 
   PetscFunctionBegin;
+  ierr = PetscLogEventBegin(EPS_CISS_SVD,eps,0,0,0);CHKERRQ(ierr);
   ierr = PetscMalloc1(5*ml,&work);CHKERRQ(ierr);
 #if defined(PETSC_USE_COMPLEX)
   ierr = PetscMalloc1(5*ml,&rwork);CHKERRQ(ierr);
@@ -557,6 +564,7 @@ static PetscErrorCode SVD_H0(EPS eps,PetscScalar *S,PetscInt *K)
 #if defined(PETSC_USE_COMPLEX)
   ierr = PetscFree(rwork);CHKERRQ(ierr);
 #endif
+  ierr = PetscLogEventEnd(EPS_CISS_SVD,eps,0,0,0);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -642,7 +650,7 @@ static PetscErrorCode SVD_S(BV S,PetscInt ml,PetscReal delta,PetscReal *sigma,Pe
     }
     ierr = PetscArrayzero(temp2,ml*ml);CHKERRQ(ierr);
     ierr = PetscMPIIntCast(ml*ml,&len);CHKERRQ(ierr);
-    ierr = MPI_Allreduce(temp,temp2,len,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)S));CHKERRQ(ierr);
+    ierr = MPIU_Allreduce(temp,temp2,len,MPIU_SCALAR,MPIU_SUM,PetscObjectComm((PetscObject)S));CHKERRQ(ierr);
 
     ierr = PetscBLASIntCast(ml,&m);CHKERRQ(ierr);
     n = m; lda = m; lwork = 5*m, ldu = 1; ldvt = 1;
@@ -818,7 +826,7 @@ PetscErrorCode EPSSetUp_CISS(EPS eps)
 {
   PetscErrorCode ierr;
   EPS_CISS       *ctx = (EPS_CISS*)eps->data;
-  PetscBool      issinvert,istrivial,isring,isellipse,isinterval,flg,useconj;
+  PetscBool      istrivial,isring,isellipse,isinterval,flg,useconj;
   PetscReal      c,d;
   Mat            A;
 
@@ -842,10 +850,8 @@ PetscErrorCode EPSSetUp_CISS(EPS eps)
   if (eps->max_it==PETSC_DEFAULT) eps->max_it = 1;
   if (eps->mpd==PETSC_DEFAULT) eps->mpd = eps->ncv;
   if (!eps->which) eps->which = EPS_ALL;
-  if (!eps->extraction) { ierr = EPSSetExtraction(eps,EPS_RITZ);CHKERRQ(ierr); }
-  else if (eps->extraction!=EPS_RITZ) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Unsupported extraction type");
-  if (eps->arbitrary) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Arbitrary selection of eigenpairs not supported in this solver");
-  if (eps->stopping!=EPSStoppingBasic) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support user-defined stopping test");
+  if (eps->which!=EPS_ALL) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver supports only computing all eigenvalues");
+  EPSCheckUnsupported(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_ARBITRARY | EPS_FEATURE_EXTRACTION | EPS_FEATURE_STOPPING | EPS_FEATURE_TWOSIDED);
 
   /* check region */
   ierr = RGIsTrivial(eps->rg,&istrivial);CHKERRQ(ierr);
@@ -861,9 +867,7 @@ PetscErrorCode EPSSetUp_CISS(EPS eps)
   if (useconj!=ctx->useconj) { ierr = EPSCISSResetSubcomm(eps);CHKERRQ(ierr); }
 
 #if !defined(PETSC_USE_COMPLEX)
-  if (isring) {
-    SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Ring region only supported for complex scalars");
-  }
+  if (isring) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Ring region only supported for complex scalars");
 #endif
   if (isinterval) {
     ierr = RGIntervalGetEndpoints(eps->rg,NULL,NULL,&c,&d);CHKERRQ(ierr);
@@ -908,10 +912,7 @@ PetscErrorCode EPSSetUp_CISS(EPS eps)
     ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)ctx->pV);CHKERRQ(ierr);
   }
 
-  if (ctx->usest) {
-    ierr = PetscObjectTypeCompare((PetscObject)eps->st,STSINVERT,&issinvert);CHKERRQ(ierr);
-    if (!issinvert) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"If the usest flag is set, you must select the STSINVERT spectral transformation");
-  }
+  EPSCheckSinvertCondition(eps,ctx->usest," (with the usest flag set)");
 
   ierr = BVDestroy(&ctx->Y);CHKERRQ(ierr);
   if (ctx->pA) {
@@ -948,6 +949,27 @@ PetscErrorCode EPSSetUp_CISS(EPS eps)
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode EPSSetUpSort_CISS(EPS eps)
+{
+  PetscErrorCode ierr;
+  SlepcSC        sc;
+
+  PetscFunctionBegin;
+  /* fill sorting criterion context */
+  eps->sc->comparison    = SlepcCompareSmallestReal;
+  eps->sc->comparisonctx = NULL;
+  eps->sc->map           = NULL;
+  eps->sc->mapobj        = NULL;
+
+  /* fill sorting criterion for DS */
+  ierr = DSGetSlepcSC(eps->ds,&sc);CHKERRQ(ierr);
+  sc->comparison    = SlepcCompareLargestMagnitude;
+  sc->comparisonctx = NULL;
+  sc->map           = NULL;
+  sc->mapobj        = NULL;
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode EPSSolve_CISS(EPS eps)
 {
   PetscErrorCode ierr;
@@ -958,7 +980,6 @@ PetscErrorCode EPSSolve_CISS(EPS eps)
   PetscReal      error,max_error,norm;
   PetscBool      *fl1;
   Vec            si,w[3];
-  SlepcSC        sc;
   PetscRandom    rand;
 #if defined(PETSC_USE_COMPLEX)
   PetscBool      isellipse;
@@ -968,12 +989,6 @@ PetscErrorCode EPSSolve_CISS(EPS eps)
   w[0] = eps->work[0];
   w[1] = NULL;
   w[2] = eps->work[1];
-  /* override SC settings */
-  ierr = DSGetSlepcSC(eps->ds,&sc);CHKERRQ(ierr);
-  sc->comparison    = SlepcCompareLargestMagnitude;
-  sc->comparisonctx = NULL;
-  sc->map           = NULL;
-  sc->mapobj        = NULL;
   ierr = VecGetLocalSize(w[0],&nlocal);CHKERRQ(ierr);
   ierr = DSGetLeadingDimension(eps->ds,&ld);CHKERRQ(ierr);
   ierr = STGetNumMatrices(eps->st,&nmat);CHKERRQ(ierr);
@@ -1045,7 +1060,9 @@ PetscErrorCode EPSSolve_CISS(EPS eps)
         ierr = ConstructS(eps);CHKERRQ(ierr);
         ierr = BVSetActiveColumns(ctx->S,0,ctx->L);CHKERRQ(ierr);
         ierr = BVCopy(ctx->S,ctx->V);CHKERRQ(ierr);
+        ierr = PetscLogEventBegin(EPS_CISS_SVD,eps,0,0,0);CHKERRQ(ierr);
         ierr = SVD_S(ctx->S,ctx->L*ctx->M,ctx->delta,ctx->sigma,&nv);CHKERRQ(ierr);
+        ierr = PetscLogEventEnd(EPS_CISS_SVD,eps,0,0,0);CHKERRQ(ierr);
         if (ctx->sigma[0]>ctx->delta && nv==ctx->L*ctx->M && inner!=ctx->refine_inner) {
           if (ctx->pA) {
             ierr = VecScatterVecs(eps,ctx->V,ctx->L);CHKERRQ(ierr);
@@ -1176,21 +1193,37 @@ PetscErrorCode EPSComputeVectors_CISS(EPS eps)
 {
   PetscErrorCode ierr;
   EPS_CISS       *ctx = (EPS_CISS*)eps->data;
-  PetscReal      norm;
-  PetscInt       i;
-  Mat            B=NULL;
+  PetscInt       n;
+  Mat            Z,B=NULL;
 
   PetscFunctionBegin;
-  ierr = EPSComputeVectors_Schur(eps);CHKERRQ(ierr);
-  if (ctx->extraction == EPS_CISS_EXTRACTION_HANKEL) { /* normalize */
+  if (eps->ishermitian) {
+    if (eps->isgeneralized && !eps->ispositive) {
+      ierr = EPSComputeVectors_Indefinite(eps);CHKERRQ(ierr);
+    } else {
+      ierr = EPSComputeVectors_Hermitian(eps);CHKERRQ(ierr);
+    }
+    PetscFunctionReturn(0);
+  }
+  ierr = DSGetDimensions(eps->ds,&n,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+  ierr = BVSetActiveColumns(eps->V,0,n);CHKERRQ(ierr);
+
+  /* right eigenvectors */
+  ierr = DSVectors(eps->ds,DS_MAT_X,NULL,NULL);CHKERRQ(ierr);
+
+  /* V = V * Z */
+  ierr = DSGetMat(eps->ds,DS_MAT_X,&Z);CHKERRQ(ierr);
+  ierr = BVMultInPlace(eps->V,Z,0,n);CHKERRQ(ierr);
+  ierr = MatDestroy(&Z);CHKERRQ(ierr);
+  ierr = BVSetActiveColumns(eps->V,0,eps->nconv);CHKERRQ(ierr);
+
+  /* normalize */
+  if (ctx->extraction == EPS_CISS_EXTRACTION_HANKEL) {
     if (eps->isgeneralized && eps->ishermitian && eps->ispositive) {
       ierr = STGetMatrix(eps->st,1,&B);CHKERRQ(ierr);
       ierr = BVSetMatrix(eps->V,B,PETSC_FALSE);CHKERRQ(ierr);
     }
-    for (i=0;i<eps->nconv;i++) {
-      ierr = BVNormColumn(eps->V,i,NORM_2,&norm);CHKERRQ(ierr);
-      ierr = BVScaleColumn(eps->V,i,1.0/norm);CHKERRQ(ierr);
-    }
+    ierr = BVNormalize(eps->V,NULL);CHKERRQ(ierr);
     if (B) { ierr = BVSetMatrix(eps->V,NULL,PETSC_FALSE);CHKERRQ(ierr); }
   }
   PetscFunctionReturn(0);
@@ -1724,7 +1757,7 @@ static PetscErrorCode EPSCISSGetExtraction_CISS(EPS eps,EPSCISSExtraction *extra
 .  eps - the eigenproblem solver context
 
    Output Parameters:
-+  extraction - extraction technique
+.  extraction - extraction technique
 
    Level: advanced
 
@@ -1973,6 +2006,7 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_CISS(EPS eps)
 
   eps->ops->solve          = EPSSolve_CISS;
   eps->ops->setup          = EPSSetUp_CISS;
+  eps->ops->setupsort      = EPSSetUpSort_CISS;
   eps->ops->setfromoptions = EPSSetFromOptions_CISS;
   eps->ops->destroy        = EPSDestroy_CISS;
   eps->ops->reset          = EPSReset_CISS;
@@ -1993,6 +2027,10 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_CISS(EPS eps)
   ierr = PetscObjectComposeFunction((PetscObject)eps,"EPSCISSSetExtraction_C",EPSCISSSetExtraction_CISS);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)eps,"EPSCISSGetExtraction_C",EPSCISSGetExtraction_CISS);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)eps,"EPSCISSGetKSPs_C",EPSCISSGetKSPs_CISS);CHKERRQ(ierr);
+
+  /* log events */
+  ierr = PetscLogEventRegister("EPSCISS_SVD",EPS_CLASSID,&EPS_CISS_SVD);CHKERRQ(ierr);
+
   /* set default values of parameters */
   ctx->N                  = 32;
   ctx->L                  = 16;
