@@ -55,22 +55,30 @@ PetscErrorCode EPSSetUp_BLZPACK(EPS eps)
   PetscErrorCode ierr;
   PetscInt       listor,lrstor,ncuv,k1,k2,k3,k4;
   EPS_BLZPACK    *blz = (EPS_BLZPACK*)eps->data;
-  PetscBool      issinv,istrivial,flg;
+  PetscBool      issinv;
 
   PetscFunctionBegin;
+  EPSCheckHermitianDefinite(eps);
   if (eps->ncv!=PETSC_DEFAULT) {
     if (eps->ncv < PetscMin(eps->nev+10,eps->nev*2)) SETERRQ(PetscObjectComm((PetscObject)eps),0,"Warning: BLZpack recommends that ncv be larger than min(nev+10,nev*2)");
   } else eps->ncv = PetscMin(eps->nev+10,eps->nev*2);
   if (eps->mpd!=PETSC_DEFAULT) { ierr = PetscInfo(eps,"Warning: parameter mpd ignored\n");CHKERRQ(ierr); }
   if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(1000,eps->n);
 
+  ierr = PetscObjectTypeCompare((PetscObject)eps->st,STSINVERT,&issinv);CHKERRQ(ierr);
+  if (!eps->which) {
+    if (issinv) eps->which = EPS_TARGET_REAL;
+    else eps->which = EPS_SMALLEST_REAL;
+  }
+  if ((issinv && eps->which!=EPS_TARGET_REAL && eps->which!=EPS_TARGET_MAGNITUDE && eps->which!=EPS_ALL) || (!issinv && eps->which!=EPS_SMALLEST_REAL)) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Wrong value of eps->which");
+  EPSCheckUnsupported(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_CONVERGENCE | EPS_FEATURE_STOPPING);
+  EPSCheckIgnored(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_EXTRACTION);
+
   if (!blz->block_size) blz->block_size = 3;
-  if (!eps->ishermitian) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Requested method is only available for Hermitian problems");
   if (eps->which==EPS_ALL) {
-    if (eps->inta==0.0 && eps->intb==0.0) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Must define a computational interval when using EPS_ALL");
+    if (eps->inta==eps->intb) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Must define a computational interval when using EPS_ALL");
     blz->slice = 1;
   }
-  ierr = PetscObjectTypeCompare((PetscObject)eps->st,STSINVERT,&issinv);CHKERRQ(ierr);
   if (blz->slice || eps->isgeneralized) {
     if (!issinv) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Shift-and-invert ST is needed for generalized problems or spectrum slicing");
   }
@@ -82,12 +90,6 @@ PetscErrorCode EPSSetUp_BLZPACK(EPS eps)
       ierr = STSetDefaultShift(eps->st,eps->intb);CHKERRQ(ierr);
     }
   }
-  if (!eps->which) {
-    if (issinv) eps->which = EPS_TARGET_REAL;
-    else eps->which = EPS_SMALLEST_REAL;
-  }
-  if ((issinv && eps->which!=EPS_TARGET_REAL && eps->which!=EPS_TARGET_MAGNITUDE && eps->which!=EPS_ALL) || (!issinv && eps->which!=EPS_SMALLEST_REAL)) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Wrong value of eps->which");
-  if (eps->arbitrary) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Arbitrary selection of eigenpairs not supported in this solver");
 
   k1 = PetscMin(eps->n,180);
   k2 = blz->block_size;
@@ -120,15 +122,8 @@ lrstor*=10;
   ierr = PetscMalloc1(2*eps->ncv,&blz->eig);CHKERRQ(ierr);
   ierr = PetscLogObjectMemory((PetscObject)eps,2*eps->ncv*sizeof(PetscReal));CHKERRQ(ierr);
 
-  if (eps->extraction) { ierr = PetscInfo(eps,"Warning: extraction type ignored\n");CHKERRQ(ierr); }
-
   ierr = EPSAllocateSolution(eps,0);CHKERRQ(ierr);
   ierr = EPS_SetInnerProduct(eps);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)eps->V,BVVECS,&flg);CHKERRQ(ierr);
-  if (flg) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver requires a BV with contiguous storage");
-  ierr = RGIsTrivial(eps->rg,&istrivial);CHKERRQ(ierr);
-  if (!istrivial) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support region filtering");
-  if (eps->stopping!=EPSStoppingBasic) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"External packages do not support user-defined stopping test");
   PetscFunctionReturn(0);
 }
 
@@ -143,6 +138,7 @@ PetscErrorCode EPSSolve_BLZPACK(EPS eps)
   Mat            A,M;
   KSP            ksp;
   PC             pc;
+  MPI_Fint       fcomm;
 
   PetscFunctionBegin;
   ierr = STGetMatrix(eps->st,0,&A);CHKERRQ(ierr);
@@ -175,7 +171,8 @@ PetscErrorCode EPSSolve_BLZPACK(EPS eps)
   blz->istor[10] = eps->isgeneralized ? 1 : 0;   /* solutions refinement (purify) */
   blz->istor[11] = 0;                  /* level of printing */
   blz->istor[12] = 6;                  /* file unit for output */
-  ierr = PetscBLASIntCast(MPI_Comm_c2f(PetscObjectComm((PetscObject)eps)),&blz->istor[13]);CHKERRQ(ierr);
+  fcomm = MPI_Comm_c2f(PetscObjectComm((PetscObject)eps));
+  blz->istor[13] = fcomm;
 
   blz->rstor[2]  = eps->tol;           /* threshold for convergence */
 
@@ -245,7 +242,7 @@ PetscErrorCode EPSSolve_BLZPACK(EPS eps)
   if (lflag!=0) {
     char msg[2048] = "";
     for (i = 0; i < 33; i++) {
-      if (blz->istor[15] & (1 << i)) { ierr = PetscStrcat(msg,blzpack_error[i]);CHKERRQ(ierr); }
+      if (blz->istor[15] & (1 << i)) { ierr = PetscStrlcat(msg,blzpack_error[i],sizeof(msg));CHKERRQ(ierr); }
     }
     SETERRQ2(PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"Error in BLZPACK (code=%d): '%s'",blz->istor[15],msg);
   }
@@ -493,6 +490,7 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_BLZPACK(EPS eps)
 
   eps->ops->solve          = EPSSolve_BLZPACK;
   eps->ops->setup          = EPSSetUp_BLZPACK;
+  eps->ops->setupsort      = EPSSetUpSort_Basic;
   eps->ops->setfromoptions = EPSSetFromOptions_BLZPACK;
   eps->ops->destroy        = EPSDestroy_BLZPACK;
   eps->ops->reset          = EPSReset_BLZPACK;
