@@ -23,10 +23,11 @@ static struct {
 PetscErrorCode EPSSetUp_TRLAN(EPS eps)
 {
   PetscErrorCode ierr;
-  PetscBool      istrivial;
   EPS_TRLAN      *tr = (EPS_TRLAN*)eps->data;
 
   PetscFunctionBegin;
+  EPSCheckHermitian(eps);
+  EPSCheckStandard(eps);
   ierr = PetscBLASIntCast(PetscMax(7,eps->nev+PetscMin(eps->nev,6)),&tr->maxlan);CHKERRQ(ierr);
   if (eps->ncv!=PETSC_DEFAULT) {
     if (eps->ncv<eps->nev) SETERRQ(PetscObjectComm((PetscObject)eps),1,"The value of ncv must be at least nev");
@@ -34,14 +35,10 @@ PetscErrorCode EPSSetUp_TRLAN(EPS eps)
   if (eps->mpd!=PETSC_DEFAULT) { ierr = PetscInfo(eps,"Warning: parameter mpd ignored\n");CHKERRQ(ierr); }
   if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(1000,eps->n);
 
-  if (!eps->ishermitian) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Requested method is only available for Hermitian problems");
-
-  if (eps->isgeneralized) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Requested method is not available for generalized problems");
-
   if (!eps->which) eps->which = EPS_LARGEST_REAL;
-  if (eps->which!=EPS_LARGEST_REAL && eps->which!=EPS_SMALLEST_REAL && eps->which!=EPS_TARGET_REAL) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Wrong value of eps->which");
-  if (eps->arbitrary) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Arbitrary selection of eigenpairs not supported in this solver");
-  if (eps->stopping!=EPSStoppingBasic) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"External packages do not support user-defined stopping test");
+  if (eps->which!=EPS_SMALLEST_REAL && eps->which!=EPS_LARGEST_REAL && eps->which!=EPS_TARGET_REAL) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver supports only smallest, largest or target real eigenvalues");
+  EPSCheckUnsupported(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_CONVERGENCE | EPS_FEATURE_STOPPING);
+  EPSCheckIgnored(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_EXTRACTION);
 
   tr->restart = 0;
   if (tr->maxlan+1-eps->ncv<=0) {
@@ -53,10 +50,6 @@ PetscErrorCode EPSSetUp_TRLAN(EPS eps)
   ierr = PetscMalloc1(tr->lwork,&tr->work);CHKERRQ(ierr);
   ierr = PetscLogObjectMemory((PetscObject)eps,tr->lwork*sizeof(PetscReal));CHKERRQ(ierr);
 
-  if (eps->extraction) { ierr = PetscInfo(eps,"Warning: extraction type ignored\n");CHKERRQ(ierr); }
-  ierr = RGIsTrivial(eps->rg,&istrivial);CHKERRQ(ierr);
-  if (!istrivial) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support region filtering");
-
   ierr = EPSAllocateSolution(eps,0);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -89,6 +82,9 @@ PetscErrorCode EPSSolve_TRLAN(EPS eps)
   PetscScalar    *pV;
   Vec            v0;
   Mat            A;
+#if !defined(PETSC_HAVE_MPIUNI)
+  MPI_Fint       fcomm;
+#endif
 
   PetscFunctionBegin;
   ierr = PetscBLASIntCast(eps->ncv,&ncv);CHKERRQ(ierr);
@@ -110,7 +106,8 @@ PetscErrorCode EPSSolve_TRLAN(EPS eps)
   ipar[5]  = tr->restart;  /* restarting scheme */
   ierr = PetscBLASIntCast(eps->max_it,&ipar[6]);CHKERRQ(ierr); /* maximum number of MATVECs */
 #if !defined(PETSC_HAVE_MPIUNI)
-  ierr = PetscBLASIntCast(MPI_Comm_c2f(PetscObjectComm((PetscObject)eps)),&ipar[7]);CHKERRQ(ierr);
+  fcomm    = MPI_Comm_c2f(PetscObjectComm((PetscObject)eps));
+  ipar[7]  = fcomm;
 #endif
   ipar[8]  = 0;            /* verboseness */
   ipar[9]  = 99;           /* Fortran IO unit number used to write log messages */
@@ -172,6 +169,7 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_TRLAN(EPS eps)
 
   eps->ops->solve          = EPSSolve_TRLAN;
   eps->ops->setup          = EPSSetUp_TRLAN;
+  eps->ops->setupsort      = EPSSetUpSort_Basic;
   eps->ops->destroy        = EPSDestroy_TRLAN;
   eps->ops->reset          = EPSReset_TRLAN;
   eps->ops->backtransform  = EPSBackTransform_Default;
