@@ -93,36 +93,34 @@ static PetscErrorCode EstimateRange(Mat A,PetscReal *left,PetscReal *right)
 
 static PetscErrorCode EPSSetUp_KrylovSchur_Filter(EPS eps)
 {
-  PetscErrorCode ierr;
-  SlepcSC        sc;
-  PetscReal      rleft,rright;
-  Mat            A;
+  PetscErrorCode  ierr;
+  EPS_KRYLOVSCHUR *ctx = (EPS_KRYLOVSCHUR*)eps->data;
+  PetscBool       estimaterange=PETSC_TRUE;
+  PetscReal       rleft,rright;
+  Mat             A;
 
   PetscFunctionBegin;
+  EPSCheckHermitianCondition(eps,PETSC_TRUE," with polynomial filter");
+  EPSCheckStandardCondition(eps,PETSC_TRUE," with polynomial filter");
   if (eps->intb >= PETSC_MAX_REAL && eps->inta <= PETSC_MIN_REAL) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"The defined computational interval should have at least one of their sides bounded");
-  if (!eps->ishermitian) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Polynomial filter only available for symmetric/Hermitian eigenproblems");
-  if (eps->isgeneralized) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Polynomial filters not available for generalized eigenproblems");
-  if (eps->arbitrary) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Arbitrary selection of eigenpairs cannot be used with polynomial filters");
+  EPSCheckUnsupportedCondition(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_EXTRACTION,PETSC_TRUE," with polynomial filter");
   if (eps->tol==PETSC_DEFAULT) eps->tol = SLEPC_DEFAULT_TOL*1e-2;  /* use tighter tolerance */
   ierr = STFilterSetInterval(eps->st,eps->inta,eps->intb);CHKERRQ(ierr);
-  ierr = STGetMatrix(eps->st,0,&A);CHKERRQ(ierr);
-  ierr = STFilterGetRange(eps->st,&rleft,&rright);CHKERRQ(ierr);
-  if (!rleft && !rright) {
+  if (!ctx->estimatedrange) {
+    ierr = STFilterGetRange(eps->st,&rleft,&rright);CHKERRQ(ierr);
+    estimaterange = (!rleft && !rright)? PETSC_TRUE: PETSC_FALSE;
+  }
+  if (estimaterange) { /* user did not set a range */
+    ierr = STGetMatrix(eps->st,0,&A);CHKERRQ(ierr);
     ierr = EstimateRange(A,&rleft,&rright);CHKERRQ(ierr);
     ierr = PetscInfo2(eps,"Setting eigenvalue range to [%g,%g]\n",(double)rleft,(double)rright);CHKERRQ(ierr);
     ierr = STFilterSetRange(eps->st,rleft,rright);CHKERRQ(ierr);
+    ctx->estimatedrange = PETSC_TRUE;
   }
   if (eps->ncv==PETSC_DEFAULT && eps->nev==1) eps->nev = 40;  /* user did not provide nev estimation */
   ierr = EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd);CHKERRQ(ierr);
   if (eps->ncv>eps->nev+eps->mpd) SETERRQ(PetscObjectComm((PetscObject)eps),1,"The value of ncv must not be larger than nev+mpd");
   if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
-
-  ierr = DSGetSlepcSC(eps->ds,&sc);CHKERRQ(ierr);
-  sc->rg            = NULL;
-  sc->comparison    = SlepcCompareLargestReal;
-  sc->comparisonctx = NULL;
-  sc->map           = NULL;
-  sc->mapobj        = NULL;
   PetscFunctionReturn(0);
 }
 
@@ -137,8 +135,7 @@ PetscErrorCode EPSSetUp_KrylovSchur(EPS eps)
   enum { EPS_KS_DEFAULT,EPS_KS_SYMM,EPS_KS_SLICE,EPS_KS_FILTER,EPS_KS_INDEF,EPS_KS_TWOSIDED } variant;
 
   PetscFunctionBegin;
-  /* spectrum slicing requires special treatment of default values */
-  if (eps->which==EPS_ALL) {
+  if (eps->which==EPS_ALL) {  /* default values in case of spectrum slicing or polynomial filter  */
     ierr = PetscObjectTypeCompare((PetscObject)eps->st,STFILTER,&isfilt);CHKERRQ(ierr);
     if (isfilt) {
       ierr = EPSSetUp_KrylovSchur_Filter(eps);CHKERRQ(ierr);
@@ -153,12 +150,9 @@ PetscErrorCode EPSSetUp_KrylovSchur(EPS eps)
   }
   if (!ctx->lock && eps->mpd<eps->ncv) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Should not use mpd parameter in non-locking variant");
 
-  if (eps->isgeneralized && eps->ishermitian && !eps->ispositive && eps->arbitrary) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Arbitrary selection of eigenpairs not implemented for indefinite problems");
-  if (eps->ishermitian && eps->ispositive && (eps->which==EPS_LARGEST_IMAGINARY || eps->which==EPS_SMALLEST_IMAGINARY)) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Wrong value of eps->which");
+  EPSCheckDefiniteCondition(eps,eps->arbitrary," with arbitrary selection of eigenpairs");
 
-  if (!eps->extraction) {
-    ierr = EPSSetExtraction(eps,EPS_RITZ);CHKERRQ(ierr);
-  } else if (eps->extraction!=EPS_RITZ && eps->extraction!=EPS_HARMONIC) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Unsupported extraction type");
+  if (eps->extraction!=EPS_RITZ && eps->extraction!=EPS_HARMONIC) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Unsupported extraction type");
 
   if (!ctx->keep) ctx->keep = 0.5;
 
@@ -210,7 +204,6 @@ PetscErrorCode EPSSetUp_KrylovSchur(EPS eps)
       ierr = DSAllocate(eps->ds,eps->ncv+1);CHKERRQ(ierr);
       break;
     case EPS_KS_SLICE:
-      if (eps->stopping!=EPSStoppingBasic) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Spectrum slicing does not support user-defined stopping test");
       eps->ops->solve = EPSSolve_KrylovSchur_Slice;
       eps->ops->computevectors = EPSComputeVectors_Slice;
       break;
@@ -237,6 +230,38 @@ PetscErrorCode EPSSetUp_KrylovSchur(EPS eps)
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode EPSSetUpSort_KrylovSchur(EPS eps)
+{
+  PetscErrorCode  ierr;
+  EPS_KRYLOVSCHUR *ctx = (EPS_KRYLOVSCHUR*)eps->data;
+  SlepcSC         sc;
+  PetscBool       isfilt;
+
+  PetscFunctionBegin;
+  ierr = EPSSetUpSort_Default(eps);CHKERRQ(ierr);
+  if (eps->which==EPS_ALL) {
+    ierr = PetscObjectTypeCompare((PetscObject)eps->st,STFILTER,&isfilt);CHKERRQ(ierr);
+    if (isfilt) {
+      ierr = DSGetSlepcSC(eps->ds,&sc);CHKERRQ(ierr);
+      sc->rg            = NULL;
+      sc->comparison    = SlepcCompareLargestReal;
+      sc->comparisonctx = NULL;
+      sc->map           = NULL;
+      sc->mapobj        = NULL;
+    } else {
+      if (!ctx->global && ctx->sr->numEigs>0) {
+        ierr = DSGetSlepcSC(eps->ds,&sc);CHKERRQ(ierr);
+        sc->rg            = NULL;
+        sc->comparison    = SlepcCompareLargestMagnitude;
+        sc->comparisonctx = NULL;
+        sc->map           = NULL;
+        sc->mapobj        = NULL;
+      }
+    }
+  }
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode EPSSolve_KrylovSchur_Default(EPS eps)
 {
   PetscErrorCode  ierr;
@@ -310,6 +335,7 @@ PetscErrorCode EPSSolve_KrylovSchur_Default(EPS eps)
 #endif
     }
     if (!ctx->lock && l>0) { l += k; k = 0; } /* non-locking variant: reset no. of converged pairs */
+    if (l) { ierr = PetscInfo1(eps,"Preparing to restart keeping l=%D vectors\n",l);CHKERRQ(ierr); }
 
     if (eps->reason == EPS_CONVERGED_ITERATING) {
       if (breakdown || k==nv) {
@@ -1404,10 +1430,10 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_KrylovSchur(EPS eps)
   ctx->global = PETSC_TRUE;
 
   eps->useds = PETSC_TRUE;
-  eps->hasts = PETSC_TRUE;
 
   /* solve and computevectors determined at setup */
   eps->ops->setup          = EPSSetUp_KrylovSchur;
+  eps->ops->setupsort      = EPSSetUpSort_KrylovSchur;
   eps->ops->setfromoptions = EPSSetFromOptions_KrylovSchur;
   eps->ops->destroy        = EPSDestroy_KrylovSchur;
   eps->ops->reset          = EPSReset_KrylovSchur;
