@@ -168,6 +168,7 @@ static PetscErrorCode EPSSliceGetEPS(EPS eps)
   Mat                A,B=NULL,Ar=NULL,Br=NULL;
   PetscInt           i;
   PetscReal          h,a,b,zero;
+  PetscBool          asymm,bsymm,aherm,bherm;
   PetscMPIInt        rank;
   EPS_SR             sr=ctx->sr;
   PC                 pc;
@@ -189,9 +190,13 @@ static PetscErrorCode EPSSliceGetEPS(EPS eps)
   } else {
     ierr = PetscObjectStateGet((PetscObject)A,&Astate);CHKERRQ(ierr);
     ierr = PetscObjectGetId((PetscObject)A,&Aid);CHKERRQ(ierr);
+    ierr = MatGetOption(A,MAT_SYMMETRIC,&asymm);CHKERRQ(ierr);
+    ierr = MatGetOption(A,MAT_HERMITIAN,&aherm);CHKERRQ(ierr);
     if (B) {
       ierr = PetscObjectStateGet((PetscObject)B,&Bstate);CHKERRQ(ierr);
       ierr = PetscObjectGetId((PetscObject)B,&Bid);CHKERRQ(ierr);
+      ierr = MatGetOption(B,MAT_SYMMETRIC,&bsymm);CHKERRQ(ierr);
+      ierr = MatGetOption(B,MAT_HERMITIAN,&bherm);CHKERRQ(ierr);
     }
     if (!ctx->subc) {
       /* Create context for subcommunicators */
@@ -204,10 +209,14 @@ static PetscErrorCode EPSSliceGetEPS(EPS eps)
       ierr = MatCreateRedundantMatrix(A,0,PetscSubcommChild(ctx->subc),MAT_INITIAL_MATRIX,&Ar);CHKERRQ(ierr);
       ctx->Astate = Astate;
       ctx->Aid = Aid;
+      ierr = MatSetOption(Ar,MAT_SYMMETRIC,asymm);CHKERRQ(ierr);
+      ierr = MatSetOption(Ar,MAT_HERMITIAN,aherm);CHKERRQ(ierr);
       if (B) {
         ierr = MatCreateRedundantMatrix(B,0,PetscSubcommChild(ctx->subc),MAT_INITIAL_MATRIX,&Br);CHKERRQ(ierr);
         ctx->Bstate = Bstate;
         ctx->Bid = Bid;
+        ierr = MatSetOption(Br,MAT_SYMMETRIC,bsymm);CHKERRQ(ierr);
+        ierr = MatSetOption(Br,MAT_HERMITIAN,bherm);CHKERRQ(ierr);
       }
     } else {
       if (ctx->Astate != Astate || (B && ctx->Bstate != Bstate) || ctx->Aid != Aid || (B && ctx->Bid != Bid)) {
@@ -215,10 +224,14 @@ static PetscErrorCode EPSSliceGetEPS(EPS eps)
         ierr = MatCreateRedundantMatrix(A,0,PetscSubcommChild(ctx->subc),MAT_INITIAL_MATRIX,&Ar);CHKERRQ(ierr);
         ctx->Astate = Astate;
         ctx->Aid = Aid;
+        ierr = MatSetOption(Ar,MAT_SYMMETRIC,asymm);CHKERRQ(ierr);
+        ierr = MatSetOption(Ar,MAT_HERMITIAN,aherm);CHKERRQ(ierr);
         if (B) {
           ierr = MatCreateRedundantMatrix(B,0,PetscSubcommChild(ctx->subc),MAT_INITIAL_MATRIX,&Br);CHKERRQ(ierr);
           ctx->Bstate = Bstate;
           ctx->Bid = Bid;
+          ierr = MatSetOption(Br,MAT_SYMMETRIC,bsymm);CHKERRQ(ierr);
+          ierr = MatSetOption(Br,MAT_HERMITIAN,bherm);CHKERRQ(ierr);
         }
         ierr = EPSSetOperators(ctx->eps,Ar,Br);CHKERRQ(ierr);
         ierr = MatDestroy(&Ar);CHKERRQ(ierr);
@@ -355,7 +368,6 @@ static PetscErrorCode EPSBackTransform_Skip(EPS eps)
 PetscErrorCode EPSSetUp_KrylovSchur_Slice(EPS eps)
 {
   PetscErrorCode  ierr;
-  PetscBool       issinv;
   EPS_KRYLOVSCHUR *ctx = (EPS_KRYLOVSCHUR*)eps->data,*ctx_glob;
   EPS_SR          sr,sr_loc,sr_glob;
   PetscInt        nEigs,dssz=1,i,zeros=0,off=0,method,hiteig=0;
@@ -363,17 +375,24 @@ PetscErrorCode EPSSetUp_KrylovSchur_Slice(EPS eps)
   PetscReal       r;
   MPI_Request     req;
   Mat             A,B=NULL;
-  SlepcSC         sc;
   DSParallelType  ptype;
 
   PetscFunctionBegin;
   if (ctx->global) {
+    EPSCheckHermitianDefiniteCondition(eps,PETSC_TRUE," with spectrum slicing");
+    EPSCheckSinvertCayleyCondition(eps,PETSC_TRUE," with spectrum slicing");
+    if (eps->inta==eps->intb) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support computing all eigenvalues unless you provide a computational interval with EPSSetInterval()");
     if (eps->intb >= PETSC_MAX_REAL && eps->inta <= PETSC_MIN_REAL) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"The defined computational interval should have at least one of their sides bounded");
-    if (!eps->ishermitian) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Spectrum slicing only available for symmetric/Hermitian eigenproblems");
-    if (eps->arbitrary) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Arbitrary selection of eigenpairs cannot be used with spectrum slicing");
-    ierr = PetscObjectTypeCompareAny((PetscObject)eps->st,&issinv,STSINVERT,STCAYLEY,"");CHKERRQ(ierr);
-    if (!issinv) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Shift-and-invert or Cayley ST is needed for spectrum slicing");
-    if (eps->tol==PETSC_DEFAULT) eps->tol = SLEPC_DEFAULT_TOL*1e-2;  /* use tighter tolerance */
+    EPSCheckUnsupportedCondition(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_STOPPING,PETSC_TRUE," with spectrum slicing");
+    EPSCheckIgnoredCondition(eps,EPS_FEATURE_BALANCE,PETSC_TRUE," with spectrum slicing");
+    if (eps->tol==PETSC_DEFAULT) {
+ #if defined(PETSC_USE_REAL_SINGLE)
+      eps->tol = SLEPC_DEFAULT_TOL;
+#else
+      /* use tighter tolerance */
+      eps->tol = SLEPC_DEFAULT_TOL*1e-2;
+#endif
+    }
     if (eps->max_it==PETSC_DEFAULT) eps->max_it = 100;
     if (ctx->nev==1) ctx->nev = PetscMin(40,eps->n);  /* nev not set, use default value */
     if (eps->n>10 && ctx->nev<10) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"nev cannot be less than 10 in spectrum slicing runs");
@@ -533,14 +552,6 @@ PetscErrorCode EPSSetUp_KrylovSchur_Slice(EPS eps)
       ierr = EPSSliceAllocateSolution(eps,1);CHKERRQ(ierr);
     }
     dssz = eps->ncv+1;
-    if (sr->numEigs>0) {
-      ierr = DSGetSlepcSC(eps->ds,&sc);CHKERRQ(ierr);
-      sc->rg            = NULL;
-      sc->comparison    = SlepcCompareLargestMagnitude;
-      sc->comparisonctx = NULL;
-      sc->map           = NULL;
-      sc->mapobj        = NULL;
-    }
     ierr = DSGetParallel(ctx->eps->ds,&ptype);CHKERRQ(ierr);
     ierr = DSSetParallel(eps->ds,ptype);CHKERRQ(ierr);
     ierr = DSGetMethod(ctx->eps->ds,&method);CHKERRQ(ierr);
@@ -752,7 +763,7 @@ static PetscErrorCode EPSSliceGatherSolution(EPS eps)
     ierr = PetscMPIIntCast(ns,&aux);CHKERRQ(ierr);
     ierr = MPI_Allgatherv(shifts_loc,aux,MPIU_REAL,ctx->shifts,ns_loc,disp,MPIU_REAL,ctx->commrank);CHKERRQ(ierr); /* shifts */
     ierr = MPI_Allgatherv(inertias_loc,aux,MPIU_INT,ctx->inertias,ns_loc,disp,MPIU_INT,ctx->commrank);CHKERRQ(ierr); /* inertias */
-    ierr = MPI_Allreduce(&sr_loc->itsKs,&eps->its,1,MPIU_INT,MPI_SUM,ctx->commrank);CHKERRQ(ierr);
+    ierr = MPIU_Allreduce(&sr_loc->itsKs,&eps->its,1,MPIU_INT,MPI_SUM,ctx->commrank);CHKERRQ(ierr);
   } else { /* subcommunicators with different size */
     ierr = MPI_Comm_rank(PetscSubcommChild(ctx->subc),&rank);CHKERRQ(ierr);
     if (!rank) {
@@ -763,7 +774,7 @@ static PetscErrorCode EPSSliceGatherSolution(EPS eps)
       ierr = PetscMPIIntCast(ns,&aux);CHKERRQ(ierr);
       ierr = MPI_Allgatherv(shifts_loc,aux,MPIU_REAL,ctx->shifts,ns_loc,disp,MPIU_REAL,ctx->commrank);CHKERRQ(ierr); /* shifts */
       ierr = MPI_Allgatherv(inertias_loc,aux,MPIU_INT,ctx->inertias,ns_loc,disp,MPIU_INT,ctx->commrank);CHKERRQ(ierr); /* inertias */
-      ierr = MPI_Allreduce(&sr_loc->itsKs,&eps->its,1,MPIU_INT,MPI_SUM,ctx->commrank);CHKERRQ(ierr);
+      ierr = MPIU_Allreduce(&sr_loc->itsKs,&eps->its,1,MPIU_INT,MPI_SUM,ctx->commrank);CHKERRQ(ierr);
     }
     ierr = PetscMPIIntCast(eps->nconv,&aux);CHKERRQ(ierr);
     ierr = MPI_Bcast(eps->eigr,aux,MPIU_SCALAR,0,PetscSubcommChild(ctx->subc));CHKERRQ(ierr);
@@ -933,8 +944,7 @@ static PetscErrorCode EPSKrylovSchur_Slice(EPS eps)
   EPS_shift       sPres;
   PetscBool       breakdown,complIterating,sch0,sch1;
   EPS_SR          sr = ctx->sr;
-#define MSGLEN 100
-  char            messg[MSGLEN];
+  char            messg[100];
 
   PetscFunctionBegin;
   /* Spectrum slicing data */
@@ -1094,7 +1104,7 @@ static PetscErrorCode EPSKrylovSchur_Slice(EPS eps)
   }
   sPres->comp[0] = PetscNot(count0 < sPres->nsch[0]);
   sPres->comp[1] = PetscNot(count1 < sPres->nsch[1]);
-  ierr = PetscSNPrintf(messg,MSGLEN,"Lanczos: %D evals in [%g,%g]%s and %D evals in [%g,%g]%s\n",count0,(double)(sr->dir==1)?sPres->ext[0]:sPres->value,(double)(sr->dir==1)?sPres->value:sPres->ext[0],(sPres->comp[0])?"*":"",count1,(double)(sr->dir==1)?sPres->value:sPres->ext[1],(double)(sr->dir==1)?sPres->ext[1]:sPres->value,(sPres->comp[1])?"*":"");CHKERRQ(ierr);
+  ierr = PetscSNPrintf(messg,sizeof(messg),"Lanczos: %D evals in [%g,%g]%s and %D evals in [%g,%g]%s\n",count0,(double)(sr->dir==1)?sPres->ext[0]:sPres->value,(double)(sr->dir==1)?sPres->value:sPres->ext[0],(sPres->comp[0])?"*":"",count1,(double)(sr->dir==1)?sPres->value:sPres->ext[1],(double)(sr->dir==1)?sPres->ext[1]:sPres->value,(sPres->comp[1])?"*":"");CHKERRQ(ierr);
   ierr = PetscInfo(eps,messg);CHKERRQ(ierr);
   if (count0 > sPres->nsch[0] || count1 > sPres->nsch[1]) InertiaMismatch(eps,ctx->detect);
   ierr = PetscFree(iwork);CHKERRQ(ierr);
