@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -26,19 +26,16 @@
 
 static PetscErrorCode EPSTwoSidedRQUpdate1(EPS eps,Mat M,PetscInt nv)
 {
-#if defined(PETSC_MISSING_LAPACK_GETRF) || defined(PETSC_MISSING_LAPACK_GETRS)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"GETRF/GETRS - Lapack routines are unavailable");
-#else
   PetscErrorCode ierr;
   PetscScalar    *T,*S,*A,*w,*pM,beta;
   Vec            u;
-  PetscInt       ld,ncv=eps->ncv,i;
+  PetscInt       ld,ncv=eps->ncv,i,l,nnv;
   PetscBLASInt   info,n_,ncv_,*p,one=1;
 
   PetscFunctionBegin;
   ierr = DSGetLeadingDimension(eps->ds,&ld);CHKERRQ(ierr);
   ierr = PetscMalloc3(nv,&p,ncv*ncv,&A,ncv,&w);CHKERRQ(ierr);
+  ierr = BVGetActiveColumns(eps->V,&l,&nnv);CHKERRQ(ierr);
   ierr = BVSetActiveColumns(eps->V,0,nv);CHKERRQ(ierr);
   ierr = BVSetActiveColumns(eps->W,0,nv);CHKERRQ(ierr);
   ierr = BVGetColumn(eps->V,nv,&u);CHKERRQ(ierr);
@@ -69,8 +66,9 @@ static PetscErrorCode EPSTwoSidedRQUpdate1(EPS eps,Mat M,PetscInt nv)
   for (i=0;i<nv;i++) T[(nv-1)*ld+i] += beta*w[i];
   ierr = DSRestoreArray(eps->dsts,DS_MAT_A,&T);CHKERRQ(ierr);
   ierr = PetscFree3(p,A,w);CHKERRQ(ierr);
+  ierr = BVSetActiveColumns(eps->V,l,nnv);CHKERRQ(ierr);
+  ierr = BVSetActiveColumns(eps->W,l,nnv);CHKERRQ(ierr);
   PetscFunctionReturn(0);
-#endif
 }
 
 static PetscErrorCode EPSTwoSidedRQUpdate2(EPS eps,Mat M,PetscInt k)
@@ -84,6 +82,8 @@ static PetscErrorCode EPSTwoSidedRQUpdate2(EPS eps,Mat M,PetscInt k)
   PetscFunctionBegin;
   ierr = DSGetLeadingDimension(eps->ds,&ld);CHKERRQ(ierr);
   ierr = BVGetActiveColumns(eps->V,&l,&nv);CHKERRQ(ierr);
+  ierr = BVSetActiveColumns(eps->V,0,nv);CHKERRQ(ierr);
+  ierr = BVSetActiveColumns(eps->W,0,nv);CHKERRQ(ierr);
   ierr = PetscMalloc2(ncv*ncv,&w,ncv,&c);CHKERRQ(ierr);
   /* u = u - V*V'*u */
   ierr = BVOrthogonalizeColumn(eps->V,k,c,&norm,NULL);CHKERRQ(ierr);
@@ -117,6 +117,8 @@ static PetscErrorCode EPSTwoSidedRQUpdate2(EPS eps,Mat M,PetscInt k)
   PetscStackCallBLAS("BLASgemm",BLASgemm_("C","N",&n_,&n_,&n_,&sone,Q,&ld_,w,&ncv_,&zero,pM,&ncv_));
   ierr = DSRestoreArray(eps->dsts,DS_MAT_Q,&Q);CHKERRQ(ierr);
   ierr = PetscFree2(w,c);CHKERRQ(ierr);
+  ierr = BVSetActiveColumns(eps->V,l,nv);CHKERRQ(ierr);
+  ierr = BVSetActiveColumns(eps->W,l,nv);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -124,52 +126,54 @@ PetscErrorCode EPSSolve_KrylovSchur_TwoSided(EPS eps)
 {
   PetscErrorCode  ierr;
   EPS_KRYLOVSCHUR *ctx = (EPS_KRYLOVSCHUR*)eps->data;
-  Mat             M,U;
+  Mat             M,U,Op,OpHT;
   PetscReal       norm,norm2,beta,betat,s,t;
   PetscScalar     *pM,*S,*T,*eigr,*eigi,*Q;
-  PetscInt        ld,l,nv,ncv=eps->ncv,i,j,k,nconv,*p,cont,*idx,*idx2,id=0;
-  PetscBool       breakdownt,breakdown;
+  PetscInt        ld,l,nv,nvt,ncv=eps->ncv,i,j,k,nconv,*p,cont,*idx,*idx2,id=0;
+  PetscBool       breakdownt,breakdown,breakdownl;
 #if defined(PETSC_USE_COMPLEX)
   Mat             A;
 #endif
 
   PetscFunctionBegin;
-  ctx->lock = PETSC_FALSE; /* TO DO */
   ierr = DSGetLeadingDimension(eps->ds,&ld);CHKERRQ(ierr);
   ierr = EPSGetStartVector(eps,0,NULL);CHKERRQ(ierr);
-  ierr = BVSetRandomColumn(eps->W,0);CHKERRQ(ierr);
-  ierr = BVNormColumn(eps->W,0,NORM_2,&norm);CHKERRQ(ierr);
-  ierr = BVScaleColumn(eps->W,0,1.0/norm);CHKERRQ(ierr);
+  ierr = EPSGetLeftStartVector(eps,0,NULL);CHKERRQ(ierr);
   l = 0;
   ierr = PetscMalloc6(ncv*ncv,&pM,ncv,&eigr,ncv,&eigi,ncv,&idx,ncv,&idx2,ncv,&p);CHKERRQ(ierr);
   ierr = MatCreateSeqDense(PETSC_COMM_SELF,eps->ncv,eps->ncv,pM,&M);CHKERRQ(ierr);
 
+  ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
+  ierr = MatCreateHermitianTranspose(Op,&OpHT);CHKERRQ(ierr);
+
   /* Restart loop */
   while (eps->reason == EPS_CONVERGED_ITERATING) {
     eps->its++;
 
-    /* Compute an nv-step Arnoldi factorization */
+    /* Compute an nv-step Arnoldi factorization for Op */
     nv = PetscMin(eps->nconv+eps->mpd,eps->ncv);
     ierr = DSGetArray(eps->ds,DS_MAT_A,&S);CHKERRQ(ierr);
-    ierr = EPSBasicArnoldi(eps,PETSC_FALSE,S,ld,eps->nconv+l,&nv,&beta,&breakdown);CHKERRQ(ierr);
+    ierr = BVMatArnoldi(eps->V,Op,S,ld,eps->nconv+l,&nv,&beta,&breakdown);CHKERRQ(ierr);
     ierr = DSRestoreArray(eps->ds,DS_MAT_A,&S);CHKERRQ(ierr);
-    ierr = DSSetDimensions(eps->ds,nv,0,eps->nconv,eps->nconv+l);CHKERRQ(ierr);
-    if (l==0) {
-      ierr = DSSetState(eps->ds,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
-    } else {
-      ierr = DSSetState(eps->ds,DS_STATE_RAW);CHKERRQ(ierr);
-    }
 
-    /* Compute an nv-step Arnoldi factorization */
+    /* Compute an nv-step Arnoldi factorization for Op' */
+    nvt = nv;
     ierr = DSGetArray(eps->dsts,DS_MAT_A,&T);CHKERRQ(ierr);
-    ierr = EPSBasicArnoldi(eps,PETSC_TRUE,T,ld,eps->nconv+l,&nv,&betat,&breakdownt);CHKERRQ(ierr);
+    ierr = BVMatArnoldi(eps->W,OpHT,T,ld,eps->nconv+l,&nvt,&betat,&breakdownt);CHKERRQ(ierr);
     ierr = DSRestoreArray(eps->dsts,DS_MAT_A,&T);CHKERRQ(ierr);
+
+    /* Make sure both factorizations have the same length */
+    nv = PetscMin(nv,nvt);
+    ierr = DSSetDimensions(eps->ds,nv,0,eps->nconv,eps->nconv+l);CHKERRQ(ierr);
     ierr = DSSetDimensions(eps->dsts,nv,0,eps->nconv,eps->nconv+l);CHKERRQ(ierr);
     if (l==0) {
+      ierr = DSSetState(eps->ds,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
       ierr = DSSetState(eps->dsts,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
     } else {
+      ierr = DSSetState(eps->ds,DS_STATE_RAW);CHKERRQ(ierr);
       ierr = DSSetState(eps->dsts,DS_STATE_RAW);CHKERRQ(ierr);
     }
+    breakdown = (breakdown || breakdownt)? PETSC_TRUE: PETSC_FALSE;
 
     /* Update M, modify Rayleigh quotients S and T */
     ierr = BVSetActiveColumns(eps->V,eps->nconv+l,nv);CHKERRQ(ierr);
@@ -196,13 +200,13 @@ PetscErrorCode EPSSolve_KrylovSchur_TwoSided(EPS eps)
     /* check correct eigenvalue correspondence */
     cont = 0;
     for (i=0;i<nv;i++) {
-      if (PetscAbsScalar(eigr[i]-eps->eigr[i])+PetscAbsScalar(eigi[i]-eps->eigi[i])>PETSC_SQRT_MACHINE_EPSILON) {idx2[cont] =i; idx[cont++] = i;}
+      if (SlepcAbsEigenvalue(eigr[i]-eps->eigr[i],eigi[i]-eps->eigi[i])>PETSC_SQRT_MACHINE_EPSILON) {idx2[cont] = i; idx[cont++] = i;}
       p[i] = -1;
     }
     if (cont) {
       for (i=0;i<cont;i++) {
         t = PETSC_MAX_REAL;
-        for (j=0;j<cont;j++) if (idx2[j]!=-1 && (s=PetscAbsScalar(eigr[idx[j]]-eps->eigr[idx[i]])+PetscAbsScalar(eigi[idx[j]]-eps->eigi[idx[i]]))<t) { id = j; t = s; }
+        for (j=0;j<cont;j++) if (idx2[j]!=-1 && (s=SlepcAbsEigenvalue(eigr[idx[j]]-eps->eigr[idx[i]],eigi[idx[j]]-eps->eigi[idx[i]]))<t) { id = j; t = s; }
         p[idx[i]] = idx[id];
         idx2[id] = -1;
       }
@@ -261,7 +265,8 @@ PetscErrorCode EPSSolve_KrylovSchur_TwoSided(EPS eps)
         ierr = PetscInfo2(eps,"Breakdown in Krylov-Schur method (it=%D norm=%g)\n",eps->its,(double)beta);CHKERRQ(ierr);
         if (k<eps->nev) {
           ierr = EPSGetStartVector(eps,k,&breakdown);CHKERRQ(ierr);
-          if (breakdown) {
+          ierr = EPSGetLeftStartVector(eps,k,&breakdownl);CHKERRQ(ierr);
+          if (breakdown || breakdownl) {
             eps->reason = EPS_DIVERGED_BREAKDOWN;
             ierr = PetscInfo(eps,"Unable to generate more start vectors\n");CHKERRQ(ierr);
           }
@@ -285,6 +290,9 @@ PetscErrorCode EPSSolve_KrylovSchur_TwoSided(EPS eps)
     ierr = EPSMonitor(eps,eps->its,nconv,eps->eigr,eps->eigi,eps->errest,nv);CHKERRQ(ierr);
   }
 
+  ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
+  ierr = MatDestroy(&OpHT);CHKERRQ(ierr);
+
   /* truncate Schur decomposition and change the state to raw so that
      DSVectors() computes eigenvectors from scratch */
   ierr = DSSetDimensions(eps->ds,eps->nconv,0,0,0);CHKERRQ(ierr);
