@@ -110,7 +110,6 @@ PetscErrorCode EPSCreate(MPI_Comm comm,EPS *outeps)
   eps->nrma            = 0.0;
   eps->nrmb            = 0.0;
   eps->useds           = PETSC_FALSE;
-  eps->hasts           = PETSC_FALSE;
   eps->isgeneralized   = PETSC_FALSE;
   eps->ispositive      = PETSC_FALSE;
   eps->ishermitian     = PETSC_FALSE;
@@ -414,7 +413,7 @@ PetscErrorCode EPSSetInterval(EPS eps,PetscReal inta,PetscReal intb)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveReal(eps,inta,2);
   PetscValidLogicalCollectiveReal(eps,intb,3);
-  if (inta>intb) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"Badly defined interval, must be inta<intb");
+  if (inta>=intb) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"Badly defined interval, must be inta<intb");
   if (eps->inta != inta || eps->intb != intb) {
     eps->inta = inta;
     eps->intb = intb;
