@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -15,10 +15,16 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_Subspace(EPS);
 SLEPC_EXTERN PetscErrorCode EPSCreate_Arnoldi(EPS);
 SLEPC_EXTERN PetscErrorCode EPSCreate_Lanczos(EPS);
 SLEPC_EXTERN PetscErrorCode EPSCreate_KrylovSchur(EPS);
+SLEPC_EXTERN PetscErrorCode EPSCreate_GD(EPS);
+SLEPC_EXTERN PetscErrorCode EPSCreate_JD(EPS);
+SLEPC_EXTERN PetscErrorCode EPSCreate_RQCG(EPS);
+SLEPC_EXTERN PetscErrorCode EPSCreate_LOBPCG(EPS);
+SLEPC_EXTERN PetscErrorCode EPSCreate_CISS(EPS);
+SLEPC_EXTERN PetscErrorCode EPSCreate_LyapII(EPS);
+SLEPC_EXTERN PetscErrorCode EPSCreate_LAPACK(EPS);
 #if defined(SLEPC_HAVE_ARPACK)
 SLEPC_EXTERN PetscErrorCode EPSCreate_ARPACK(EPS);
 #endif
-SLEPC_EXTERN PetscErrorCode EPSCreate_LAPACK(EPS);
 #if defined(SLEPC_HAVE_BLZPACK)
 SLEPC_EXTERN PetscErrorCode EPSCreate_BLZPACK(EPS);
 #endif
@@ -31,11 +37,18 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_BLOPEX(EPS);
 #if defined(SLEPC_HAVE_PRIMME)
 SLEPC_EXTERN PetscErrorCode EPSCreate_PRIMME(EPS);
 #endif
-SLEPC_EXTERN PetscErrorCode EPSCreate_GD(EPS);
-SLEPC_EXTERN PetscErrorCode EPSCreate_JD(EPS);
-SLEPC_EXTERN PetscErrorCode EPSCreate_RQCG(EPS);
-SLEPC_EXTERN PetscErrorCode EPSCreate_LOBPCG(EPS);
-SLEPC_EXTERN PetscErrorCode EPSCreate_CISS(EPS);
+#if defined(SLEPC_HAVE_FEAST)
+SLEPC_EXTERN PetscErrorCode EPSCreate_FEAST(EPS);
+#endif
+#if defined(SLEPC_HAVE_SCALAPACK)
+SLEPC_EXTERN PetscErrorCode EPSCreate_ScaLAPACK(EPS);
+#endif
+#if defined(SLEPC_HAVE_ELPA)
+SLEPC_EXTERN PetscErrorCode EPSCreate_ELPA(EPS);
+#endif
+#if defined(SLEPC_HAVE_ELEMENTAL)
+SLEPC_EXTERN PetscErrorCode EPSCreate_Elemental(EPS);
+#endif
 
 /*@C
   EPSRegisterAll - Registers all the eigenvalue solvers in the EPS package.
@@ -53,16 +66,17 @@ PetscErrorCode EPSRegisterAll(void)
   PetscFunctionBegin;
   if (EPSRegisterAllCalled) PetscFunctionReturn(0);
   EPSRegisterAllCalled = PETSC_TRUE;
-  ierr = EPSRegister(EPSKRYLOVSCHUR,EPSCreate_KrylovSchur);CHKERRQ(ierr);
   ierr = EPSRegister(EPSPOWER,EPSCreate_Power);CHKERRQ(ierr);
   ierr = EPSRegister(EPSSUBSPACE,EPSCreate_Subspace);CHKERRQ(ierr);
   ierr = EPSRegister(EPSARNOLDI,EPSCreate_Arnoldi);CHKERRQ(ierr);
   ierr = EPSRegister(EPSLANCZOS,EPSCreate_Lanczos);CHKERRQ(ierr);
+  ierr = EPSRegister(EPSKRYLOVSCHUR,EPSCreate_KrylovSchur);CHKERRQ(ierr);
   ierr = EPSRegister(EPSGD,EPSCreate_GD);CHKERRQ(ierr);
   ierr = EPSRegister(EPSJD,EPSCreate_JD);CHKERRQ(ierr);
   ierr = EPSRegister(EPSRQCG,EPSCreate_RQCG);CHKERRQ(ierr);
   ierr = EPSRegister(EPSLOBPCG,EPSCreate_LOBPCG);CHKERRQ(ierr);
   ierr = EPSRegister(EPSCISS,EPSCreate_CISS);CHKERRQ(ierr);
+  ierr = EPSRegister(EPSLYAPII,EPSCreate_LyapII);CHKERRQ(ierr);
   ierr = EPSRegister(EPSLAPACK,EPSCreate_LAPACK);CHKERRQ(ierr);
 #if defined(SLEPC_HAVE_ARPACK)
   ierr = EPSRegister(EPSARPACK,EPSCreate_ARPACK);CHKERRQ(ierr);
@@ -78,6 +92,18 @@ PetscErrorCode EPSRegisterAll(void)
 #endif
 #if defined(SLEPC_HAVE_PRIMME)
   ierr = EPSRegister(EPSPRIMME,EPSCreate_PRIMME);CHKERRQ(ierr);
+#endif
+#if defined(SLEPC_HAVE_FEAST)
+  ierr = EPSRegister(EPSFEAST,EPSCreate_FEAST);CHKERRQ(ierr);
+#endif
+#if defined(SLEPC_HAVE_SCALAPACK)
+  ierr = EPSRegister(EPSSCALAPACK,EPSCreate_ScaLAPACK);CHKERRQ(ierr);
+#endif
+#if defined(SLEPC_HAVE_ELPA)
+  ierr = EPSRegister(EPSELPA,EPSCreate_ELPA);CHKERRQ(ierr);
+#endif
+#if defined(SLEPC_HAVE_ELEMENTAL)
+  ierr = EPSRegister(EPSELEMENTAL,EPSCreate_Elemental);CHKERRQ(ierr);
 #endif
   PetscFunctionReturn(0);
 }
