@@ -393,8 +393,8 @@ PetscErrorCode EPSSetUp(EPS eps)
    Notes:
    To specify a standard eigenproblem, use NULL for parameter B.
 
-   It must be called before EPSSetUp(). If it is called again after EPSSetUp() then
-   the EPS object is reset.
+   It must be called before EPSSetUp(). If it is called again after EPSSetUp() and
+   the matrix sizes have changed then the EPS object is reset.
 
    Level: beginner
 
@@ -403,7 +403,7 @@ PetscErrorCode EPSSetUp(EPS eps)
 PetscErrorCode EPSSetOperators(EPS eps,Mat A,Mat B)
 {
   PetscErrorCode ierr;
-  PetscInt       m,n,m0,nmat;
+  PetscInt       m,n,m0,mloc,nloc,mloc0,nmat;
   Mat            mat[2];
 
   PetscFunctionBegin;
@@ -413,15 +413,20 @@ PetscErrorCode EPSSetOperators(EPS eps,Mat A,Mat B)
   PetscCheckSameComm(eps,1,A,2);
   if (B) PetscCheckSameComm(eps,1,B,3);
 
-  /* Check for square matrices */
+  /* Check matrix sizes */
   ierr = MatGetSize(A,&m,&n);CHKERRQ(ierr);
-  if (m!=n) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"A is a non-square matrix");
+  ierr = MatGetLocalSize(A,&mloc,&nloc);CHKERRQ(ierr);
+  if (m!=n) SETERRQ2(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"A is a non-square matrix (%D rows, %D cols)",m,n);
+  if (mloc!=nloc) SETERRQ2(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"A does not have equal row and column sizes (%D, %D)",mloc,nloc);
   if (B) {
     ierr = MatGetSize(B,&m0,&n);CHKERRQ(ierr);
-    if (m0!=n) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"B is a non-square matrix");
-    if (m!=m0) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_INCOMP,"Dimensions of A and B do not match");
+    ierr = MatGetLocalSize(B,&mloc0,&nloc);CHKERRQ(ierr);
+    if (m0!=n) SETERRQ2(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"B is a non-square matrix (%D rows, %D cols)",m0,n);
+    if (mloc0!=nloc) SETERRQ2(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"B does not have equal row and column local sizes (%D, %D)",mloc0,nloc);
+    if (m!=m0) SETERRQ2(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_INCOMP,"Dimensions of A and B do not match (%D, %D)",m,m0);
+    if (mloc!=mloc0) SETERRQ2(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_INCOMP,"Local dimensions of A and B do not match (%D, %D)",mloc,mloc0);
   }
-  if (eps->state && n!=eps->n) { ierr = EPSReset(eps);CHKERRQ(ierr); }
+  if (eps->state && (n!=eps->n || nloc!=eps->nloc)) { ierr = EPSReset(eps);CHKERRQ(ierr); }
   eps->nrma = 0.0;
   eps->nrmb = 0.0;
   if (!eps->st) { ierr = EPSGetST(eps,&eps->st);CHKERRQ(ierr); }
