@@ -138,7 +138,7 @@ int main (int argc,char **argv)
     ierr = EPSErrorView(eps,EPS_ERROR_RELATIVE,NULL);CHKERRQ(ierr);
   } else {
     ierr = PetscViewerPushFormat(PETSC_VIEWER_STDOUT_WORLD,PETSC_VIEWER_ASCII_INFO_DETAIL);CHKERRQ(ierr);
-    ierr = EPSReasonView(eps,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
+    ierr = EPSConvergedReasonView(eps,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
     ierr = EPSErrorView(eps,EPS_ERROR_RELATIVE,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
     ierr = PetscViewerPopFormat(PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
   }
@@ -302,7 +302,6 @@ PetscErrorCode STDestroy_User(SampleShellST *shell)
 
    testset:
       args: -eps_nev 5 -eps_non_hermitian -terse
-      requires: !single
       output_file: output/ex10_1.out
       test:
          suffix: 1_sinvert
@@ -313,6 +312,7 @@ PetscErrorCode STDestroy_User(SampleShellST *shell)
       test:
          suffix: 1_shell
          args: -st_type shell
+         requires: !single
       test:
          suffix: 1_shell_twoside
          args: -st_type shell -eps_balance twoside
