@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -33,8 +33,8 @@ PetscErrorCode MFNSetUp_Expokit(MFN mfn)
 
   PetscFunctionBegin;
   ierr = MatGetSize(mfn->A,&N,NULL);CHKERRQ(ierr);
-  if (!mfn->ncv) mfn->ncv = PetscMin(30,N);
-  if (!mfn->max_it) mfn->max_it = 100;
+  if (mfn->ncv==PETSC_DEFAULT) mfn->ncv = PetscMin(30,N);
+  if (mfn->max_it==PETSC_DEFAULT) mfn->max_it = 100;
   ierr = MFNAllocateSolution(mfn,2);CHKERRQ(ierr);
 
   ierr = PetscObjectTypeCompare((PetscObject)mfn->fn,FNEXP,&isexp);CHKERRQ(ierr);
@@ -91,7 +91,7 @@ PetscErrorCode MFNSolve_Expokit(MFN mfn,Vec b,Vec x)
     t_step = PetscMin(t_out-t_now,t_new);
     ierr = BVInsertVec(mfn->V,0,x);CHKERRQ(ierr);
     ierr = BVScaleColumn(mfn->V,0,1.0/beta);CHKERRQ(ierr);
-    ierr = MFNBasicArnoldi(mfn,H,ld,0,&mb,&beta2,&breakdown);CHKERRQ(ierr);
+    ierr = BVMatArnoldi(mfn->V,mfn->transpose_solve?mfn->AT:mfn->A,H,ld,0,&mb,&beta2,&breakdown);CHKERRQ(ierr);
     if (breakdown) {
       k1 = 0;
       t_step = t_out-t_now;
@@ -100,12 +100,12 @@ PetscErrorCode MFNSolve_Expokit(MFN mfn,Vec b,Vec x)
       H[m+1+ld*m] = 1.0;
       ierr = BVGetColumn(mfn->V,m,&v);CHKERRQ(ierr);
       ierr = BVGetColumn(mfn->V,m+1,&r);CHKERRQ(ierr);
-      ierr = MatMult(mfn->A,v,r);CHKERRQ(ierr);
+      ierr = MatMult(mfn->transpose_solve?mfn->AT:mfn->A,v,r);CHKERRQ(ierr);
       ierr = BVRestoreColumn(mfn->V,m,&v);CHKERRQ(ierr);
       ierr = BVRestoreColumn(mfn->V,m+1,&r);CHKERRQ(ierr);
       ierr = BVNormColumn(mfn->V,m+1,NORM_2,&avnorm);CHKERRQ(ierr);
     }
-    ierr = PetscMemcpy(B,H,ld*ld*sizeof(PetscScalar));CHKERRQ(ierr);
+    ierr = PetscArraycpy(B,H,ld*ld);CHKERRQ(ierr);
 
     ireject = 0;
     while (ireject <= mxrej) {
@@ -119,7 +119,7 @@ PetscErrorCode MFNSolve_Expokit(MFN mfn,Vec b,Vec x)
       ierr = MFN_CreateDenseMat(mx,&K);CHKERRQ(ierr);
       ierr = MatDenseGetArray(M,&F);CHKERRQ(ierr);
       for (j=0;j<mx;j++) {
-        ierr = PetscMemcpy(F+j*mx,H+j*ld,mx*sizeof(PetscScalar));CHKERRQ(ierr);
+        ierr = PetscArraycpy(F+j*mx,H+j*ld,mx);CHKERRQ(ierr);
       }
       ierr = MatDenseRestoreArray(M,&F);CHKERRQ(ierr);
       ierr = FNEvaluateFunctionMat(fn,M,K);CHKERRQ(ierr);
