@@ -224,9 +224,6 @@ int main(int argc,char **argv)
 
 /*TEST
 
-   build:
-      requires: c99
-
    test:
       suffix: 1
       args: -n 127 -tend 0.125 -mfn_tol 1e-3 -deltat 0.025
