@@ -149,7 +149,7 @@ static PetscErrorCode MatMultTranspose_FullBasis_Sinvert(Mat M,Vec x,Vec y)
     ierr = MatMultTranspose(ctx->D[0],z0,yy);CHKERRQ(ierr);
   }
   ierr = VecPlaceArray(xx,px);CHKERRQ(ierr);
-  ierr = VecAXPY(yy,-1.0,xx);;CHKERRQ(ierr);
+  ierr = VecAXPY(yy,-1.0,xx);CHKERRQ(ierr);
   ierr = VecResetArray(xx);CHKERRQ(ierr);
   ierr = VecScale(yy,-1.0/(s[0]-sigma));CHKERRQ(ierr);
   ierr = VecResetArray(yy);CHKERRQ(ierr);
@@ -286,7 +286,7 @@ PetscErrorCode NEPSetUp_NLEIGS_FullBasis(NEP nep)
     case NEP_WHICH_USER:         which = EPS_WHICH_USER;
       ierr = EPSSetEigenvalueComparison(ctx->eps,nep->sc->comparison,nep->sc->comparisonctx);CHKERRQ(ierr);
       break;
-    default: SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Should set a target selection in NEPSetWhichEigenvalues()");
+    default: SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Should set a target selection in NEPSetWhichEigenpairs()");
   }
   ierr = EPSSetWhichEigenpairs(ctx->eps,which);CHKERRQ(ierr);
   ierr = RGIsTrivial(nep->rg,&istrivial);CHKERRQ(ierr);
