@@ -9,6 +9,11 @@
 */
 /*
    NEP routines related to the solution process
+
+   References:
+
+       [1] C. Campos and J.E. Roman, "NEP: a module for the parallel solution
+           of nonlinear eigenvalue problems in SLEPc", arXiv:1910.11712, 2019.
 */
 
 #include <slepc/private/nepimpl.h>       /*I "slepcnep.h" I*/
@@ -82,10 +87,14 @@ PetscErrorCode NEPSolve(NEP nep)
   ierr = NEPViewFromOptions(nep,NULL,"-nep_view_pre");CHKERRQ(ierr);
   ierr = RGViewFromOptions(nep->rg,NULL,"-rg_view");CHKERRQ(ierr);
 
+  /* call solver */
   ierr = (*nep->ops->solve)(nep);CHKERRQ(ierr);
+  if (!nep->reason) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
   nep->state = NEP_STATE_SOLVED;
 
-  if (!nep->reason) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_PLIB,"Internal error, solver returned without setting converged reason");
+  /* Only the first nconv columns contain useful information */
+  ierr = BVSetActiveColumns(nep->V,0,nep->nconv);CHKERRQ(ierr);
+  if (nep->twosided) { ierr = BVSetActiveColumns(nep->W,0,nep->nconv);CHKERRQ(ierr); }
 
   if (nep->refine==NEP_REFINE_SIMPLE && nep->rits>0 && nep->nconv>0) {
     ierr = NEPComputeVectors(nep);CHKERRQ(ierr);
@@ -99,7 +108,7 @@ PetscErrorCode NEPSolve(NEP nep)
 
   /* various viewers */
   ierr = NEPViewFromOptions(nep,NULL,"-nep_view");CHKERRQ(ierr);
-  ierr = NEPReasonViewFromOptions(nep);CHKERRQ(ierr);
+  ierr = NEPConvergedReasonViewFromOptions(nep);CHKERRQ(ierr);
   ierr = NEPErrorViewFromOptions(nep);CHKERRQ(ierr);
   ierr = NEPValuesViewFromOptions(nep);CHKERRQ(ierr);
   ierr = NEPVectorsViewFromOptions(nep);CHKERRQ(ierr);
