@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -38,8 +38,6 @@
    PetscViewerASCIIOpen() - output to a specified file.
 
    Level: beginner
-
-.seealso: PetscViewerASCIIOpen()
 @*/
 PetscErrorCode NEPView(NEP nep,PetscViewer viewer)
 {
@@ -87,7 +85,7 @@ PetscErrorCode NEPView(NEP nep,PetscViewer viewer)
     }
     ierr = PetscViewerASCIIPrintf(viewer,"  selected portion of the spectrum: ");CHKERRQ(ierr);
     ierr = PetscViewerASCIIUseTabs(viewer,PETSC_FALSE);CHKERRQ(ierr);
-    ierr = SlepcSNPrintfScalar(str,50,nep->target,PETSC_FALSE);CHKERRQ(ierr);
+    ierr = SlepcSNPrintfScalar(str,sizeof(str),nep->target,PETSC_FALSE);CHKERRQ(ierr);
     if (!nep->which) {
       ierr = PetscViewerASCIIPrintf(viewer,"not yet set\n");CHKERRQ(ierr);
     } else switch (nep->which) {
@@ -197,33 +195,66 @@ PetscErrorCode NEPView(NEP nep,PetscViewer viewer)
 }
 
 /*@C
-   NEPReasonView - Displays the reason a NEP solve converged or diverged.
+   NEPViewFromOptions - View from options
+
+   Collective on NEP
+
+   Input Parameters:
++  nep  - the nonlinear eigensolver context
+.  obj  - optional object
+-  name - command line option
+
+   Level: intermediate
+
+.seealso: NEPView(), NEPCreate()
+@*/
+PetscErrorCode NEPViewFromOptions(NEP nep,PetscObject obj,const char name[])
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  ierr = PetscObjectViewFromOptions((PetscObject)nep,obj,name);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+/*@C
+   NEPConvergedReasonView - Displays the reason a NEP solve converged or diverged.
 
    Collective on nep
 
-   Parameter:
+   Input Parameters:
 +  nep - the nonlinear eigensolver context
 -  viewer - the viewer to display the reason
 
    Options Database Keys:
 .  -nep_converged_reason - print reason for convergence, and number of iterations
 
+   Note:
+   To change the format of the output call PetscViewerPushFormat(viewer,format) before
+   this call. Use PETSC_VIEWER_DEFAULT for the default, use PETSC_VIEWER_FAILED to only
+   display a reason if it fails. The latter can be set in the command line with
+   -nep_converged_reason ::failed
+
    Level: intermediate
 
-.seealso: NEPSetConvergenceTest(), NEPSetTolerances(), NEPGetIterationNumber()
+.seealso: NEPSetConvergenceTest(), NEPSetTolerances(), NEPGetIterationNumber(), NEPConvergedReasonViewFromOptions(
 @*/
-PetscErrorCode NEPReasonView(NEP nep,PetscViewer viewer)
+PetscErrorCode NEPConvergedReasonView(NEP nep,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
-  PetscBool      isAscii;
+  PetscErrorCode    ierr;
+  PetscBool         isAscii;
+  PetscViewerFormat format;
 
   PetscFunctionBegin;
+  if (!viewer) viewer = PETSC_VIEWER_STDOUT_(PetscObjectComm((PetscObject)nep));
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isAscii);CHKERRQ(ierr);
   if (isAscii) {
+    ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
     ierr = PetscViewerASCIIAddTab(viewer,((PetscObject)nep)->tablevel);CHKERRQ(ierr);
-    if (nep->reason > 0) {
+    if (nep->reason > 0 && format != PETSC_VIEWER_FAILED) {
       ierr = PetscViewerASCIIPrintf(viewer,"%s Nonlinear eigensolve converged (%D eigenpair%s) due to %s; iterations %D\n",((PetscObject)nep)->prefix?((PetscObject)nep)->prefix:"",nep->nconv,(nep->nconv>1)?"s":"",NEPConvergedReasons[nep->reason],nep->its);CHKERRQ(ierr);
-    } else {
+    } else if (nep->reason <= 0) {
       ierr = PetscViewerASCIIPrintf(viewer,"%s Nonlinear eigensolve did not converge due to %s; iterations %D\n",((PetscObject)nep)->prefix?((PetscObject)nep)->prefix:"",NEPConvergedReasons[nep->reason],nep->its);CHKERRQ(ierr);
     }
     ierr = PetscViewerASCIISubtractTab(viewer,((PetscObject)nep)->tablevel);CHKERRQ(ierr);
@@ -232,17 +263,19 @@ PetscErrorCode NEPReasonView(NEP nep,PetscViewer viewer)
 }
 
 /*@
-   NEPReasonViewFromOptions - Processes command line options to determine if/how
+   NEPConvergedReasonViewFromOptions - Processes command line options to determine if/how
    the NEP converged reason is to be viewed.
 
    Collective on nep
 
-   Input Parameters:
+   Input Parameter:
 .  nep - the nonlinear eigensolver context
 
    Level: developer
+
+.seealso: NEPConvergedReasonView()
 @*/
-PetscErrorCode NEPReasonViewFromOptions(NEP nep)
+PetscErrorCode NEPConvergedReasonViewFromOptions(NEP nep)
 {
   PetscErrorCode    ierr;
   PetscViewer       viewer;
@@ -256,7 +289,7 @@ PetscErrorCode NEPReasonViewFromOptions(NEP nep)
   ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)nep),((PetscObject)nep)->options,((PetscObject)nep)->prefix,"-nep_converged_reason",&viewer,&format,&flg);CHKERRQ(ierr);
   if (flg) {
     ierr = PetscViewerPushFormat(viewer,format);CHKERRQ(ierr);
-    ierr = NEPReasonView(nep,viewer);CHKERRQ(ierr);
+    ierr = NEPConvergedReasonView(nep,viewer);CHKERRQ(ierr);
     ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
     ierr = PetscViewerDestroy(&viewer);CHKERRQ(ierr);
   }
@@ -310,20 +343,19 @@ static PetscErrorCode NEPErrorView_DETAIL(NEP nep,NEPErrorType etype,PetscViewer
   PetscReal      error,re,im;
   PetscScalar    kr,ki;
   PetscInt       i;
-#define EXLEN 30
-  char           ex[EXLEN],sep[]=" ---------------------- --------------------\n";
+  char           ex[30],sep[]=" ---------------------- --------------------\n";
 
   PetscFunctionBegin;
   if (!nep->nconv) PetscFunctionReturn(0);
   switch (etype) {
     case NEP_ERROR_ABSOLUTE:
-      ierr = PetscSNPrintf(ex,EXLEN,"    ||T(k)x||");CHKERRQ(ierr);
+      ierr = PetscSNPrintf(ex,sizeof(ex),"    ||T(k)x||");CHKERRQ(ierr);
       break;
     case NEP_ERROR_RELATIVE:
-      ierr = PetscSNPrintf(ex,EXLEN," ||T(k)x||/||kx||");CHKERRQ(ierr);
+      ierr = PetscSNPrintf(ex,sizeof(ex)," ||T(k)x||/||kx||");CHKERRQ(ierr);
       break;
     case NEP_ERROR_BACKWARD:
-      ierr = PetscSNPrintf(ex,EXLEN,"    eta(x,k)");CHKERRQ(ierr);
+      ierr = PetscSNPrintf(ex,sizeof(ex),"    eta(x,k)");CHKERRQ(ierr);
       break;
   }
   ierr = PetscViewerASCIIPrintf(viewer,"%s            k             %s\n%s",sep,ex,sep);CHKERRQ(ierr);
@@ -432,7 +464,7 @@ PetscErrorCode NEPErrorView(NEP nep,NEPErrorType etype,PetscViewer viewer)
 
    Collective on nep
 
-   Input Parameters:
+   Input Parameter:
 .  nep - the nonlinear eigensolver context
 
    Level: developer
@@ -503,6 +535,31 @@ static PetscErrorCode NEPValuesView_DRAW(NEP nep,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
+static PetscErrorCode NEPValuesView_BINARY(NEP nep,PetscViewer viewer)
+{
+#if defined(PETSC_HAVE_COMPLEX)
+  PetscInt       i,k;
+  PetscComplex   *ev;
+  PetscErrorCode ierr;
+#endif
+
+  PetscFunctionBegin;
+#if defined(PETSC_HAVE_COMPLEX)
+  ierr = PetscMalloc1(nep->nconv,&ev);CHKERRQ(ierr);
+  for (i=0;i<nep->nconv;i++) {
+    k = nep->perm[i];
+#if defined(PETSC_USE_COMPLEX)
+    ev[i] = nep->eigr[k];
+#else
+    ev[i] = PetscCMPLX(nep->eigr[k],nep->eigi[k]);
+#endif
+  }
+  ierr = PetscViewerBinaryWrite(viewer,ev,nep->nconv,PETSC_COMPLEX);CHKERRQ(ierr);
+  ierr = PetscFree(ev);CHKERRQ(ierr);
+#endif
+  PetscFunctionReturn(0);
+}
+
 static PetscErrorCode NEPValuesView_ASCII(NEP nep,PetscViewer viewer)
 {
   PetscInt       i,k;
@@ -567,7 +624,7 @@ static PetscErrorCode NEPValuesView_MATLAB(NEP nep,PetscViewer viewer)
 @*/
 PetscErrorCode NEPValuesView(NEP nep,PetscViewer viewer)
 {
-  PetscBool         isascii,isdraw;
+  PetscBool         isascii,isdraw,isbinary;
   PetscViewerFormat format;
   PetscErrorCode    ierr;
 
@@ -580,9 +637,12 @@ PetscErrorCode NEPValuesView(NEP nep,PetscViewer viewer)
   PetscCheckSameComm(nep,1,viewer,2);
   NEPCheckSolved(nep,1);
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERDRAW,&isdraw);CHKERRQ(ierr);
+  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERBINARY,&isbinary);CHKERRQ(ierr);
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
   if (isdraw) {
     ierr = NEPValuesView_DRAW(nep,viewer);CHKERRQ(ierr);
+  } else if (isbinary) {
+    ierr = NEPValuesView_BINARY(nep,viewer);CHKERRQ(ierr);
   } else if (isascii) {
     ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
     switch (format) {
@@ -607,7 +667,7 @@ PetscErrorCode NEPValuesView(NEP nep,PetscViewer viewer)
 
    Collective on nep
 
-   Input Parameters:
+   Input Parameter:
 .  nep - the nonlinear eigensolver context
 
    Level: developer
@@ -639,7 +699,7 @@ PetscErrorCode NEPValuesViewFromOptions(NEP nep)
 
    Collective on nep
 
-   Parameter:
+   Input Parameters:
 +  nep    - the nonlinear eigensolver context
 -  viewer - the viewer
 
@@ -664,8 +724,7 @@ PetscErrorCode NEPVectorsView(NEP nep,PetscViewer viewer)
   PetscErrorCode ierr;
   PetscInt       i,k;
   Vec            x;
-#define NMLEN 30
-  char           vname[NMLEN];
+  char           vname[30];
   const char     *ename;
 
   PetscFunctionBegin;
@@ -681,13 +740,13 @@ PetscErrorCode NEPVectorsView(NEP nep,PetscViewer viewer)
     ierr = NEPComputeVectors(nep);CHKERRQ(ierr);
     for (i=0;i<nep->nconv;i++) {
       k = nep->perm[i];
-      ierr = PetscSNPrintf(vname,NMLEN,"X%d_%s",(int)i,ename);CHKERRQ(ierr);
+      ierr = PetscSNPrintf(vname,sizeof(vname),"X%d_%s",(int)i,ename);CHKERRQ(ierr);
       ierr = BVGetColumn(nep->V,k,&x);CHKERRQ(ierr);
       ierr = PetscObjectSetName((PetscObject)x,vname);CHKERRQ(ierr);
       ierr = VecView(x,viewer);CHKERRQ(ierr);
       ierr = BVRestoreColumn(nep->V,k,&x);CHKERRQ(ierr);
       if (nep->twosided) {
-        ierr = PetscSNPrintf(vname,NMLEN,"Y%d_%s",(int)i,ename);CHKERRQ(ierr);
+        ierr = PetscSNPrintf(vname,sizeof(vname),"Y%d_%s",(int)i,ename);CHKERRQ(ierr);
         ierr = BVGetColumn(nep->W,k,&x);CHKERRQ(ierr);
         ierr = PetscObjectSetName((PetscObject)x,vname);CHKERRQ(ierr);
         ierr = VecView(x,viewer);CHKERRQ(ierr);
@@ -704,7 +763,7 @@ PetscErrorCode NEPVectorsView(NEP nep,PetscViewer viewer)
 
    Collective on nep
 
-   Input Parameters:
+   Input Parameter:
 .  nep - the nonlinear eigensolver context
 
    Level: developer
