@@ -151,7 +151,7 @@ int main(int argc,char **argv)
     ierr = NEPErrorView(nep,NEP_ERROR_RELATIVE,NULL);CHKERRQ(ierr);
   } else {
     ierr = PetscViewerPushFormat(PETSC_VIEWER_STDOUT_WORLD,PETSC_VIEWER_ASCII_INFO_DETAIL);CHKERRQ(ierr);
-    ierr = NEPReasonView(nep,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
+    ierr = NEPConvergedReasonView(nep,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
     ierr = NEPErrorView(nep,NEP_ERROR_RELATIVE,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
     ierr = PetscViewerPopFormat(PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
   }
@@ -369,7 +369,7 @@ PetscErrorCode MatDestroy_Jac(Mat A)
       args: -terse
       requires: !single
       output_file: output/ex21_1.out
-      filter: sed -e "s/[+-]0\.0*i//g" -e "s/+0i//"
+      filter: sed -e "s/[+-]0\.0*i//g" -e "s/+0i//g"
       test:
          suffix: 1_rii
          args: -nep_type rii -nep_target 4
