@@ -167,7 +167,7 @@ int main(int argc,char **argv)
     ierr = NEPErrorView(nep,NEP_ERROR_RELATIVE,NULL);CHKERRQ(ierr);
   } else {
     ierr = PetscViewerPushFormat(PETSC_VIEWER_STDOUT_WORLD,PETSC_VIEWER_ASCII_INFO_DETAIL);CHKERRQ(ierr);
-    ierr = NEPReasonView(nep,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
+    ierr = NEPConvergedReasonView(nep,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
     ierr = NEPErrorView(nep,NEP_ERROR_RELATIVE,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
     ierr = PetscViewerPopFormat(PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
   }
@@ -192,11 +192,6 @@ int main(int argc,char **argv)
          suffix: 1
          args: -nep_type {{rii slp narnoldi}}
 
-   test:
-      suffix: 1_ciss
-      args: -nep_type ciss -rg_type ellipse -rg_ellipse_center 10 -rg_ellipse_radius 9.5 -nep_ncv 24 -terse
-      requires: complex
-
    test:
       suffix: 2
       args: -nep_type interpol -nep_interpol_pep_extract {{none norm residual}} -rg_type interval -rg_interval_endpoints 5,20,-.1,.1 -nep_nev 3 -nep_target 5 -terse
@@ -208,10 +203,10 @@ int main(int argc,char **argv)
       output_file: output/ex22_3.out
       test:
          suffix: 3
-         args: -nep_type {{rii slp narnoldi}} -nep_deflation_simpleu
+         args: -nep_type {{rii slp narnoldi}}
       test:
          suffix: 3_simpleu
-         args: -nep_type narnoldi -nep_deflation_simpleu
+         args: -nep_type {{rii slp narnoldi}} -nep_deflation_simpleu
       test:
          suffix: 3_slp_thres
          args: -nep_type slp -nep_slp_deflation_threshold 1e-8
