@@ -20,7 +20,7 @@
 
        [1] C. Campos and J.E. Roman, "A polynomial Jacobi-Davidson solver
            with support for non-monomial bases and deflation", BIT Numer.
-           Math. (in press), 2019.
+           Math. 60:295-318, 2020.
 
        [2] G.L.G. Sleijpen et al., "Jacobi-Davidson type methods for
            generalized eigenproblems and polynomial eigenproblems", BIT
@@ -41,10 +41,9 @@ static const char citation[] =
   "   author = \"C. Campos and J. E. Roman\",\n"
   "   title = \"A polynomial {Jacobi-Davidson} solver with support for non-monomial bases and deflation\",\n"
   "   journal = \"{BIT} Numer. Math.\",\n"
-  "   volume = \"IP\",\n"
-  "   number = \"-\",\n"
-  "   pages = \"1--24\",\n"
-  "   year = \"2019,\"\n"
+  "   volume = \"60\",\n"
+  "   pages = \"295--318\",\n"
+  "   year = \"2020,\"\n"
   "   doi = \"https://doi.org/10.1007/s10543-019-00778-z\"\n"
   "}\n";
 
@@ -133,17 +132,17 @@ PetscErrorCode PEPSetUp_JD(PEP pep)
   PetscInt       i;
 
   PetscFunctionBegin;
-  pep->lineariz = PETSC_FALSE;
   ierr = PEPSetDimensions_Default(pep,pep->nev,&pep->ncv,&pep->mpd);CHKERRQ(ierr);
   if (pep->max_it==PETSC_DEFAULT) pep->max_it = PetscMax(100,2*pep->n/pep->ncv);
   if (!pep->which) pep->which = PEP_TARGET_MAGNITUDE;
-  if (pep->which!=PEP_TARGET_MAGNITUDE && pep->which!=PEP_TARGET_REAL && pep->which!=PEP_TARGET_IMAGINARY) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Wrong value of pep->which");
+  if (pep->which!=PEP_TARGET_MAGNITUDE && pep->which!=PEP_TARGET_REAL && pep->which!=PEP_TARGET_IMAGINARY) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"The JD solver supports only target which, see PEPSetWhichEigenpairs()");
 
   ierr = PetscObjectTypeCompare((PetscObject)pep->st,STPRECOND,&isprecond);CHKERRQ(ierr);
-  if (!isprecond) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"JD only works with PRECOND spectral transformation");
+  if (!isprecond) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"The JD solver only works with PRECOND spectral transformation");
 
   ierr = STGetTransform(pep->st,&flg);CHKERRQ(ierr);
-  if (flg) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Solver requires the ST transformation flag unset, see STSetTransform()");
+  if (flg) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"The JD solver requires the ST transform flag unset, see STSetTransform()");
+  PEPCheckIgnored(pep,PEP_FEATURE_EXTRACT);
 
   if (!pjd->mmidx) pjd->mmidx = pep->nmat-1;
   pjd->mmidx = PetscMin(pjd->mmidx,pep->nmat-1);
@@ -1123,45 +1122,34 @@ static PetscErrorCode PEPJDEigenvectors(PEP pep)
   PetscErrorCode ierr;
   PEP_JD         *pjd = (PEP_JD*)pep->data;
   PetscBLASInt   ld,nconv,info,nc;
-  PetscScalar    *Z,*w;
-  PetscReal      *wr,norm;
-  PetscInt       i;
+  PetscScalar    *Z;
+  PetscReal      *wr;
   Mat            U;
-#if !defined(PETSC_USE_COMPLEX)
-  Vec            v,v1;
+#if defined(PETSC_USE_COMPLEX)
+  PetscScalar    *w;
 #endif
 
   PetscFunctionBegin;
-  ierr = PetscMalloc3(pep->nconv*pep->nconv,&Z,3*pep->ncv,&wr,2*pep->ncv,&w);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(pep->ncv,&ld);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(pep->nconv,&nconv);CHKERRQ(ierr);
 #if !defined(PETSC_USE_COMPLEX)
+  ierr = PetscMalloc2(pep->nconv*pep->nconv,&Z,3*pep->ncv,&wr);CHKERRQ(ierr);
   PetscStackCallBLAS("LAPACKtrevc",LAPACKtrevc_("R","A",NULL,&nconv,pjd->T,&ld,NULL,&nconv,Z,&nconv,&nconv,&nc,wr,&info));
 #else
+  ierr = PetscMalloc3(pep->nconv*pep->nconv,&Z,3*pep->ncv,&wr,2*pep->ncv,&w);CHKERRQ(ierr);
   PetscStackCallBLAS("LAPACKtrevc",LAPACKtrevc_("R","A",NULL,&nconv,pjd->T,&ld,NULL,&nconv,Z,&nconv,&nconv,&nc,w,wr,&info));
 #endif
   SlepcCheckLapackInfo("trevc",info);
   ierr = MatCreateSeqDense(PETSC_COMM_SELF,nconv,nconv,Z,&U);CHKERRQ(ierr);
   ierr = BVSetActiveColumns(pjd->X,0,pep->nconv);CHKERRQ(ierr);
   ierr = BVMultInPlace(pjd->X,U,0,pep->nconv);CHKERRQ(ierr);
-  for (i=0;i<pep->nconv;i++) {
-#if !defined(PETSC_USE_COMPLEX)
-    if (pep->eigi[i]!=0.0) {   /* first eigenvalue of a complex conjugate pair */
-      ierr = BVGetColumn(pjd->X,i,&v);CHKERRQ(ierr);
-      ierr = BVGetColumn(pjd->X,i+1,&v1);CHKERRQ(ierr);
-      ierr = VecNormalizeComplex(v,v1,PETSC_TRUE,NULL);CHKERRQ(ierr);
-      ierr = BVRestoreColumn(pjd->X,i,&v);CHKERRQ(ierr);
-      ierr = BVRestoreColumn(pjd->X,i+1,&v1);CHKERRQ(ierr);
-      i++;
-    } else   /* real eigenvalue */
-#endif
-    {
-      ierr = BVNormColumn(pjd->X,i,NORM_2,&norm);CHKERRQ(ierr);
-      ierr = BVScaleColumn(pjd->X,i,1.0/norm);CHKERRQ(ierr);
-    }
-  }
+  ierr = BVNormalize(pjd->X,pep->eigi);CHKERRQ(ierr);
   ierr = MatDestroy(&U);CHKERRQ(ierr);
+#if !defined(PETSC_USE_COMPLEX)
+  ierr = PetscFree2(Z,wr);CHKERRQ(ierr);
+#else
   ierr = PetscFree3(Z,wr,w);CHKERRQ(ierr);
+#endif
   PetscFunctionReturn(0);
 }
 
@@ -2090,8 +2078,9 @@ SLEPC_EXTERN PetscErrorCode PEPCreate_JD(PEP pep)
   ierr = PetscNewLog(pep,&pjd);CHKERRQ(ierr);
   pep->data = (void*)pjd;
 
-  pjd->fix   = 0.01;
-  pjd->mmidx = 0;
+  pep->lineariz = PETSC_FALSE;
+  pjd->fix      = 0.01;
+  pjd->mmidx    = 0;
 
   pep->ops->solve          = PEPSolve_JD;
   pep->ops->setup          = PEPSetUp_JD;
