@@ -20,7 +20,7 @@
 
        [1] C. Campos and J.E. Roman, "Inertia-based spectrum slicing
            for symmetric quadratic eigenvalue problems", Numer. Linear
-           Algebra Appl. (in press), 2020.
+           Algebra Appl. 27(4):e2293, 2020.
 */
 
 #include <slepc/private/pepimpl.h>         /*I "slepcpep.h" I*/
@@ -33,9 +33,9 @@ static const char citation[] =
   "   author = \"C. Campos and J. E. Roman\",\n"
   "   title = \"Inertia-based spectrum slicing for symmetric quadratic eigenvalue problems\",\n"
   "   journal = \"Numer. Linear Algebra Appl.\",\n"
-  "   volume = \"IP\",\n"
-  "   number = \"x\",\n"
-  "   pages = \"xx--xx\",\n"
+  "   volume = \"27\",\n"
+  "   number = \"4\",\n"
+  "   pages = \"e2293\",\n"
   "   year = \"2020,\"\n"
   "   doi = \"https://doi.org/10.1002/nla.2293\"\n"
   "}\n";
@@ -502,14 +502,21 @@ PetscErrorCode PEPSetUp_STOAR_QSlice(PEP pep)
   PEP_SR         sr;
   PetscInt       ld,i,zeros=0;
   SlepcSC        sc;
-  PetscBool      issinv;
   PetscReal      r;
 
   PetscFunctionBegin;
+  PEPCheckSinvertCayley(pep);
+  if (pep->inta==pep->intb) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"This solver does not support computing all eigenvalues unless you provide a computational interval with PEPSetInterval()");
   if (pep->intb >= PETSC_MAX_REAL && pep->inta <= PETSC_MIN_REAL) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_WRONG,"The defined computational interval should have at least one of their sides bounded");
-  ierr = PetscObjectTypeCompareAny((PetscObject)pep->st,&issinv,STSINVERT,STCAYLEY,"");CHKERRQ(ierr);
-  if (!issinv) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Shift-and-invert or Cayley ST is needed for spectrum slicing");
-  if (pep->tol==PETSC_DEFAULT) pep->tol = SLEPC_DEFAULT_TOL*1e-2;  /* use tighter tolerance */
+  PEPCheckUnsupportedCondition(pep,PEP_FEATURE_STOPPING,PETSC_TRUE," (with spectrum slicing)");
+  if (pep->tol==PETSC_DEFAULT) {
+#if defined(PETSC_USE_REAL_SINGLE)
+    pep->tol = SLEPC_DEFAULT_TOL;
+#else
+    /* use tighter tolerance */
+    pep->tol = SLEPC_DEFAULT_TOL*1e-2;
+#endif
+  }
   if (ctx->nev==1) ctx->nev = PetscMin(20,pep->n);  /* nev not set, use default value */
   if (pep->n>10 && ctx->nev<10) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_WRONG,"nev cannot be less than 10 in spectrum slicing runs");
   pep->ops->backtransform = PEPBackTransform_Skip;
