@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -14,10 +14,10 @@
 #include <slepc/private/pepimpl.h>    /*I "slepcpep.h" I*/
 #include <slepcblaslapack.h>
 
-/* 
+/*
   Computes T_j=phy_idx(T) for a matrix T.
-    Tp (if j>0) and Tpp (if j>1) are the evaluation 
-    of phy_(j-1) and phy(j-2)respectively. 
+    Tp (if j>0) and Tpp (if j>1) are the evaluation
+    of phy_(j-1) and phy(j-2)respectively.
 */
 PetscErrorCode PEPEvaluateBasisMat(PEP pep,PetscInt k,PetscScalar *T,PetscInt ldt,PetscInt idx,PetscScalar *Tpp,PetscInt ldtpp,PetscScalar *Tp,PetscInt ldtp,PetscScalar *Tj,PetscInt ldtj)
 {
@@ -30,7 +30,7 @@ PetscErrorCode PEPEvaluateBasisMat(PEP pep,PetscInt k,PetscScalar *T,PetscInt ld
   PetscFunctionBegin;
   if (idx==0) {
     for (i=0;i<k;i++) {
-      ierr = PetscMemzero(Tj+i*ldtj,k*sizeof(PetscScalar));CHKERRQ(ierr);
+      ierr = PetscArrayzero(Tj+i*ldtj,k);CHKERRQ(ierr);
       Tj[i+i*ldtj] = 1.0;
     }
   } else {
@@ -40,9 +40,9 @@ PetscErrorCode PEPEvaluateBasisMat(PEP pep,PetscInt k,PetscScalar *T,PetscInt ld
     ierr = PetscBLASIntCast(k,&k_);CHKERRQ(ierr);
     ca = pep->pbc; cb = pep->pbc+pep->nmat; cg = pep->pbc+2*pep->nmat;
     for (i=0;i<k;i++) T[i*ldt+i] -= cb[idx-1];
-    if (idx>1) { 
+    if (idx>1) {
       for (i=0;i<k;i++) {
-        ierr = PetscMemcpy(Tj+i*ldtj,Tpp+i*ldtpp,k*sizeof(PetscScalar));CHKERRQ(ierr);
+        ierr = PetscArraycpy(Tj+i*ldtj,Tpp+i*ldtpp,k);CHKERRQ(ierr);
       }
     }
     a = 1/ca[idx-1];
