@@ -85,6 +85,22 @@ PetscErrorCode PEPConvergedNorm(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscR
   PetscFunctionReturn(0);
 }
 
+/*
+  PEPSetWhichEigenpairs_Default - Sets the default value for which,
+  depending on the ST.
+ */
+PetscErrorCode PEPSetWhichEigenpairs_Default(PEP pep)
+{
+  PetscBool      target;
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  ierr = PetscObjectTypeCompare((PetscObject)pep->st,STSINVERT,&target);CHKERRQ(ierr);
+  if (target) pep->which = PEP_TARGET_MAGNITUDE;
+  else pep->which = PEP_LARGEST_MAGNITUDE;
+  PetscFunctionReturn(0);
+}
+
 /*
   PEPConvergedAbsolute - Checks convergence absolutely.
 */
@@ -157,9 +173,6 @@ PetscErrorCode PEPComputeVectors_Default(PEP pep)
   PetscErrorCode ierr;
   PetscInt       i;
   Vec            v;
-#if !defined(PETSC_USE_COMPLEX)
-  Vec            v1;
-#endif
 
   PetscFunctionBegin;
   ierr = PEPExtractVectors(pep);CHKERRQ(ierr);
@@ -174,23 +187,7 @@ PetscErrorCode PEPComputeVectors_Default(PEP pep)
   }
 
   /* normalization */
-  for (i=0;i<pep->nconv;i++) {
-#if !defined(PETSC_USE_COMPLEX)
-    if (pep->eigi[i]!=0.0) {   /* first eigenvalue of a complex conjugate pair */
-      ierr = BVGetColumn(pep->V,i,&v);CHKERRQ(ierr);
-      ierr = BVGetColumn(pep->V,i+1,&v1);CHKERRQ(ierr);
-      ierr = VecNormalizeComplex(v,v1,PETSC_TRUE,NULL);CHKERRQ(ierr);
-      ierr = BVRestoreColumn(pep->V,i,&v);CHKERRQ(ierr);
-      ierr = BVRestoreColumn(pep->V,i+1,&v1);CHKERRQ(ierr);
-      i++;
-    } else   /* real eigenvalue */
-#endif
-    {
-      ierr = BVGetColumn(pep->V,i,&v);CHKERRQ(ierr);
-      ierr = VecNormalizeComplex(v,NULL,PETSC_FALSE,NULL);CHKERRQ(ierr);
-      ierr = BVRestoreColumn(pep->V,i,&v);CHKERRQ(ierr);
-    }
-  }
+  ierr = BVNormalize(pep->V,pep->eigi);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -289,7 +286,7 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
       for (j=0;j<nz;j++) aux[cidx[j]] += PetscAbsScalar(array[j]);
       ierr = MatSeqAIJRestoreArray(M,&array);CHKERRQ(ierr);
     }
-    ierr = MPI_Allreduce(aux,csum,n,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)pep->Dr));CHKERRQ(ierr);
+    ierr = MPIU_Allreduce(aux,csum,n,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)pep->Dr));CHKERRQ(ierr);
     /* Update Dr */
     for (j=lst;j<lend;j++) {
       d = PetscLogReal(csum[j])/l2;
@@ -331,8 +328,8 @@ PetscErrorCode PEPBuildDiagonalScaling(PEP pep)
     }
     ierr = MatSeqAIJRestoreArray(M,&array);CHKERRQ(ierr);
     /* Compute global max and min */
-    ierr = MPI_Allreduce(&emaxl,&emax,1,MPIU_INT,MPI_MAX,PetscObjectComm((PetscObject)pep->Dl));CHKERRQ(ierr);
-    ierr = MPI_Allreduce(&eminl,&emin,1,MPIU_INT,MPI_MIN,PetscObjectComm((PetscObject)pep->Dl));CHKERRQ(ierr);
+    ierr = MPIU_Allreduce(&emaxl,&emax,1,MPIU_INT,MPI_MAX,PetscObjectComm((PetscObject)pep->Dl));CHKERRQ(ierr);
+    ierr = MPIU_Allreduce(&eminl,&emin,1,MPIU_INT,MPI_MIN,PetscObjectComm((PetscObject)pep->Dl));CHKERRQ(ierr);
     if (emax<=emin+2) cont = PETSC_FALSE;
   }
   ierr = VecRestoreArray(pep->Dr,&Dr);CHKERRQ(ierr);
