@@ -156,7 +156,7 @@ int main(int argc,char **argv)
   /* show detailed info unless -terse option is given by user */
   ierr = PetscViewerASCIIGetStdout(PETSC_COMM_WORLD,&viewer);CHKERRQ(ierr);
   ierr = PetscViewerPushFormat(viewer,PETSC_VIEWER_ASCII_INFO_DETAIL);CHKERRQ(ierr);
-  ierr = PEPReasonView(pep,viewer);CHKERRQ(ierr);
+  ierr = PEPConvergedReasonView(pep,viewer);CHKERRQ(ierr);
   ierr = PetscOptionsHasName(NULL,NULL,"-terse",&terse);CHKERRQ(ierr);
   if (!terse) {
     ierr = PEPErrorView(pep,PEP_ERROR_BACKWARD,viewer);CHKERRQ(ierr);
@@ -177,7 +177,7 @@ int main(int argc,char **argv)
 
     Ignores the value of nev. It only takes into account the number of
     eigenpairs that have converged in recent outer iterations (restarts);
-    if no new eigenvalus have converged in the last few restarts,
+    if no new eigenvalues have converged in the last few restarts,
     we stop the iteration, assuming that no more eigenvalues are present
     inside the region.
 */
