@@ -135,10 +135,13 @@ int main(int argc,char **argv)
   ierr = KSPSetType(ksp,KSPPREONLY);CHKERRQ(ierr);
   ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
   ierr = PCSetType(pc,PCCHOLESKY);CHKERRQ(ierr);
-#if defined(PETSC_HAVE_MUMPS)
-#if defined(PETSC_USE_COMPLEX)
-  SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_SUP,"Spectrum slicing with MUMPS is not available for complex scalars");
-#endif
+
+  /*
+     Use MUMPS if available.
+     Note that in complex scalars we cannot use MUMPS for spectrum slicing,
+     because MatGetInertia() is not available in that case.
+  */
+#if defined(PETSC_HAVE_MUMPS) && !defined(PETSC_USE_COMPLEX)
   ierr = PCFactorSetMatSolverType(pc,MATSOLVERMUMPS);CHKERRQ(ierr);
   /*
      Add several MUMPS options (see ex43.c for a better way of setting them in program):
