@@ -93,7 +93,7 @@ PetscErrorCode SVDView(SVD svd,PetscViewer viewer)
       ierr = (*svd->ops->view)(svd,viewer);CHKERRQ(ierr);
     }
   }
-  ierr = PetscObjectTypeCompareAny((PetscObject)svd,&isshell,SVDCROSS,SVDCYCLIC,SVDPRIMME,"");CHKERRQ(ierr);
+  ierr = PetscObjectTypeCompareAny((PetscObject)svd,&isshell,SVDCROSS,SVDCYCLIC,SVDSCALAPACK,SVDELEMENTAL,SVDPRIMME,"");CHKERRQ(ierr);
   if (!isshell) {
     ierr = PetscViewerPushFormat(viewer,PETSC_VIEWER_ASCII_INFO);CHKERRQ(ierr);
     if (!svd->V) { ierr = SVDGetBV(svd,&svd->V,NULL);CHKERRQ(ierr); }
@@ -130,7 +130,7 @@ PetscErrorCode SVDViewFromOptions(SVD svd,PetscObject obj,const char name[])
 }
 
 /*@C
-   SVDReasonView - Displays the reason an SVD solve converged or diverged.
+   SVDConvergedReasonView - Displays the reason an SVD solve converged or diverged.
 
    Collective on svd
 
@@ -141,22 +141,31 @@ PetscErrorCode SVDViewFromOptions(SVD svd,PetscObject obj,const char name[])
    Options Database Keys:
 .  -svd_converged_reason - print reason for convergence, and number of iterations
 
+   Note:
+   To change the format of the output call PetscViewerPushFormat(viewer,format) before
+   this call. Use PETSC_VIEWER_DEFAULT for the default, use PETSC_VIEWER_FAILED to only
+   display a reason if it fails. The latter can be set in the command line with
+   -svd_converged_reason ::failed
+
    Level: intermediate
 
-.seealso: SVDSetTolerances(), SVDGetIterationNumber()
+.seealso: SVDSetTolerances(), SVDGetIterationNumber(), SVDConvergedReasonViewFromOptions()
 @*/
-PetscErrorCode SVDReasonView(SVD svd,PetscViewer viewer)
+PetscErrorCode SVDConvergedReasonView(SVD svd,PetscViewer viewer)
 {
-  PetscErrorCode ierr;
-  PetscBool      isAscii;
+  PetscErrorCode    ierr;
+  PetscBool         isAscii;
+  PetscViewerFormat format;
 
   PetscFunctionBegin;
+  if (!viewer) viewer = PETSC_VIEWER_STDOUT_(PetscObjectComm((PetscObject)svd));
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isAscii);CHKERRQ(ierr);
   if (isAscii) {
+    ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
     ierr = PetscViewerASCIIAddTab(viewer,((PetscObject)svd)->tablevel);CHKERRQ(ierr);
-    if (svd->reason > 0) {
+    if (svd->reason > 0 && format != PETSC_VIEWER_FAILED) {
       ierr = PetscViewerASCIIPrintf(viewer,"%s SVD solve converged (%D singular triplet%s) due to %s; iterations %D\n",((PetscObject)svd)->prefix?((PetscObject)svd)->prefix:"",svd->nconv,(svd->nconv>1)?"s":"",SVDConvergedReasons[svd->reason],svd->its);CHKERRQ(ierr);
-    } else {
+    } else if (svd->reason <= 0) {
       ierr = PetscViewerASCIIPrintf(viewer,"%s SVD solve did not converge due to %s; iterations %D\n",((PetscObject)svd)->prefix?((PetscObject)svd)->prefix:"",SVDConvergedReasons[svd->reason],svd->its);CHKERRQ(ierr);
     }
     ierr = PetscViewerASCIISubtractTab(viewer,((PetscObject)svd)->tablevel);CHKERRQ(ierr);
@@ -165,7 +174,7 @@ PetscErrorCode SVDReasonView(SVD svd,PetscViewer viewer)
 }
 
 /*@
-   SVDReasonViewFromOptions - Processes command line options to determine if/how
+   SVDConvergedReasonViewFromOptions - Processes command line options to determine if/how
    the SVD converged reason is to be viewed.
 
    Collective on svd
@@ -174,8 +183,10 @@ PetscErrorCode SVDReasonView(SVD svd,PetscViewer viewer)
 .  svd - the singular value solver context
 
    Level: developer
+
+.seealso: SVDConvergedReasonView()
 @*/
-PetscErrorCode SVDReasonViewFromOptions(SVD svd)
+PetscErrorCode SVDConvergedReasonViewFromOptions(SVD svd)
 {
   PetscErrorCode    ierr;
   PetscViewer       viewer;
@@ -189,7 +200,7 @@ PetscErrorCode SVDReasonViewFromOptions(SVD svd)
   ierr = PetscOptionsGetViewer(PetscObjectComm((PetscObject)svd),((PetscObject)svd)->options,((PetscObject)svd)->prefix,"-svd_converged_reason",&viewer,&format,&flg);CHKERRQ(ierr);
   if (flg) {
     ierr = PetscViewerPushFormat(viewer,format);CHKERRQ(ierr);
-    ierr = SVDReasonView(svd,viewer);CHKERRQ(ierr);
+    ierr = SVDConvergedReasonView(svd,viewer);CHKERRQ(ierr);
     ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
     ierr = PetscViewerDestroy(&viewer);CHKERRQ(ierr);
   }
@@ -233,17 +244,16 @@ static PetscErrorCode SVDErrorView_DETAIL(SVD svd,SVDErrorType etype,PetscViewer
   PetscErrorCode ierr;
   PetscReal      error,sigma;
   PetscInt       i;
-#define EXLEN 30
-  char           ex[EXLEN],sep[]=" ---------------------- --------------------\n";
+  char           ex[30],sep[]=" ---------------------- --------------------\n";
 
   PetscFunctionBegin;
   if (!svd->nconv) PetscFunctionReturn(0);
   switch (etype) {
     case SVD_ERROR_ABSOLUTE:
-      ierr = PetscSNPrintf(ex,EXLEN," absolute error");CHKERRQ(ierr);
+      ierr = PetscSNPrintf(ex,sizeof(ex)," absolute error");CHKERRQ(ierr);
       break;
     case SVD_ERROR_RELATIVE:
-      ierr = PetscSNPrintf(ex,EXLEN," relative error");CHKERRQ(ierr);
+      ierr = PetscSNPrintf(ex,sizeof(ex)," relative error");CHKERRQ(ierr);
       break;
   }
   ierr = PetscViewerASCIIPrintf(viewer,"%s          sigma           %s\n%s",sep,ex,sep);CHKERRQ(ierr);
@@ -397,6 +407,23 @@ static PetscErrorCode SVDValuesView_DRAW(SVD svd,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
+static PetscErrorCode SVDValuesView_BINARY(SVD svd,PetscViewer viewer)
+{
+  PetscInt       i,k;
+  PetscReal      *sv;
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  ierr = PetscMalloc1(svd->nconv,&sv);CHKERRQ(ierr);
+  for (i=0;i<svd->nconv;i++) {
+    k = svd->perm[i];
+    sv[i] = svd->sigma[k];
+  }
+  ierr = PetscViewerBinaryWrite(viewer,sv,svd->nconv,PETSC_REAL);CHKERRQ(ierr);
+  ierr = PetscFree(sv);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 static PetscErrorCode SVDValuesView_ASCII(SVD svd,PetscViewer viewer)
 {
   PetscInt       i;
@@ -445,7 +472,7 @@ static PetscErrorCode SVDValuesView_MATLAB(SVD svd,PetscViewer viewer)
 @*/
 PetscErrorCode SVDValuesView(SVD svd,PetscViewer viewer)
 {
-  PetscBool         isascii,isdraw;
+  PetscBool         isascii,isdraw,isbinary;
   PetscViewerFormat format;
   PetscErrorCode    ierr;
 
@@ -458,9 +485,12 @@ PetscErrorCode SVDValuesView(SVD svd,PetscViewer viewer)
   PetscCheckSameComm(svd,1,viewer,2);
   SVDCheckSolved(svd,1);
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERDRAW,&isdraw);CHKERRQ(ierr);
+  ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERBINARY,&isbinary);CHKERRQ(ierr);
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
   if (isdraw) {
     ierr = SVDValuesView_DRAW(svd,viewer);CHKERRQ(ierr);
+  } else if (isbinary) {
+    ierr = SVDValuesView_BINARY(svd,viewer);CHKERRQ(ierr);
   } else if (isascii) {
     ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
     switch (format) {
@@ -537,8 +567,7 @@ PetscErrorCode SVDVectorsView(SVD svd,PetscViewer viewer)
   PetscErrorCode ierr;
   PetscInt       i,k;
   Vec            x;
-#define NMLEN 30
-  char           vname[NMLEN];
+  char           vname[30];
   const char     *ename;
 
   PetscFunctionBegin;
@@ -554,12 +583,12 @@ PetscErrorCode SVDVectorsView(SVD svd,PetscViewer viewer)
     ierr = SVDComputeVectors(svd);CHKERRQ(ierr);
     for (i=0;i<svd->nconv;i++) {
       k = svd->perm[i];
-      ierr = PetscSNPrintf(vname,NMLEN,"V%d_%s",(int)i,ename);CHKERRQ(ierr);
+      ierr = PetscSNPrintf(vname,sizeof(vname),"V%d_%s",(int)i,ename);CHKERRQ(ierr);
       ierr = BVGetColumn(svd->V,k,&x);CHKERRQ(ierr);
       ierr = PetscObjectSetName((PetscObject)x,vname);CHKERRQ(ierr);
       ierr = VecView(x,viewer);CHKERRQ(ierr);
       ierr = BVRestoreColumn(svd->V,k,&x);CHKERRQ(ierr);
-      ierr = PetscSNPrintf(vname,NMLEN,"U%d_%s",(int)i,ename);CHKERRQ(ierr);
+      ierr = PetscSNPrintf(vname,sizeof(vname),"U%d_%s",(int)i,ename);CHKERRQ(ierr);
       ierr = BVGetColumn(svd->U,k,&x);CHKERRQ(ierr);
       ierr = PetscObjectSetName((PetscObject)x,vname);CHKERRQ(ierr);
       ierr = VecView(x,viewer);CHKERRQ(ierr);
