@@ -179,17 +179,27 @@ PetscErrorCode BVNorm_Local_Contiguous(BV bv,PetscInt j,NormType type,PetscReal
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode BVNormalize_Contiguous(BV bv,PetscScalar *eigi)
+{
+  PetscErrorCode ierr;
+  BV_CONTIGUOUS  *ctx = (BV_CONTIGUOUS*)bv->data;
+  PetscScalar    *wi=NULL;
+
+  PetscFunctionBegin;
+  if (eigi) wi = eigi+bv->l;
+  ierr = BVNormalize_LAPACK_Private(bv,bv->n,bv->k-bv->l,ctx->array+(bv->nc+bv->l)*bv->n,wi,ctx->mpi);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode BVMatMult_Contiguous(BV V,Mat A,BV W)
 {
   PetscErrorCode ierr;
   BV_CONTIGUOUS  *v = (BV_CONTIGUOUS*)V->data,*w = (BV_CONTIGUOUS*)W->data;
   PetscInt       j;
-  PetscBool      flg;
   Mat            Vmat,Wmat;
 
   PetscFunctionBegin;
-  ierr = MatHasOperation(A,MATOP_MAT_MULT,&flg);CHKERRQ(ierr);
-  if (V->vmm && flg) {
+  if (V->vmm) {
     ierr = BVGetMat(V,&Vmat);CHKERRQ(ierr);
     ierr = BVGetMat(W,&Wmat);CHKERRQ(ierr);
     ierr = MatProductCreateWithMat(A,Vmat,NULL,Wmat);CHKERRQ(ierr);
@@ -235,45 +245,37 @@ PetscErrorCode BVResize_Contiguous(BV bv,PetscInt m,PetscBool copy)
 {
   PetscErrorCode ierr;
   BV_CONTIGUOUS  *ctx = (BV_CONTIGUOUS*)bv->data;
-  PetscInt       j,bs,lsplit;
+  PetscInt       j,bs;
   PetscScalar    *newarray;
   Vec            *newV;
   char           str[50];
-  BV             parent;
 
   PetscFunctionBegin;
-  if (bv->issplit==2) {
-    parent = bv->splitparent;
-    lsplit = parent->lsplit;
-    ctx->V = ((BV_CONTIGUOUS*)parent->data)->V+lsplit;
-    ctx->array = ((BV_CONTIGUOUS*)parent->data)->array+lsplit*bv->n;
-  } else if (!bv->issplit) {
-    ierr = VecGetBlockSize(bv->t,&bs);CHKERRQ(ierr);
-    ierr = PetscMalloc1(m*bv->n,&newarray);CHKERRQ(ierr);
-    ierr = PetscArrayzero(newarray,m*bv->n);CHKERRQ(ierr);
-    ierr = PetscMalloc1(m,&newV);CHKERRQ(ierr);
-    for (j=0;j<m;j++) {
-      if (ctx->mpi) {
-        ierr = VecCreateMPIWithArray(PetscObjectComm((PetscObject)bv->t),bs,bv->n,PETSC_DECIDE,newarray+j*bv->n,newV+j);CHKERRQ(ierr);
-      } else {
-        ierr = VecCreateSeqWithArray(PetscObjectComm((PetscObject)bv->t),bs,bv->n,newarray+j*bv->n,newV+j);CHKERRQ(ierr);
-      }
+  ierr = VecGetBlockSize(bv->t,&bs);CHKERRQ(ierr);
+  ierr = PetscMalloc1(m*bv->n,&newarray);CHKERRQ(ierr);
+  ierr = PetscArrayzero(newarray,m*bv->n);CHKERRQ(ierr);
+  ierr = PetscMalloc1(m,&newV);CHKERRQ(ierr);
+  for (j=0;j<m;j++) {
+    if (ctx->mpi) {
+      ierr = VecCreateMPIWithArray(PetscObjectComm((PetscObject)bv->t),bs,bv->n,PETSC_DECIDE,newarray+j*bv->n,newV+j);CHKERRQ(ierr);
+    } else {
+      ierr = VecCreateSeqWithArray(PetscObjectComm((PetscObject)bv->t),bs,bv->n,newarray+j*bv->n,newV+j);CHKERRQ(ierr);
     }
-    ierr = PetscLogObjectParents(bv,m,newV);CHKERRQ(ierr);
-    if (((PetscObject)bv)->name) {
-      for (j=0;j<m;j++) {
-        ierr = PetscSNPrintf(str,50,"%s_%d",((PetscObject)bv)->name,(int)j);CHKERRQ(ierr);
-        ierr = PetscObjectSetName((PetscObject)newV[j],str);CHKERRQ(ierr);
-      }
-    }
-    if (copy) {
-      ierr = PetscArraycpy(newarray,ctx->array,PetscMin(m,bv->m)*bv->n);CHKERRQ(ierr);
-    }
-    ierr = VecDestroyVecs(bv->m,&ctx->V);CHKERRQ(ierr);
-    ctx->V = newV;
-    ierr = PetscFree(ctx->array);CHKERRQ(ierr);
-    ctx->array = newarray;
   }
+  ierr = PetscLogObjectParents(bv,m,newV);CHKERRQ(ierr);
+  if (((PetscObject)bv)->name) {
+    for (j=0;j<m;j++) {
+      ierr = PetscSNPrintf(str,sizeof(str),"%s_%d",((PetscObject)bv)->name,(int)j);CHKERRQ(ierr);
+      ierr = PetscObjectSetName((PetscObject)newV[j],str);CHKERRQ(ierr);
+    }
+  }
+  if (copy) {
+    ierr = PetscArraycpy(newarray,ctx->array,PetscMin(m,bv->m)*bv->n);CHKERRQ(ierr);
+  }
+  ierr = VecDestroyVecs(bv->m,&ctx->V);CHKERRQ(ierr);
+  ctx->V = newV;
+  ierr = PetscFree(ctx->array);CHKERRQ(ierr);
+  ctx->array = newarray;
   PetscFunctionReturn(0);
 }
 
@@ -368,7 +370,7 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Contiguous(BV bv)
   }
   if (((PetscObject)bv)->name) {
     for (j=0;j<bv->m;j++) {
-      ierr = PetscSNPrintf(str,50,"%s_%d",((PetscObject)bv)->name,(int)j);CHKERRQ(ierr);
+      ierr = PetscSNPrintf(str,sizeof(str),"%s_%d",((PetscObject)bv)->name,(int)j);CHKERRQ(ierr);
       ierr = PetscObjectSetName((PetscObject)ctx->V[j],str);CHKERRQ(ierr);
     }
   }
@@ -390,6 +392,7 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Contiguous(BV bv)
   bv->ops->scale            = BVScale_Contiguous;
   bv->ops->norm             = BVNorm_Contiguous;
   bv->ops->norm_local       = BVNorm_Local_Contiguous;
+  bv->ops->normalize        = BVNormalize_Contiguous;
   bv->ops->matmult          = BVMatMult_Contiguous;
   bv->ops->copy             = BVCopy_Contiguous;
   bv->ops->copycolumn       = BVCopyColumn_Contiguous;
