@@ -203,17 +203,29 @@ PetscErrorCode BVNorm_Local_Svec(BV bv,PetscInt j,NormType type,PetscReal *val)
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode BVNormalize_Svec(BV bv,PetscScalar *eigi)
+{
+  PetscErrorCode ierr;
+  BV_SVEC        *ctx = (BV_SVEC*)bv->data;
+  PetscScalar    *array,*wi=NULL;
+
+  PetscFunctionBegin;
+  ierr = VecGetArray(ctx->v,&array);CHKERRQ(ierr);
+  if (eigi) wi = eigi+bv->l;
+  ierr = BVNormalize_LAPACK_Private(bv,bv->n,bv->k-bv->l,array+(bv->nc+bv->l)*bv->n,wi,ctx->mpi);CHKERRQ(ierr);
+  ierr = VecRestoreArray(ctx->v,&array);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode BVMatMult_Svec(BV V,Mat A,BV W)
 {
   PetscErrorCode ierr;
   PetscInt       j;
-  PetscBool      flg;
   Mat            Vmat,Wmat;
   Vec            vv,ww;
 
   PetscFunctionBegin;
-  ierr = MatHasOperation(A,MATOP_MAT_MULT,&flg);CHKERRQ(ierr);
-  if (V->vmm && flg) {
+  if (V->vmm) {
     ierr = BVGetMat(V,&Vmat);CHKERRQ(ierr);
     ierr = BVGetMat(W,&Wmat);CHKERRQ(ierr);
     ierr = MatProductCreateWithMat(A,Vmat,NULL,Wmat);CHKERRQ(ierr);
@@ -272,41 +284,30 @@ PetscErrorCode BVResize_Svec(BV bv,PetscInt m,PetscBool copy)
   BV_SVEC           *ctx = (BV_SVEC*)bv->data;
   PetscScalar       *pnew;
   const PetscScalar *pv;
-  PetscInt          bs,lsplit;
-  Vec               vnew,vpar;
+  PetscInt          bs;
+  Vec               vnew;
   char              str[50];
-  BV                parent;
 
   PetscFunctionBegin;
-  if (bv->issplit==2) {
-    parent = bv->splitparent;
-    lsplit = parent->lsplit;
-    vpar = ((BV_SVEC*)parent->data)->v;
-    ierr = VecGetArrayRead(vpar,&pv);CHKERRQ(ierr);
-    ierr = VecResetArray(ctx->v);CHKERRQ(ierr);
-    ierr = VecPlaceArray(ctx->v,pv+lsplit*bv->n);CHKERRQ(ierr);
-    ierr = VecRestoreArrayRead(vpar,&pv);CHKERRQ(ierr);
-  } else if (!bv->issplit) {
-    ierr = VecGetBlockSize(bv->t,&bs);CHKERRQ(ierr);
-    ierr = VecCreate(PetscObjectComm((PetscObject)bv->t),&vnew);CHKERRQ(ierr);
-    ierr = VecSetType(vnew,((PetscObject)bv->t)->type_name);CHKERRQ(ierr);
-    ierr = VecSetSizes(vnew,m*bv->n,PETSC_DECIDE);CHKERRQ(ierr);
-    ierr = VecSetBlockSize(vnew,bs);CHKERRQ(ierr);
-    ierr = PetscLogObjectParent((PetscObject)bv,(PetscObject)vnew);CHKERRQ(ierr);
-    if (((PetscObject)bv)->name) {
-      ierr = PetscSNPrintf(str,50,"%s_0",((PetscObject)bv)->name);CHKERRQ(ierr);
-      ierr = PetscObjectSetName((PetscObject)vnew,str);CHKERRQ(ierr);
-    }
-    if (copy) {
-      ierr = VecGetArrayRead(ctx->v,&pv);CHKERRQ(ierr);
-      ierr = VecGetArray(vnew,&pnew);CHKERRQ(ierr);
-      ierr = PetscArraycpy(pnew,pv,PetscMin(m,bv->m)*bv->n);CHKERRQ(ierr);
-      ierr = VecRestoreArrayRead(ctx->v,&pv);CHKERRQ(ierr);
-      ierr = VecRestoreArray(vnew,&pnew);CHKERRQ(ierr);
-    }
-    ierr = VecDestroy(&ctx->v);CHKERRQ(ierr);
-    ctx->v = vnew;
+  ierr = VecGetBlockSize(bv->t,&bs);CHKERRQ(ierr);
+  ierr = VecCreate(PetscObjectComm((PetscObject)bv->t),&vnew);CHKERRQ(ierr);
+  ierr = VecSetType(vnew,((PetscObject)bv->t)->type_name);CHKERRQ(ierr);
+  ierr = VecSetSizes(vnew,m*bv->n,PETSC_DECIDE);CHKERRQ(ierr);
+  ierr = VecSetBlockSize(vnew,bs);CHKERRQ(ierr);
+  ierr = PetscLogObjectParent((PetscObject)bv,(PetscObject)vnew);CHKERRQ(ierr);
+  if (((PetscObject)bv)->name) {
+    ierr = PetscSNPrintf(str,sizeof(str),"%s_0",((PetscObject)bv)->name);CHKERRQ(ierr);
+    ierr = PetscObjectSetName((PetscObject)vnew,str);CHKERRQ(ierr);
   }
+  if (copy) {
+    ierr = VecGetArrayRead(ctx->v,&pv);CHKERRQ(ierr);
+    ierr = VecGetArray(vnew,&pnew);CHKERRQ(ierr);
+    ierr = PetscArraycpy(pnew,pv,PetscMin(m,bv->m)*bv->n);CHKERRQ(ierr);
+    ierr = VecRestoreArrayRead(ctx->v,&pv);CHKERRQ(ierr);
+    ierr = VecRestoreArray(vnew,&pnew);CHKERRQ(ierr);
+  }
+  ierr = VecDestroy(&ctx->v);CHKERRQ(ierr);
+  ctx->v = vnew;
   PetscFunctionReturn(0);
 }
 
@@ -487,7 +488,7 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Svec(BV bv)
   }
   ierr = PetscLogObjectParent((PetscObject)bv,(PetscObject)ctx->v);CHKERRQ(ierr);
   if (((PetscObject)bv)->name) {
-    ierr = PetscSNPrintf(str,50,"%s_0",((PetscObject)bv)->name);CHKERRQ(ierr);
+    ierr = PetscSNPrintf(str,sizeof(str),"%s_0",((PetscObject)bv)->name);CHKERRQ(ierr);
     ierr = PetscObjectSetName((PetscObject)ctx->v,str);CHKERRQ(ierr);
   }
 
@@ -520,6 +521,8 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Svec(BV bv)
     bv->ops->getcolumn        = BVGetColumn_Svec_CUDA;
     bv->ops->restorecolumn    = BVRestoreColumn_Svec_CUDA;
     bv->ops->restoresplit     = BVRestoreSplit_Svec_CUDA;
+    bv->ops->getmat           = BVGetMat_Svec_CUDA;
+    bv->ops->restoremat       = BVRestoreMat_Svec_CUDA;
 #endif
   } else {
     bv->ops->mult             = BVMult_Svec;
@@ -539,6 +542,7 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Svec(BV bv)
   }
   bv->ops->norm             = BVNorm_Svec;
   bv->ops->norm_local       = BVNorm_Local_Svec;
+  bv->ops->normalize        = BVNormalize_Svec;
   bv->ops->getarray         = BVGetArray_Svec;
   bv->ops->restorearray     = BVRestoreArray_Svec;
   bv->ops->getarrayread     = BVGetArrayRead_Svec;
