@@ -295,12 +295,10 @@ PetscErrorCode BVMatMult_Vecs(BV V,Mat A,BV W)
   PetscErrorCode ierr;
   BV_VECS        *v = (BV_VECS*)V->data,*w = (BV_VECS*)W->data;
   PetscInt       j;
-  PetscBool      flg;
   Mat            Vmat,Wmat;
 
   PetscFunctionBegin;
-  ierr = MatHasOperation(A,MATOP_MAT_MULT,&flg);CHKERRQ(ierr);
-  if (V->vmm && flg) {
+  if (V->vmm) {
     ierr = BVGetMat(V,&Vmat);CHKERRQ(ierr);
     ierr = BVGetMat(W,&Wmat);CHKERRQ(ierr);
     ierr = MatProductCreateWithMat(A,Vmat,NULL,Wmat);CHKERRQ(ierr);
@@ -347,32 +345,25 @@ PetscErrorCode BVResize_Vecs(BV bv,PetscInt m,PetscBool copy)
   PetscErrorCode ierr;
   BV_VECS        *ctx = (BV_VECS*)bv->data;
   Vec            *newV;
-  PetscInt       j,lsplit;
+  PetscInt       j;
   char           str[50];
-  BV             parent;
 
   PetscFunctionBegin;
-  if (bv->issplit==2) {
-    parent = bv->splitparent;
-    lsplit = parent->lsplit;
-    ctx->V = ((BV_VECS*)parent->data)->V+lsplit;
-  } else if (!bv->issplit) {
-    ierr = VecDuplicateVecs(bv->t,m,&newV);CHKERRQ(ierr);
-    ierr = PetscLogObjectParents(bv,m,newV);CHKERRQ(ierr);
-    if (((PetscObject)bv)->name) {
-      for (j=0;j<m;j++) {
-        ierr = PetscSNPrintf(str,50,"%s_%D",((PetscObject)bv)->name,j);CHKERRQ(ierr);
-        ierr = PetscObjectSetName((PetscObject)newV[j],str);CHKERRQ(ierr);
-      }
+  ierr = VecDuplicateVecs(bv->t,m,&newV);CHKERRQ(ierr);
+  ierr = PetscLogObjectParents(bv,m,newV);CHKERRQ(ierr);
+  if (((PetscObject)bv)->name) {
+    for (j=0;j<m;j++) {
+      ierr = PetscSNPrintf(str,sizeof(str),"%s_%D",((PetscObject)bv)->name,j);CHKERRQ(ierr);
+      ierr = PetscObjectSetName((PetscObject)newV[j],str);CHKERRQ(ierr);
     }
-    if (copy) {
-      for (j=0;j<PetscMin(m,bv->m);j++) {
-        ierr = VecCopy(ctx->V[j],newV[j]);CHKERRQ(ierr);
-      }
-    }
-    ierr = VecDestroyVecs(bv->m,&ctx->V);CHKERRQ(ierr);
-    ctx->V = newV;
   }
+  if (copy) {
+    for (j=0;j<PetscMin(m,bv->m);j++) {
+      ierr = VecCopy(ctx->V[j],newV[j]);CHKERRQ(ierr);
+    }
+  }
+  ierr = VecDestroyVecs(bv->m,&ctx->V);CHKERRQ(ierr);
+  ctx->V = newV;
   PetscFunctionReturn(0);
 }
 
@@ -554,7 +545,7 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Vecs(BV bv)
     ierr = PetscLogObjectParents(bv,bv->m,ctx->V);CHKERRQ(ierr);
     if (((PetscObject)bv)->name) {
       for (j=0;j<bv->m;j++) {
-        ierr = PetscSNPrintf(str,50,"%s_%D",((PetscObject)bv)->name,j);CHKERRQ(ierr);
+        ierr = PetscSNPrintf(str,sizeof(str),"%s_%D",((PetscObject)bv)->name,j);CHKERRQ(ierr);
         ierr = PetscObjectSetName((PetscObject)ctx->V[j],str);CHKERRQ(ierr);
       }
     }
