@@ -14,9 +14,9 @@
 #include <slepc/private/bvimpl.h>            /*I "slepcbv.h" I*/
 
 PetscClassId     BV_CLASSID = 0;
-PetscLogEvent    BV_Create = 0,BV_Copy = 0,BV_Mult = 0,BV_MultVec = 0,BV_MultInPlace = 0,BV_Dot = 0,BV_DotVec = 0,BV_Orthogonalize = 0,BV_OrthogonalizeVec = 0,BV_Scale = 0,BV_Norm = 0,BV_NormVec = 0,BV_SetRandom = 0,BV_MatMult = 0,BV_MatMultVec = 0,BV_MatProject = 0;
+PetscLogEvent    BV_Create = 0,BV_Copy = 0,BV_Mult = 0,BV_MultVec = 0,BV_MultInPlace = 0,BV_Dot = 0,BV_DotVec = 0,BV_Orthogonalize = 0,BV_OrthogonalizeVec = 0,BV_Scale = 0,BV_Norm = 0,BV_NormVec = 0,BV_Normalize = 0,BV_SetRandom = 0,BV_MatMult = 0,BV_MatMultVec = 0,BV_MatProject = 0;
 static PetscBool BVPackageInitialized = PETSC_FALSE;
-MPI_Op MPIU_TSQR = 0;
+MPI_Op MPIU_TSQR = 0,MPIU_LAPY2;
 
 const char *BVOrthogTypes[] = {"CGS","MGS","BVOrthogType","BV_ORTHOG_",0};
 const char *BVOrthogRefineTypes[] = {"IFNEEDED","NEVER","ALWAYS","BVOrthogRefineType","BV_ORTHOG_REFINE_",0};
@@ -38,6 +38,7 @@ PetscErrorCode BVFinalizePackage(void)
   PetscFunctionBegin;
   ierr = PetscFunctionListDestroy(&BVList);CHKERRQ(ierr);
   ierr = MPI_Op_free(&MPIU_TSQR);CHKERRQ(ierr);
+  ierr = MPI_Op_free(&MPIU_LAPY2);CHKERRQ(ierr);
   BVPackageInitialized = PETSC_FALSE;
   BVRegisterAllCalled  = PETSC_FALSE;
   PetscFunctionReturn(0);
@@ -79,12 +80,14 @@ PetscErrorCode BVInitializePackage(void)
   ierr = PetscLogEventRegister("BVScale",BV_CLASSID,&BV_Scale);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("BVNorm",BV_CLASSID,&BV_Norm);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("BVNormVec",BV_CLASSID,&BV_NormVec);CHKERRQ(ierr);
+  ierr = PetscLogEventRegister("BVNormalize",BV_CLASSID,&BV_Normalize);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("BVSetRandom",BV_CLASSID,&BV_SetRandom);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("BVMatMult",BV_CLASSID,&BV_MatMult);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("BVMatMultVec",BV_CLASSID,&BV_MatMultVec);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("BVMatProject",BV_CLASSID,&BV_MatProject);CHKERRQ(ierr);
   /* MPI reduction operation used in BVOrthogonalize */
   ierr = MPI_Op_create(SlepcGivensPacked,PETSC_FALSE,&MPIU_TSQR);CHKERRQ(ierr);
+  ierr = MPI_Op_create(SlepcPythag,PETSC_TRUE,&MPIU_LAPY2);CHKERRQ(ierr);
   /* Process Info */
   classids[0] = BV_CLASSID;
   ierr = PetscInfoProcessClass("bv",1,&classids[0]);CHKERRQ(ierr);
