@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -103,8 +103,8 @@ PetscErrorCode BDC_dsrtdf_(PetscBLASInt *k,PetscBLASInt n,PetscBLASInt n1,
 /*         which will be passed to DLAED3M. */
 
 /*  Q2     (output) DOUBLE PRECISION array, dimension */
-/*         ( N*N ) (if everything is deflated) or */
-/*         ( N1*(COLTYP(1)+COLTYP(2)) + (N-N1)*(COLTYP(2)+COLTYP(3)) ) */
+/*         (N*N) (if everything is deflated) or */
+/*         (N1*(COLTYP(1)+COLTYP(2)) + (N-N1)*(COLTYP(2)+COLTYP(3))) */
 /*         (if not everything is deflated) */
 /*         If everything is deflated, then N*N intermediate workspace */
 /*         is needed in Q2. */
@@ -170,10 +170,6 @@ PetscErrorCode BDC_dsrtdf_(PetscBLASInt *k,PetscBLASInt n,PetscBLASInt n1,
 
 /*  ===================================================================== */
 
-#if defined(SLEPC_MISSING_LAPACK_LAMRG) || defined(SLEPC_MISSING_LAPACK_LACPY)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"LAMRG/LACPY - Lapack routine is unavailable");
-#else
   PetscReal    c, s, t, eps, tau, tol, dmax, dmone = -1.;
   PetscBLASInt i, j, i1, k2, n2, ct, nj, pj=0, js, iq1, iq2;
   PetscBLASInt psm[4], imax, jmax, ctot[4], factmp=1, one=1;
@@ -278,7 +274,7 @@ PetscErrorCode BDC_dsrtdf_(PetscBLASInt *k,PetscBLASInt n,PetscBLASInt n1,
       dlamda[j] = d[i-1];
       iq2 += n;
     }
-    PetscStackCallBLAS("LAPACKlacpy",LAPACKlacpy_("A", &n, &n, q2, &n, q, &ldq));
+    for (j=0;j<n;j++) for (i=0;i<n;i++) q[i+j*ldq] = q2[i+j*n];
     PetscStackCallBLAS("BLAScopy",BLAScopy_(&n, dlamda, &one, d, &one));
     PetscFunctionReturn(0);
   }
@@ -340,7 +336,7 @@ L80:
     /* Find sqrt(a**2+b**2) without overflow or */
     /* destructive underflow. */
 
-    tau = LAPACKlapy2_(&c, &s);
+    tau = SlepcAbs(c, s);
     t = d[nj] - d[pj];
     c /= tau;
     s = -s / tau;
@@ -484,7 +480,7 @@ L100:
   /* The deflated eigenvalues and their corresponding vectors go back */
   /* into the last N - K slots of D and Q respectively. */
 
-  PetscStackCallBLAS("LAPACKlacpy",LAPACKlacpy_("A", &n, &ctot[3], &q2[iq1], &n, &q[*k*ldq], &ldq));
+  for (j=0;j<ctot[3];j++) for (i=0;i<n;i++) q[i+(j+*k)*ldq] = q2[iq1+i+j*n];
   i1 = n - *k;
   PetscStackCallBLAS("BLAScopy",BLAScopy_(&i1, &z[*k], &one, &d[*k], &one));
 
@@ -492,6 +488,5 @@ L100:
 
   for (j = 0; j < 4; ++j) coltyp[j] = ctot[j];
   PetscFunctionReturn(0);
-#endif
 }
 
