@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -171,7 +171,6 @@ PetscErrorCode DSVectors_HEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
     case DS_MAT_U:
     case DS_MAT_VT:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented yet");
-      break;
     default:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Invalid mat parameter");
   }
@@ -227,10 +226,6 @@ PetscErrorCode DSVectors_HEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
 */
 static PetscErrorCode ArrowTridiag(PetscBLASInt n,PetscReal *d,PetscReal *e,PetscScalar *Q,PetscBLASInt ld)
 {
-#if defined(SLEPC_MISSING_LAPACK_LARTG)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"LARTG - Lapack routine is unavailable");
-#else
   PetscBLASInt i,j,j2,one=1;
   PetscReal    c,s,p,off,temp;
 
@@ -271,7 +266,6 @@ static PetscErrorCode ArrowTridiag(PetscBLASInt n,PetscReal *d,PetscReal *e,Pets
     }
   }
   PetscFunctionReturn(0);
-#endif
 }
 
 /*
@@ -279,13 +273,9 @@ static PetscErrorCode ArrowTridiag(PetscBLASInt n,PetscReal *d,PetscReal *e,Pets
 */
 static PetscErrorCode DSIntermediate_HEP(DS ds)
 {
-#if defined(SLEPC_MISSING_LAPACK_SYTRD) || defined(SLEPC_MISSING_LAPACK_ORGTR)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"SYTRD/ORGTR - Lapack routine is unavailable");
-#else
   PetscErrorCode ierr;
   PetscInt       i;
-  PetscBLASInt   n1,n2,n3,lwork,info,l,n,ld,off;
+  PetscBLASInt   n1 = 0,n2,lwork,info,l = 0,n = 0,ld,off;
   PetscScalar    *A,*Q,*work,*tau;
   PetscReal      *d,*e;
 
@@ -293,9 +283,8 @@ static PetscErrorCode DSIntermediate_HEP(DS ds)
   ierr = PetscBLASIntCast(ds->n,&n);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(ds->l,&l);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(ds->ld,&ld);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ds->k-l+1,&n1);CHKERRQ(ierr); /* size of leading block, excl. locked */
-  ierr = PetscBLASIntCast(n-ds->k-1,&n2);CHKERRQ(ierr); /* size of trailing block */
-  n3 = n1+n2;
+  ierr = PetscBLASIntCast(PetscMax(0,ds->k-l+1),&n1);CHKERRQ(ierr); /* size of leading block, excl. locked */
+  n2 = n-l;     /* n2 = n1 + size of trailing block */
   off = l+l*ld;
   A  = ds->mat[DS_MAT_A];
   Q  = ds->mat[DS_MAT_Q];
@@ -318,9 +307,9 @@ static PetscErrorCode DSIntermediate_HEP(DS ds)
       tau  = ds->work;
       work = ds->work+ld;
       lwork = ld*ld;
-      PetscStackCallBLAS("LAPACKsytrd",LAPACKsytrd_("L",&n3,Q+off,&ld,d+l,e+l,tau,work,&lwork,&info));
+      PetscStackCallBLAS("LAPACKsytrd",LAPACKsytrd_("L",&n2,Q+off,&ld,d+l,e+l,tau,work,&lwork,&info));
       SlepcCheckLapackInfo("sytrd",info);
-      PetscStackCallBLAS("LAPACKorgtr",LAPACKorgtr_("L",&n3,Q+off,&ld,tau,work,&lwork,&info));
+      PetscStackCallBLAS("LAPACKorgtr",LAPACKorgtr_("L",&n2,Q+off,&ld,tau,work,&lwork,&info));
       SlepcCheckLapackInfo("orgtr",info);
     } else {
       /* copy tridiagonal to d,e */
@@ -329,7 +318,6 @@ static PetscErrorCode DSIntermediate_HEP(DS ds)
     }
   }
   PetscFunctionReturn(0);
-#endif
 }
 
 PetscErrorCode DSSort_HEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,PetscScalar *ri,PetscInt *k)
@@ -393,13 +381,9 @@ PetscErrorCode DSUpdateExtraRow_HEP(DS ds)
 
 PetscErrorCode DSSolve_HEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
-#if defined(PETSC_MISSING_LAPACK_STEQR)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"STEQR - Lapack routine is unavailable");
-#else
   PetscErrorCode ierr;
   PetscInt       i;
-  PetscBLASInt   n1,n2,n3,info,l,n,ld,off;
+  PetscBLASInt   n1,info,l = 0,n = 0,ld,off;
   PetscScalar    *Q,*A;
   PetscReal      *d,*e;
 
@@ -408,9 +392,7 @@ PetscErrorCode DSSolve_HEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
   ierr = PetscBLASIntCast(ds->n,&n);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(ds->l,&l);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(ds->ld,&ld);CHKERRQ(ierr);
-  ierr = PetscBLASIntCast(ds->k-l+1,&n1);CHKERRQ(ierr); /* size of leading block, excl. locked */
-  ierr = PetscBLASIntCast(n-ds->k-1,&n2);CHKERRQ(ierr); /* size of trailing block */
-  n3 = n1+n2;
+  n1 = n-l;     /* n1 = size of leading block, excl. locked + size of trailing block */
   off = l+l*ld;
   Q  = ds->mat[DS_MAT_Q];
   A  = ds->mat[DS_MAT_A];
@@ -424,7 +406,7 @@ PetscErrorCode DSSolve_HEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
   for (i=0;i<l;i++) wr[i] = d[i];
 
   ierr = DSAllocateWork_Private(ds,0,2*ld,0);CHKERRQ(ierr);
-  PetscStackCallBLAS("LAPACKsteqr",LAPACKsteqr_("V",&n3,d+l,e+l,Q+off,&ld,ds->rwork,&info));
+  PetscStackCallBLAS("LAPACKsteqr",LAPACKsteqr_("V",&n1,d+l,e+l,Q+off,&ld,ds->rwork,&info));
   SlepcCheckLapackInfo("steqr",info);
   for (i=l;i<n;i++) wr[i] = d[i];
 
@@ -441,18 +423,13 @@ PetscErrorCode DSSolve_HEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
   /* Set zero wi */
   if (wi) for (i=l;i<n;i++) wi[i] = 0.0;
   PetscFunctionReturn(0);
-#endif
 }
 
 PetscErrorCode DSSolve_HEP_MRRR(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
-#if defined(SLEPC_MISSING_LAPACK_STEVR)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"STEVR - Lapack routine is unavailable");
-#else
   PetscErrorCode ierr;
   PetscInt       i;
-  PetscBLASInt   n1,n2,n3,lwork,liwork,info,l,n,m,ld,off,il,iu,*isuppz;
+  PetscBLASInt   n1 = 0,n2 = 0,n3,lwork,liwork,info,l = 0,n = 0,m = 0,ld,off,il,iu,*isuppz;
   PetscScalar    *A,*Q,*W=NULL,one=1.0,zero=0.0;
   PetscReal      *d,*e,abstol=0.0,vl,vu;
 #if defined(PETSC_USE_COMPLEX)
@@ -524,18 +501,13 @@ PetscErrorCode DSSolve_HEP_MRRR(DS ds,PetscScalar *wr,PetscScalar *wi)
   /* Set zero wi */
   if (wi) for (i=l;i<n;i++) wi[i] = 0.0;
   PetscFunctionReturn(0);
-#endif
 }
 
 PetscErrorCode DSSolve_HEP_DC(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
-#if defined(SLEPC_MISSING_LAPACK_STEDC)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"STEDC - Lapack routine is unavailable");
-#else
   PetscErrorCode ierr;
   PetscInt       i;
-  PetscBLASInt   n1,info,l,ld,off,lrwork,liwork;
+  PetscBLASInt   n1,info,l = 0,ld,off,lrwork,liwork;
   PetscScalar    *Q,*A;
   PetscReal      *d,*e;
 #if defined(PETSC_USE_COMPLEX)
@@ -589,14 +561,13 @@ PetscErrorCode DSSolve_HEP_DC(DS ds,PetscScalar *wr,PetscScalar *wi)
   /* Set zero wi */
   if (wi) for (i=l;i<ds->n;i++) wi[i] = 0.0;
   PetscFunctionReturn(0);
-#endif
 }
 
 #if !defined(PETSC_USE_COMPLEX)
 PetscErrorCode DSSolve_HEP_BDC(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
   PetscErrorCode ierr;
-  PetscBLASInt   i,j,k,m,n,info,nblks,bs,ld,lde,lrwork,liwork,*ksizes,*iwork,mingapi;
+  PetscBLASInt   i,j,k,m,n = 0,info,nblks,bs = 0,ld = 0,lde,lrwork,liwork,*ksizes,*iwork,mingapi;
   PetscScalar    *Q,*A;
   PetscReal      *D,*E,*d,*e,tol=PETSC_MACHINE_EPSILON/2,tau1=1e-16,tau2=1e-18,*rwork,mingap;
 
@@ -662,8 +633,9 @@ PetscErrorCode DSSolve_HEP_BDC(DS ds,PetscScalar *wr,PetscScalar *wi)
 
 PetscErrorCode DSTruncate_HEP(DS ds,PetscInt n)
 {
-  PetscInt    i,ld=ds->ld,l=ds->l;
-  PetscScalar *A;
+  PetscErrorCode ierr;
+  PetscInt       i,ld=ds->ld,l=ds->l;
+  PetscScalar    *A;
 
   PetscFunctionBegin;
   if (ds->state==DS_STATE_CONDENSED) ds->t = ds->n;
@@ -674,6 +646,7 @@ PetscErrorCode DSTruncate_HEP(DS ds,PetscInt n)
   if (ds->extrarow) ds->k = n;
   else ds->k = 0;
   ds->n = n;
+  ierr = PetscInfo1(ds,"Decomposition truncated to size n=%D\n",n);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -726,10 +699,6 @@ PetscErrorCode DSSynchronize_HEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
 
 PetscErrorCode DSCond_HEP(DS ds,PetscReal *cond)
 {
-#if defined(PETSC_MISSING_LAPACK_GETRF) || defined(PETSC_MISSING_LAPACK_GETRI) || defined(SLEPC_MISSING_LAPACK_LANGE)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"GETRF/GETRI/LANGE - Lapack routines are unavailable");
-#else
   PetscErrorCode ierr;
   PetscScalar    *work;
   PetscReal      *rwork;
@@ -765,15 +734,10 @@ PetscErrorCode DSCond_HEP(DS ds,PetscReal *cond)
 
   *cond = hn*hin;
   PetscFunctionReturn(0);
-#endif
 }
 
 PetscErrorCode DSTranslateRKS_HEP(DS ds,PetscScalar alpha)
 {
-#if defined(PETSC_MISSING_LAPACK_GEQRF) || defined(PETSC_MISSING_LAPACK_ORGQR)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"GEQRF/ORGQR - Lapack routines are unavailable");
-#else
   PetscErrorCode ierr;
   PetscInt       i,j,k=ds->k;
   PetscScalar    *Q,*A,*R,*tau,*work;
@@ -822,7 +786,6 @@ PetscErrorCode DSTranslateRKS_HEP(DS ds,PetscScalar alpha)
   for (i=0;i<k;i++)
     A[ld*i+i] -= alpha;
   PetscFunctionReturn(0);
-#endif
 }
 
 PetscErrorCode DSHermitian_HEP(DS ds,DSMatType m,PetscBool *flg)
