@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -19,13 +19,13 @@
 #define dspepgetcoefficients_    dspepgetcoefficients
 #endif
 
-SLEPC_EXTERN void PETSC_STDCALL dspepsetcoefficients_(DS *ds,PetscReal *pbc,PetscErrorCode *ierr)
+SLEPC_EXTERN void dspepsetcoefficients_(DS *ds,PetscReal *pbc,PetscErrorCode *ierr)
 {
   CHKFORTRANNULLREAL(pbc);
   *ierr = DSPEPSetCoefficients(*ds,pbc);
 }
 
-SLEPC_EXTERN void PETSC_STDCALL dspepgetcoefficients_(DS *ds,PetscReal *pbc,PetscErrorCode *ierr)
+SLEPC_EXTERN void dspepgetcoefficients_(DS *ds,PetscReal *pbc,PetscErrorCode *ierr)
 {
   PetscReal *opbc;
   PetscInt  d;
