@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -56,6 +56,7 @@ PetscErrorCode DSInitializePackage()
 {
   char           logList[256];
   PetscBool      opt,pkg;
+  PetscClassId   classids[1];
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
@@ -70,12 +71,9 @@ PetscErrorCode DSInitializePackage()
   ierr = PetscLogEventRegister("DSVectors",DS_CLASSID,&DS_Vectors);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("DSSynchronize",DS_CLASSID,&DS_Synchronize);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("DSOther",DS_CLASSID,&DS_Other);CHKERRQ(ierr);
-  /* Process info exclusions */
-  ierr = PetscOptionsGetString(NULL,NULL,"-info_exclude",logList,sizeof(logList),&opt);CHKERRQ(ierr);
-  if (opt) {
-    ierr = PetscStrInList("ds",logList,',',&pkg);CHKERRQ(ierr);
-    if (pkg) { ierr = PetscInfoDeactivateClass(DS_CLASSID);CHKERRQ(ierr); }
-  }
+  /* Process Info */
+  classids[0] = DS_CLASSID;
+  ierr = PetscInfoProcessClass("ds",1,&classids[0]);CHKERRQ(ierr);
   /* Process summary exclusions */
   ierr = PetscOptionsGetString(NULL,NULL,"-log_exclude",logList,sizeof(logList),&opt);CHKERRQ(ierr);
   if (opt) {
@@ -838,6 +836,30 @@ PetscErrorCode DSView(DS ds,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
+/*@C
+   DSViewFromOptions - View from options
+
+   Collective on DS
+
+   Input Parameters:
++  ds   - the direct solver context
+.  obj  - optional object
+-  name - command line option
+
+   Level: intermediate
+
+.seealso: DSView(), DSCreate()
+@*/
+PetscErrorCode DSViewFromOptions(DS ds,PetscObject obj,const char name[])
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(ds,DS_CLASSID,1);
+  ierr = PetscObjectViewFromOptions((PetscObject)ds,obj,name);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 /*@
    DSAllocate - Allocates memory for internal storage or matrices in DS.
 
@@ -866,6 +888,7 @@ PetscErrorCode DSAllocate(DS ds,PetscInt ld)
   PetscValidType(ds,1);
   if (ld<1) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Leading dimension should be at least one");
   if (ld!=ds->ld) {
+    ierr = PetscInfo1(ds,"Allocating memory with leading dimension=%D\n",ld);CHKERRQ(ierr);
     ierr = DSReset(ds);CHKERRQ(ierr);
     ds->ld = ld;
     ierr = (*ds->ops->allocate)(ds,ld);CHKERRQ(ierr);
