@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -33,7 +33,7 @@ PetscErrorCode DSGetLeadingDimension(DS ds,PetscInt *ld)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  PetscValidPointer(ld,2);
+  PetscValidIntPointer(ld,2);
   *ld = ds->ld;
   PetscFunctionReturn(0);
 }
@@ -41,7 +41,7 @@ PetscErrorCode DSGetLeadingDimension(DS ds,PetscInt *ld)
 /*@
    DSSetState - Change the state of the DS object.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds    - the direct solver context
@@ -72,7 +72,7 @@ PetscErrorCode DSSetState(DS ds,DSStateType state)
     case DS_STATE_INTERMEDIATE:
     case DS_STATE_CONDENSED:
     case DS_STATE_TRUNCATED:
-      if (ds->state<state) { ierr = PetscInfo(ds,"DS state has been increased\n");CHKERRQ(ierr); }
+      if (ds->state!=state) { ierr = PetscInfo2(ds,"State has changed from %s to %s\n",DSStateTypes[ds->state],DSStateTypes[state]);CHKERRQ(ierr); }
       ds->state = state;
       break;
     default:
@@ -108,7 +108,7 @@ PetscErrorCode DSGetState(DS ds,DSStateType *state)
 /*@
    DSSetDimensions - Resize the matrices in the DS object.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds - the direct solver context
@@ -128,6 +128,9 @@ PetscErrorCode DSGetState(DS ds,DSStateType *state)
 @*/
 PetscErrorCode DSSetDimensions(DS ds,PetscInt n,PetscInt m,PetscInt l,PetscInt k)
 {
+  PetscErrorCode ierr;
+  PetscInt       on,om,ol,ok;
+
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   DSCheckAlloc(ds,1);
@@ -135,6 +138,7 @@ PetscErrorCode DSSetDimensions(DS ds,PetscInt n,PetscInt m,PetscInt l,PetscInt k
   PetscValidLogicalCollectiveInt(ds,m,3);
   PetscValidLogicalCollectiveInt(ds,l,4);
   PetscValidLogicalCollectiveInt(ds,k,5);
+  on = ds->n; om = ds->m; ol = ds->l; ok = ds->k;
   if (n==PETSC_DECIDE || n==PETSC_DEFAULT) {
     ds->n = ds->ld;
   } else {
@@ -163,6 +167,9 @@ PetscErrorCode DSSetDimensions(DS ds,PetscInt n,PetscInt m,PetscInt l,PetscInt k
     if (k<0 || k>ds->n) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of k. Must be between 0 and n");
     ds->k = k;
   }
+  if (on!=ds->n || om!=ds->m || ol!=ds->l || ok!=ds->k) {
+    ierr = PetscInfo4(ds,"New dimensions are: n=%D, m=%D, l=%D, k=%D\n",ds->n,ds->m,ds->l,ds->k);CHKERRQ(ierr);
+  }
   PetscFunctionReturn(0);
 }
 
@@ -205,7 +212,7 @@ PetscErrorCode DSGetDimensions(DS ds,PetscInt *n,PetscInt *m,PetscInt *l,PetscIn
 /*@
    DSTruncate - Truncates the system represented in the DS object.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds - the direct solver context
@@ -236,6 +243,7 @@ PetscErrorCode DSTruncate(DS ds,PetscInt n)
   ierr = (*ds->ops->truncate)(ds,n);CHKERRQ(ierr);
   ierr = PetscFPTrapPop();CHKERRQ(ierr);
   ierr = PetscLogEventEnd(DS_Other,ds,0,0,0);CHKERRQ(ierr);
+  ierr = PetscInfo1(ds,"State has changed from %s to TRUNCATED\n",DSStateTypes[ds->state]);CHKERRQ(ierr);
   ds->state = DS_STATE_TRUNCATED;
   ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -310,7 +318,7 @@ PetscErrorCode DSMatIsHermitian(DS ds,DSMatType t,PetscBool *flg)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidType(ds,1);
   DSCheckValidMat(ds,t,2);
-  PetscValidPointer(flg,3);
+  PetscValidBoolPointer(flg,3);
   if (ds->ops->hermitian) {
     ierr = (*ds->ops->hermitian)(ds,t,flg);CHKERRQ(ierr);
   } else *flg = PETSC_FALSE;
@@ -381,7 +389,7 @@ PetscErrorCode DSGetMat(DS ds,DSMatType m,Mat *A)
   M  = ds->mat[m];
   ierr = MatDenseGetArray(*A,&pA);CHKERRQ(ierr);
   for (j=0;j<cols;j++) {
-    ierr = PetscMemcpy(pA+j*rows,M+j*ds->ld,rows*sizeof(PetscScalar));CHKERRQ(ierr);
+    ierr = PetscArraycpy(pA+j*rows,M+j*ds->ld,rows);CHKERRQ(ierr);
   }
   ierr = MatDenseRestoreArray(*A,&pA);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -427,7 +435,7 @@ PetscErrorCode DSRestoreMat(DS ds,DSMatType m,Mat *A)
   M  = ds->mat[m];
   ierr = MatDenseGetArray(*A,&pA);CHKERRQ(ierr);
   for (j=0;j<cols;j++) {
-    ierr = PetscMemcpy(M+j*ds->ld,pA+j*rows,rows*sizeof(PetscScalar));CHKERRQ(ierr);
+    ierr = PetscArraycpy(M+j*ds->ld,pA+j*rows,rows);CHKERRQ(ierr);
   }
   ierr = MatDenseRestoreArray(*A,&pA);CHKERRQ(ierr);
   ierr = MatDestroy(A);CHKERRQ(ierr);
@@ -555,7 +563,7 @@ PetscErrorCode DSRestoreArrayReal(DS ds,DSMatType m,PetscReal *a[])
 /*@
    DSSolve - Solves the problem.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds   - the direct solver context
@@ -578,14 +586,16 @@ PetscErrorCode DSSolve(DS ds,PetscScalar eigr[],PetscScalar eigi[])
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidType(ds,1);
   DSCheckAlloc(ds,1);
-  PetscValidPointer(eigr,2);
+  PetscValidScalarPointer(eigr,2);
   if (ds->state>=DS_STATE_CONDENSED) PetscFunctionReturn(0);
   if (!ds->ops->solve[ds->method]) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"The specified method number does not exist for this DS");
+  ierr = PetscInfo3(ds,"Starting solve with problem sizes: n=%D, l=%D, k=%D\n",ds->n,ds->l,ds->k);CHKERRQ(ierr);
   ierr = PetscLogEventBegin(DS_Solve,ds,0,0,0);CHKERRQ(ierr);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
   ierr = (*ds->ops->solve[ds->method])(ds,eigr,eigi);CHKERRQ(ierr);
   ierr = PetscFPTrapPop();CHKERRQ(ierr);
   ierr = PetscLogEventEnd(DS_Solve,ds,0,0,0);CHKERRQ(ierr);
+  ierr = PetscInfo1(ds,"State has changed from %s to CONDENSED\n",DSStateTypes[ds->state]);CHKERRQ(ierr);
   ds->state = DS_STATE_CONDENSED;
   ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -595,7 +605,7 @@ PetscErrorCode DSSolve(DS ds,PetscScalar eigr[],PetscScalar eigi[])
    DSSort - Sorts the result of DSSolve() according to a given sorting
    criterion.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds   - the direct solver context
@@ -633,8 +643,8 @@ PetscErrorCode DSSort(DS ds,PetscScalar *eigr,PetscScalar *eigi,PetscScalar *rr,
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidType(ds,1);
   DSCheckSolved(ds,1);
-  PetscValidPointer(eigr,2);
-  if (rr) PetscValidPointer(rr,4);
+  PetscValidScalarPointer(eigr,2);
+  if (rr) PetscValidScalarPointer(rr,4);
   if (ds->state==DS_STATE_TRUNCATED) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"Cannot sort a truncated DS");
   if (!ds->ops->sort) SETERRQ1(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DS type %s",((PetscObject)ds)->type_name);
   if (!ds->sc) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"Must provide a sorting criterion first");
@@ -647,6 +657,7 @@ PetscErrorCode DSSort(DS ds,PetscScalar *eigr,PetscScalar *eigi,PetscScalar *rr,
   ierr = PetscFPTrapPop();CHKERRQ(ierr);
   ierr = PetscLogEventEnd(DS_Other,ds,0,0,0);CHKERRQ(ierr);
   ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
+  ierr = PetscInfo(ds,"Finished sorting\n");CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -654,7 +665,7 @@ PetscErrorCode DSSort(DS ds,PetscScalar *eigr,PetscScalar *eigi,PetscScalar *rr,
    DSSortWithPermutation - Reorders the result of DSSolve() according to a given
    permutation.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds   - the direct solver context
@@ -681,8 +692,8 @@ PetscErrorCode DSSortWithPermutation(DS ds,PetscInt *perm,PetscScalar *eigr,Pets
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidType(ds,1);
   DSCheckSolved(ds,1);
-  PetscValidPointer(perm,2);
-  PetscValidPointer(eigr,3);
+  PetscValidIntPointer(perm,2);
+  PetscValidScalarPointer(eigr,3);
   if (ds->state==DS_STATE_TRUNCATED) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"Cannot sort a truncated DS");
   if (!ds->ops->sortperm) SETERRQ1(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DS type %s",((PetscObject)ds)->type_name);
 
@@ -692,6 +703,7 @@ PetscErrorCode DSSortWithPermutation(DS ds,PetscInt *perm,PetscScalar *eigr,Pets
   ierr = PetscFPTrapPop();CHKERRQ(ierr);
   ierr = PetscLogEventEnd(DS_Other,ds,0,0,0);CHKERRQ(ierr);
   ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
+  ierr = PetscInfo(ds,"Finished sorting\n");CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -699,10 +711,10 @@ PetscErrorCode DSSortWithPermutation(DS ds,PetscInt *perm,PetscScalar *eigr,Pets
    DSSynchronize - Make sure that all processes have the same data, performing
    communication if necessary.
 
-   Collective on DS
+   Collective on ds
 
    Input Parameter:
-+  ds   - the direct solver context
+.  ds   - the direct solver context
 
    Input/Output Parameters:
 +  eigr - (optional) array with the computed eigenvalues (real part)
@@ -742,6 +754,7 @@ PetscErrorCode DSSynchronize(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     }
     ierr = PetscLogEventEnd(DS_Synchronize,ds,0,0,0);CHKERRQ(ierr);
     ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
+    ierr = PetscInfo1(ds,"Synchronization completed (%s)\n",DSParallelTypes[ds->pmode]);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
@@ -750,7 +763,7 @@ PetscErrorCode DSSynchronize(DS ds,PetscScalar eigr[],PetscScalar eigi[])
    DSVectors - Compute vectors associated to the dense system such
    as eigenvectors.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds  - the direct solver context
@@ -796,6 +809,7 @@ PetscErrorCode DSVectors(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
   if (!ds->ops->vectors) SETERRQ1(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DS type %s",((PetscObject)ds)->type_name);
   if (rnorm && !j) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"Must give a value of j");
   if (!ds->mat[mat]) { ierr = DSAllocateMat_Private(ds,mat);CHKERRQ(ierr); }
+  if (!j) { ierr = PetscInfo1(ds,"Computing all vectors on %s\n",DSMatName[mat]);CHKERRQ(ierr); }
   ierr = PetscLogEventBegin(DS_Vectors,ds,0,0,0);CHKERRQ(ierr);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
   ierr = (*ds->ops->vectors)(ds,mat,j,rnorm);CHKERRQ(ierr);
@@ -828,6 +842,7 @@ PetscErrorCode DSUpdateExtraRow(DS ds)
   DSCheckAlloc(ds,1);
   if (!ds->ops->update) SETERRQ1(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DS type %s",((PetscObject)ds)->type_name);
   if (!ds->extrarow) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONGSTATE,"Should have called DSSetExtraRow");
+  ierr = PetscInfo(ds,"Updating extra row\n");CHKERRQ(ierr);
   ierr = PetscLogEventBegin(DS_Other,ds,0,0,0);CHKERRQ(ierr);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
   ierr = (*ds->ops->update)(ds);CHKERRQ(ierr);
@@ -858,20 +873,21 @@ PetscErrorCode DSCond(DS ds,PetscReal *cond)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidType(ds,1);
   DSCheckAlloc(ds,1);
-  PetscValidPointer(cond,2);
+  PetscValidRealPointer(cond,2);
   if (!ds->ops->cond) SETERRQ1(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DS type %s",((PetscObject)ds)->type_name);
   ierr = PetscLogEventBegin(DS_Other,ds,0,0,0);CHKERRQ(ierr);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
   ierr = (*ds->ops->cond)(ds,cond);CHKERRQ(ierr);
   ierr = PetscFPTrapPop();CHKERRQ(ierr);
   ierr = PetscLogEventEnd(DS_Other,ds,0,0,0);CHKERRQ(ierr);
+  ierr = PetscInfo1(ds,"Computed condition number = %g\n",(double)*cond);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
 /*@C
    DSTranslateHarmonic - Computes a translation of the dense system.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds      - the direct solver context
@@ -907,6 +923,8 @@ PetscErrorCode DSTranslateHarmonic(DS ds,PetscScalar tau,PetscReal beta,PetscBoo
   PetscValidType(ds,1);
   DSCheckAlloc(ds,1);
   if (!ds->ops->transharm) SETERRQ1(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DS type %s",((PetscObject)ds)->type_name);
+  if (recover) { ierr = PetscInfo(ds,"Undoing the translation\n");CHKERRQ(ierr); }
+  else { ierr = PetscInfo(ds,"Computing the translation\n");CHKERRQ(ierr); }
   ierr = PetscLogEventBegin(DS_Other,ds,0,0,0);CHKERRQ(ierr);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
   ierr = (*ds->ops->transharm)(ds,tau,beta,recover,g,gamma);CHKERRQ(ierr);
@@ -921,7 +939,7 @@ PetscErrorCode DSTranslateHarmonic(DS ds,PetscScalar tau,PetscReal beta,PetscBoo
    DSTranslateRKS - Computes a modification of the dense system corresponding
    to an update of the shift in a rational Krylov method.
 
-   Logically Collective on DS
+   Logically Collective on ds
 
    Input Parameters:
 +  ds    - the direct solver context
@@ -950,6 +968,7 @@ PetscErrorCode DSTranslateRKS(DS ds,PetscScalar alpha)
   PetscValidType(ds,1);
   DSCheckAlloc(ds,1);
   if (!ds->ops->transrks) SETERRQ1(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"DS type %s",((PetscObject)ds)->type_name);
+  ierr = PetscInfo1(ds,"Translating with alpha=%g\n",PetscRealPart(alpha));CHKERRQ(ierr);
   ierr = PetscLogEventBegin(DS_Other,ds,0,0,0);CHKERRQ(ierr);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
   ierr = (*ds->ops->transrks)(ds,alpha);CHKERRQ(ierr);
@@ -1022,9 +1041,9 @@ PetscErrorCode DSCopyMat(DS ds,DSMatType m,PetscInt mr,PetscInt mc,Mat A,PetscIn
   ierr = MatDenseGetArray(A,&pA);CHKERRQ(ierr);
   for (j=0;j<cols;j++) {
     if (out) {
-      ierr = PetscMemcpy(pA+(Ac+j)*arows+Ar,M+(mc+j)*ds->ld+mr,rows*sizeof(PetscScalar));CHKERRQ(ierr);
+      ierr = PetscArraycpy(pA+(Ac+j)*arows+Ar,M+(mc+j)*ds->ld+mr,rows);CHKERRQ(ierr);
     } else {
-      ierr = PetscMemcpy(M+(mc+j)*ds->ld+mr,pA+(Ac+j)*arows+Ar,rows*sizeof(PetscScalar));CHKERRQ(ierr);
+      ierr = PetscArraycpy(M+(mc+j)*ds->ld+mr,pA+(Ac+j)*arows+Ar,rows);CHKERRQ(ierr);
     }
   }
   ierr = MatDenseRestoreArray(A,&pA);CHKERRQ(ierr);
