@@ -449,7 +449,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
 #if !defined(PETSC_USE_COMPLEX)
   PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","N",&n,sMaux,&n,wr,wi,NULL,&n,NULL,&n,&work1,&query,&info));
   SlepcCheckLapackInfo("geev",info);
-  ierr = PetscBLASIntCast((PetscInt)PetscRealPart(work1),&lwork);CHKERRQ(ierr);
+  ierr = PetscBLASIntCast((PetscInt)work1,&lwork);CHKERRQ(ierr);
   ierr = PetscMalloc1(lwork,&work);CHKERRQ(ierr);
   PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","N",&n,sMaux,&n,wr,wi,NULL,&n,NULL,&n,work,&lwork,&info));
   ierr = PetscFree(work);CHKERRQ(ierr);
@@ -822,11 +822,11 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham(FN fn,Mat A,Mat B)
   const PetscScalar c3[4]   = { 120, 60, 12, 1 };
   const PetscScalar c5[6]   = { 30240, 15120, 3360, 420, 30, 1 };
   const PetscScalar c7[8]   = { 17297280, 8648640, 1995840, 277200, 25200, 1512, 56, 1 };
-  const PetscScalar c9[10]  = { 17643225600, 8821612800, 2075673600, 302702400, 30270240,
+  const PetscScalar c9[10]  = { 17643225600.0, 8821612800.0, 2075673600, 302702400, 30270240,
                                 2162160, 110880, 3960, 90, 1 };
-  const PetscScalar c13[14] = { 64764752532480000, 32382376266240000, 7771770303897600,
-                                1187353796428800,  129060195264000,   10559470521600,
-                                670442572800,      33522128640,       1323241920,
+  const PetscScalar c13[14] = { 64764752532480000.0, 32382376266240000.0, 7771770303897600.0,
+                                1187353796428800.0,  129060195264000.0,   10559470521600.0,
+                                670442572800.0,      33522128640.0,       1323241920.0,
                                 40840800,          960960,            16380,  182,  1 };
 
   PetscFunctionBegin;
