@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -91,7 +91,7 @@ static PetscErrorCode RGIntervalGetEndpoints_Interval(RG rg,PetscReal *a,PetscRe
   PetscFunctionReturn(0);
 }
 
-/*@
+/*@C
    RGIntervalGetEndpoints - Gets the parameters that define the interval region.
 
    Not Collective
@@ -203,7 +203,7 @@ PetscErrorCode RGComputeContour_Interval(RG rg,PetscInt n,PetscScalar *cr,PetscS
       cr[idx] = vr[i]+off*(hr[i]/h); ci[idx] = vi[i]+off*(hi[i]/h);
 #endif
       idx++;
-      pt = (d[i]-off)/h+1;
+      pt = (PetscInt)((d[i]-off)/h)+1;
       for (j=1;j<pt && idx<n;j++) {
 #if defined(PETSC_USE_COMPLEX)
         cr[idx] = cr[idx-1]+PetscCMPLX(hr[i],hi[i]);
