@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -50,6 +50,7 @@ PetscErrorCode RGInitializePackage(void)
 {
   char           logList[256];
   PetscBool      opt,pkg;
+  PetscClassId   classids[1];
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
@@ -59,12 +60,9 @@ PetscErrorCode RGInitializePackage(void)
   ierr = PetscClassIdRegister("Region",&RG_CLASSID);CHKERRQ(ierr);
   /* Register Constructors */
   ierr = RGRegisterAll();CHKERRQ(ierr);
-  /* Process info exclusions */
-  ierr = PetscOptionsGetString(NULL,NULL,"-info_exclude",logList,sizeof(logList),&opt);CHKERRQ(ierr);
-  if (opt) {
-    ierr = PetscStrInList("rg",logList,',',&pkg);CHKERRQ(ierr);
-    if (pkg) { ierr = PetscInfoDeactivateClass(RG_CLASSID);CHKERRQ(ierr); }
-  }
+  /* Process Info */
+  classids[0] = RG_CLASSID;
+  ierr = PetscInfoProcessClass("rg",1,&classids[0]);CHKERRQ(ierr);
   /* Process summary exclusions */
   ierr = PetscOptionsGetString(NULL,NULL,"-log_exclude",logList,sizeof(logList),&opt);CHKERRQ(ierr);
   if (opt) {
@@ -282,7 +280,7 @@ PetscErrorCode RGSetFromOptions(RG rg)
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   ierr = RGRegisterAll();CHKERRQ(ierr);
   ierr = PetscObjectOptionsBegin((PetscObject)rg);CHKERRQ(ierr);
-    ierr = PetscOptionsFList("-rg_type","Region type","RGSetType",RGList,(char*)(((PetscObject)rg)->type_name?((PetscObject)rg)->type_name:RGINTERVAL),type,256,&flg);CHKERRQ(ierr);
+    ierr = PetscOptionsFList("-rg_type","Region type","RGSetType",RGList,(char*)(((PetscObject)rg)->type_name?((PetscObject)rg)->type_name:RGINTERVAL),type,sizeof(type),&flg);CHKERRQ(ierr);
     if (flg) {
       ierr = RGSetType(rg,type);CHKERRQ(ierr);
     } else if (!((PetscObject)rg)->type_name) {
@@ -357,6 +355,30 @@ PetscErrorCode RGView(RG rg,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
+/*@C
+   RGViewFromOptions - View from options
+
+   Collective on RG
+
+   Input Parameters:
++  rg   - the region context
+.  obj  - optional object
+-  name - command line option
+
+   Level: intermediate
+
+.seealso: RGView(), RGCreate()
+@*/
+PetscErrorCode RGViewFromOptions(RG rg,PetscObject obj,const char name[])
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(rg,RG_CLASSID,1);
+  ierr = PetscObjectViewFromOptions((PetscObject)rg,obj,name);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 /*@
    RGIsTrivial - Whether it is the trivial region (whole complex plane).
 
@@ -445,7 +467,7 @@ PetscErrorCode RGCheckInside(RG rg,PetscInt n,PetscScalar *ar,PetscScalar *ai,Pe
 }
 
 /*@
-   RGComputeContour - Computes the coordinates of several points lying in the
+   RGComputeContour - Computes the coordinates of several points lying on the
    contour of the region.
 
    Not Collective
