@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -14,7 +14,9 @@
 #include <slepc/private/stimpl.h>          /*I "slepcst.h" I*/
 
 typedef struct {
-  PetscBool setmat;
+  PetscBool ksphasmat;  /* the KSP must have the same matrix as PC */
+  PetscBool usermat;    /* the user has set a matrix */
+  Mat       mat;        /* user-provided matrix */
 } ST_PRECOND;
 
 static PetscErrorCode STSetDefaultKSP_Precond(ST st)
@@ -22,107 +24,93 @@ static PetscErrorCode STSetDefaultKSP_Precond(ST st)
   PetscErrorCode ierr;
   PC             pc;
   PCType         pctype;
-  Mat            P;
   PetscBool      t0,t1;
 
   PetscFunctionBegin;
   ierr = KSPGetPC(st->ksp,&pc);CHKERRQ(ierr);
-  ierr = PetscObjectGetType((PetscObject)pc,&pctype);CHKERRQ(ierr);
-  ierr = STPrecondGetMatForPC(st,&P);CHKERRQ(ierr);
+  ierr = PCGetType(pc,&pctype);CHKERRQ(ierr);
   if (!pctype && st->A && st->A[0]) {
-    if (P || st->shift_matrix == ST_MATMODE_SHELL) {
+    if (st->matmode == ST_MATMODE_SHELL) {
       ierr = PCSetType(pc,PCJACOBI);CHKERRQ(ierr);
     } else {
       ierr = MatHasOperation(st->A[0],MATOP_DUPLICATE,&t0);CHKERRQ(ierr);
       if (st->nmat>1) {
         ierr = MatHasOperation(st->A[0],MATOP_AXPY,&t1);CHKERRQ(ierr);
       } else t1 = PETSC_TRUE;
-      ierr = PCSetType(pc,(t0 && t1)?PCJACOBI:PCNONE);CHKERRQ(ierr);
+      ierr = PCSetType(pc,(t0 && t1)?PCBJACOBI:PCNONE);CHKERRQ(ierr);
     }
   }
   ierr = KSPSetErrorIfNotConverged(st->ksp,PETSC_FALSE);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode STSetUp_Precond(ST st)
+PetscErrorCode STPostSolve_Precond(ST st)
 {
-  Mat            P;
-  PC             pc;
-  PetscBool      t0,setmat,destroyP=PETSC_FALSE,builtP;
   PetscErrorCode ierr;
+  ST_PRECOND     *ctx = (ST_PRECOND*)st->data;
+
+  PetscFunctionBegin;
+  if (st->matmode == ST_MATMODE_INPLACE && !(ctx->mat || (PetscAbsScalar(st->sigma)>=PETSC_MAX_REAL && st->nmat>1))) {
+    if (st->nmat>1) {
+      ierr = MatAXPY(st->A[0],st->sigma,st->A[1],st->str);CHKERRQ(ierr);
+    } else {
+      ierr = MatShift(st->A[0],st->sigma);CHKERRQ(ierr);
+    }
+    st->Astate[0] = ((PetscObject)st->A[0])->state;
+    st->state   = ST_STATE_INITIAL;
+    st->opready = PETSC_FALSE;
+  }
+  PetscFunctionReturn(0);
+}
+
+/*
+   Operator (precond):
+               Op        P         M
+   if nmat=1:  ---       A-sI      NULL
+   if nmat=2:  ---       A-sB      NULL
+*/
+PetscErrorCode STComputeOperator_Precond(ST st)
+{
+  PetscErrorCode ierr;
+  ST_PRECOND     *ctx = (ST_PRECOND*)st->data;
 
   PetscFunctionBegin;
   /* if the user did not set the shift, use the target value */
   if (!st->sigma_set) st->sigma = st->defsigma;
+  st->M = NULL;
 
-  /* If either pc is none and no matrix has to be set, or pc is shell , exit */
-  if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
-  ierr = KSPGetPC(st->ksp,&pc);CHKERRQ(ierr);
-  ierr = PetscObjectTypeCompare((PetscObject)pc,PCSHELL,&t0);CHKERRQ(ierr);
-  if (t0) PetscFunctionReturn(0);
-  ierr = PetscObjectTypeCompare((PetscObject)pc,PCNONE,&t0);CHKERRQ(ierr);
-  ierr = STPrecondGetKSPHasMat(st,&setmat);CHKERRQ(ierr);
-  if (t0 && !setmat) PetscFunctionReturn(0);
-
-  /* Check if a user matrix is set */
-  ierr = STPrecondGetMatForPC(st,&P);CHKERRQ(ierr);
-
-  /* If not, create A - shift*B */
-  if (P) {
-    builtP = PETSC_FALSE;
-    destroyP = PETSC_TRUE;
-    ierr = PetscObjectReference((PetscObject)P);CHKERRQ(ierr);
+  /* P = A-sigma*B */
+  if (ctx->mat) {
+    ierr = PetscObjectReference((PetscObject)ctx->mat);CHKERRQ(ierr);
+    ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+    st->P = ctx->mat;
   } else {
-    builtP = PETSC_TRUE;
-
+    ierr = PetscObjectReference((PetscObject)st->A[1]);CHKERRQ(ierr);
+    ierr = MatDestroy(&st->T[0]);CHKERRQ(ierr);
+    st->T[0] = st->A[1];
     if (!(PetscAbsScalar(st->sigma) < PETSC_MAX_REAL) && st->nmat>1) {
-      P = st->A[1];
-      destroyP = PETSC_FALSE;
-    } else if (st->sigma == 0.0) {
-      P = st->A[0];
-      destroyP = PETSC_FALSE;
-    } else if (PetscAbsScalar(st->sigma) < PETSC_MAX_REAL && st->shift_matrix != ST_MATMODE_SHELL) {
-      if (st->shift_matrix == ST_MATMODE_INPLACE) {
-        P = st->A[0];
-        destroyP = PETSC_FALSE;
-      } else {
-        ierr = MatDuplicate(st->A[0],MAT_COPY_VALUES,&P);CHKERRQ(ierr);
-        destroyP = PETSC_TRUE;
-      }
-      if (st->nmat>1) {
-        ierr = MatAXPY(P,-st->sigma,st->A[1],st->str);CHKERRQ(ierr);
-      } else {
-        ierr = MatShift(P,-st->sigma);CHKERRQ(ierr);
-      }
-      /* TODO: in case of ST_MATMODE_INPLACE should keep the Hermitian flag of st->A and restore at the end */
-      ierr = STMatSetHermitian(st,P);CHKERRQ(ierr);
-    } else builtP = PETSC_FALSE;
-  }
-
-  /* If P was not possible to obtain, set pc to PCNONE */
-  if (!P) {
-    ierr = PCSetType(pc,PCNONE);CHKERRQ(ierr);
-
-    /* If some matrix has to be set to ksp, a shell matrix is created */
-    if (setmat) {
-      ierr = STMatShellCreate(st,-st->sigma,0,NULL,NULL,&P);CHKERRQ(ierr);
-      ierr = STMatSetHermitian(st,P);CHKERRQ(ierr);
-      destroyP = PETSC_TRUE;
+      ierr = PetscObjectReference((PetscObject)st->T[0]);CHKERRQ(ierr);
+      ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+      st->P = st->T[0];
+    } else if (PetscAbsScalar(st->sigma)<PETSC_MAX_REAL) {
+      ierr = STMatMAXPY_Private(st,-st->sigma,0.0,0,NULL,PetscNot(st->state==ST_STATE_UPDATED),&st->T[1]);CHKERRQ(ierr);
+      ierr = PetscObjectReference((PetscObject)st->T[1]);CHKERRQ(ierr);
+      ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+      st->P = st->T[1];
     }
   }
+  PetscFunctionReturn(0);
+}
 
-  ierr = KSPSetOperators(st->ksp,setmat?P:NULL,P);CHKERRQ(ierr);
+PetscErrorCode STSetUp_Precond(ST st)
+{
+  PetscErrorCode ierr;
+  ST_PRECOND     *ctx = (ST_PRECOND*)st->data;
 
-  if (destroyP) {
-    ierr = MatDestroy(&P);CHKERRQ(ierr);
-  } else if (st->shift_matrix == ST_MATMODE_INPLACE && builtP) {
-    if (st->sigma != 0.0 && PetscAbsScalar(st->sigma) < PETSC_MAX_REAL) {
-      if (st->nmat>1) {
-        ierr = MatAXPY(st->A[0],st->sigma,st->A[1],st->str);CHKERRQ(ierr);
-      } else {
-        ierr = MatShift(st->A[0],st->sigma);CHKERRQ(ierr);
-      }
-    }
+  PetscFunctionBegin;
+  if (st->P) {
+    ierr = KSPSetOperators(st->ksp,ctx->ksphasmat?st->P:NULL,st->P);CHKERRQ(ierr);
+    /* NOTE: we do not call KSPSetUp() here because some eigensolvers such as JD require a lazy setup */
   }
   PetscFunctionReturn(0);
 }
@@ -130,30 +118,30 @@ PetscErrorCode STSetUp_Precond(ST st)
 PetscErrorCode STSetShift_Precond(ST st,PetscScalar newshift)
 {
   PetscErrorCode ierr;
+  ST_PRECOND     *ctx = (ST_PRECOND*)st->data;
 
   PetscFunctionBegin;
-  /* Nothing to be done if STSetUp has not been called yet */
-  if (!st->state) PetscFunctionReturn(0);
-  st->sigma = newshift;
-  if (st->shift_matrix != ST_MATMODE_SHELL) {
-    ierr = STSetUp_Precond(st);CHKERRQ(ierr);
+  if (st->transform && !ctx->mat) {
+    ierr = STMatMAXPY_Private(st,-newshift,-st->sigma,0,NULL,PETSC_FALSE,&st->T[1]);CHKERRQ(ierr);
+    if (st->P!=st->T[1]) {
+      ierr = PetscObjectReference((PetscObject)st->T[1]);CHKERRQ(ierr);
+      ierr = MatDestroy(&st->P);CHKERRQ(ierr);
+      st->P = st->T[1];
+    }
+  }
+  if (st->P) {
+    if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
+    ierr = KSPSetOperators(st->ksp,ctx->ksphasmat?st->P:NULL,st->P);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
 
 static PetscErrorCode STPrecondGetMatForPC_Precond(ST st,Mat *mat)
 {
-  PetscErrorCode ierr;
-  PC             pc;
-  PetscBool      flag;
+  ST_PRECOND *ctx = (ST_PRECOND*)st->data;
 
   PetscFunctionBegin;
-  if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
-  ierr = KSPGetPC(st->ksp,&pc);CHKERRQ(ierr);
-  ierr = PCGetOperatorsSet(pc,NULL,&flag);CHKERRQ(ierr);
-  if (flag) {
-    ierr = PCGetOperators(pc,NULL,mat);CHKERRQ(ierr);
-  } else *mat = NULL;
+  *mat = ctx->mat;
   PetscFunctionReturn(0);
 }
 
@@ -186,33 +174,24 @@ PetscErrorCode STPrecondGetMatForPC(ST st,Mat *mat)
 
 static PetscErrorCode STPrecondSetMatForPC_Precond(ST st,Mat mat)
 {
-  PC             pc;
-  Mat            A;
-  PetscBool      flag;
+  ST_PRECOND     *ctx = (ST_PRECOND*)st->data;
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  if (!st->ksp) { ierr = STGetKSP(st,&st->ksp);CHKERRQ(ierr); }
-  ierr = KSPGetPC(st->ksp,&pc);CHKERRQ(ierr);
-  /* Yes, all these lines are needed to safely set mat as the preconditioner
-     matrix in pc */
-  ierr = PCGetOperatorsSet(pc,&flag,NULL);CHKERRQ(ierr);
-  if (flag) {
-    ierr = PCGetOperators(pc,&A,NULL);CHKERRQ(ierr);
-    ierr = PetscObjectReference((PetscObject)A);CHKERRQ(ierr);
-  } else A = NULL;
+  STCheckNotSeized(st,1);
   ierr = PetscObjectReference((PetscObject)mat);CHKERRQ(ierr);
-  ierr = PCSetOperators(pc,A,mat);CHKERRQ(ierr);
-  ierr = MatDestroy(&A);CHKERRQ(ierr);
-  ierr = MatDestroy(&mat);CHKERRQ(ierr);
-  ierr = STPrecondSetKSPHasMat(st,PETSC_TRUE);CHKERRQ(ierr);
+  ierr = MatDestroy(&ctx->mat);CHKERRQ(ierr);
+  ctx->mat     = mat;
+  ctx->usermat = mat? PETSC_TRUE: PETSC_FALSE;
+  st->state    = ST_STATE_INITIAL;
+  st->opready  = PETSC_FALSE;
   PetscFunctionReturn(0);
 }
 
 /*@
    STPrecondSetMatForPC - Sets the matrix that must be used to build the preconditioner.
 
-   Logically Collective on ST and Mat
+   Logically Collective on st
 
    Input Parameter:
 +  st - the spectral transformation context
@@ -240,52 +219,55 @@ PetscErrorCode STPrecondSetMatForPC(ST st,Mat mat)
   PetscFunctionReturn(0);
 }
 
-static PetscErrorCode STPrecondSetKSPHasMat_Precond(ST st,PetscBool setmat)
+static PetscErrorCode STPrecondSetKSPHasMat_Precond(ST st,PetscBool ksphasmat)
 {
-  ST_PRECOND *data = (ST_PRECOND*)st->data;
+  ST_PRECOND *ctx = (ST_PRECOND*)st->data;
 
   PetscFunctionBegin;
-  data->setmat = setmat;
+  if (ctx->ksphasmat != ksphasmat) {
+    ctx->ksphasmat = ksphasmat;
+    st->state      = ST_STATE_INITIAL;
+  }
   PetscFunctionReturn(0);
 }
 
 /*@
    STPrecondSetKSPHasMat - Sets a flag indicating that during STSetUp the coefficient
-   matrix of the KSP linear system (A) must be set to be the same matrix as the
+   matrix of the KSP linear solver (A) must be set to be the same matrix as the
    preconditioner (P).
 
-   Collective on ST
+   Collective on st
 
    Input Parameter:
 +  st - the spectral transformation context
--  setmat - the flag
+-  ksphasmat - the flag
 
    Notes:
-   In most cases, the preconditioner matrix is used only in the PC object, but
-   in external solvers this matrix must be provided also as the A-matrix in
+   Often, the preconditioner matrix is used only in the PC object, but
+   in some solvers this matrix must be provided also as the A-matrix in
    the KSP object.
 
    Level: developer
 
 .seealso: STPrecondGetKSPHasMat(), STSetShift()
 @*/
-PetscErrorCode STPrecondSetKSPHasMat(ST st,PetscBool setmat)
+PetscErrorCode STPrecondSetKSPHasMat(ST st,PetscBool ksphasmat)
 {
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  PetscValidLogicalCollectiveBool(st,setmat,2);
-  ierr = PetscTryMethod(st,"STPrecondSetKSPHasMat_C",(ST,PetscBool),(st,setmat));CHKERRQ(ierr);
+  PetscValidLogicalCollectiveBool(st,ksphasmat,2);
+  ierr = PetscTryMethod(st,"STPrecondSetKSPHasMat_C",(ST,PetscBool),(st,ksphasmat));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-static PetscErrorCode STPrecondGetKSPHasMat_Precond(ST st,PetscBool *setmat)
+static PetscErrorCode STPrecondGetKSPHasMat_Precond(ST st,PetscBool *ksphasmat)
 {
-  ST_PRECOND *data = (ST_PRECOND*)st->data;
+  ST_PRECOND *ctx = (ST_PRECOND*)st->data;
 
   PetscFunctionBegin;
-  *setmat = data->setmat;
+  *ksphasmat = ctx->ksphasmat;
   PetscFunctionReturn(0);
 }
 
@@ -300,28 +282,30 @@ static PetscErrorCode STPrecondGetKSPHasMat_Precond(ST st,PetscBool *setmat)
 .  st - the spectral transformation context
 
    Output Parameter:
-.  setmat - the flag
+.  ksphasmat - the flag
 
    Level: developer
 
 .seealso: STPrecondSetKSPHasMat(), STSetShift()
 @*/
-PetscErrorCode STPrecondGetKSPHasMat(ST st,PetscBool *setmat)
+PetscErrorCode STPrecondGetKSPHasMat(ST st,PetscBool *ksphasmat)
 {
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  PetscValidPointer(setmat,2);
-  ierr = PetscUseMethod(st,"STPrecondGetKSPHasMat_C",(ST,PetscBool*),(st,setmat));CHKERRQ(ierr);
+  PetscValidBoolPointer(ksphasmat,2);
+  ierr = PetscUseMethod(st,"STPrecondGetKSPHasMat_C",(ST,PetscBool*),(st,ksphasmat));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
 PetscErrorCode STDestroy_Precond(ST st)
 {
+  ST_PRECOND     *ctx = (ST_PRECOND*)st->data;
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
+  ierr = MatDestroy(&ctx->mat);CHKERRQ(ierr);
   ierr = PetscFree(st->data);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondGetMatForPC_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondSetMatForPC_C",NULL);CHKERRQ(ierr);
@@ -339,9 +323,16 @@ SLEPC_EXTERN PetscErrorCode STCreate_Precond(ST st)
   ierr = PetscNewLog(st,&ctx);CHKERRQ(ierr);
   st->data = (void*)ctx;
 
+  st->usesksp = PETSC_TRUE;
+
+  st->ops->apply           = STApply_Generic;
+  st->ops->applymat        = STApplyMat_Generic;
+  st->ops->applytrans      = STApplyTranspose_Generic;
+  st->ops->setshift        = STSetShift_Precond;
   st->ops->getbilinearform = STGetBilinearForm_Default;
   st->ops->setup           = STSetUp_Precond;
-  st->ops->setshift        = STSetShift_Precond;
+  st->ops->computeoperator = STComputeOperator_Precond;
+  st->ops->postsolve       = STPostSolve_Precond;
   st->ops->destroy         = STDestroy_Precond;
   st->ops->setdefaultksp   = STSetDefaultKSP_Precond;
 
@@ -349,8 +340,6 @@ SLEPC_EXTERN PetscErrorCode STCreate_Precond(ST st)
   ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondSetMatForPC_C",STPrecondSetMatForPC_Precond);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondGetKSPHasMat_C",STPrecondGetKSPHasMat_Precond);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)st,"STPrecondSetKSPHasMat_C",STPrecondSetKSPHasMat_Precond);CHKERRQ(ierr);
-
-  ierr = STPrecondSetKSPHasMat_Precond(st,PETSC_TRUE);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
