@@ -66,6 +66,58 @@ PetscErrorCode STApply(ST st,Vec x,Vec y)
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode STApplyMat_Generic(ST st,Mat B,Mat C)
+{
+  PetscErrorCode ierr;
+  Mat            work;
+
+  PetscFunctionBegin;
+  if (st->M && st->P) {
+    ierr = MatMatMult(st->M,B,MAT_INITIAL_MATRIX,PETSC_DEFAULT,&work);CHKERRQ(ierr);
+    ierr = STMatMatSolve(st,work,C);CHKERRQ(ierr);
+    ierr = MatDestroy(&work);CHKERRQ(ierr);
+  } else if (st->M) {
+    ierr = MatMatMult(st->M,B,MAT_REUSE_MATRIX,PETSC_DEFAULT,&C);CHKERRQ(ierr);
+  } else {
+    ierr = STMatMatSolve(st,B,C);CHKERRQ(ierr);
+  }
+  PetscFunctionReturn(0);
+}
+
+/*@
+   STApplyMat - Applies the spectral transformation operator to a matrix, for
+   instance (A - sB)^-1 B in the case of the shift-and-invert transformation
+   and generalized eigenproblem.
+
+   Collective on st
+
+   Input Parameters:
++  st - the spectral transformation context
+-  X  - input matrix
+
+   Output Parameter:
+.  y - output matrix
+
+   Level: developer
+
+.seealso: STApply()
+@*/
+PetscErrorCode STApplyMat(ST st,Mat X,Mat Y)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(st,ST_CLASSID,1);
+  PetscValidHeaderSpecific(X,MAT_CLASSID,2);
+  PetscValidHeaderSpecific(Y,MAT_CLASSID,3);
+  PetscValidType(st,1);
+  STCheckMatrices(st,1);
+  if (X == Y) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_IDN,"X and Y must be different matrices");
+  if (!st->ops->applymat) SETERRQ(PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"ST does not have applymat");
+  ierr = (*st->ops->applymat)(st,X,Y);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode STApplyTranspose_Generic(ST st,Vec x,Vec y)
 {
   PetscErrorCode ierr;
@@ -272,14 +324,31 @@ static PetscErrorCode MatMultHermitianTranspose_STOperator(Mat Op,Vec x,Vec y)
 }
 #endif
 
+static PetscErrorCode MatMatMult_STOperator(Mat Op,Mat B,Mat C,void *ctx)
+{
+  PetscErrorCode ierr;
+  ST             st;
+
+  PetscFunctionBegin;
+  ierr = MatShellGetContext(Op,(void**)&st);CHKERRQ(ierr);
+  ierr = STSetUp(st);CHKERRQ(ierr);
+  ierr = PetscLogEventBegin(ST_Apply,st,B,C,0);CHKERRQ(ierr);
+  ierr = STApplyMat_Generic(st,B,C);CHKERRQ(ierr);
+  ierr = PetscLogEventEnd(ST_Apply,st,B,C,0);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode STGetOperator_Private(ST st,Mat *Op)
 {
   PetscErrorCode ierr;
   PetscInt       m,n,M,N;
+  Vec            v;
+  VecType        vtype;
 
   PetscFunctionBegin;
   if (!st->Op) {
     if (Op) *Op = NULL;
+    /* create the shell matrix */
     ierr = MatGetLocalSize(st->A[0],&m,&n);CHKERRQ(ierr);
     ierr = MatGetSize(st->A[0],&M,&N);CHKERRQ(ierr);
     ierr = MatCreateShell(PetscObjectComm((PetscObject)st),m,n,M,N,st,&st->Op);CHKERRQ(ierr);
@@ -290,6 +359,15 @@ PetscErrorCode STGetOperator_Private(ST st,Mat *Op)
 #else
     ierr = MatShellSetOperation(st->Op,MATOP_MULT_HERMITIAN_TRANSPOSE,(void(*)(void))MatMultTranspose_STOperator);CHKERRQ(ierr);
 #endif
+    if (!st->D && st->ops->apply==STApply_Generic) {
+      ierr = MatShellSetMatProductOperation(st->Op,MATPRODUCT_AB,NULL,MatMatMult_STOperator,NULL,MATDENSE,MATDENSE);CHKERRQ(ierr);
+    }
+    /* make sure the shell matrix generates a vector of the same type as the problem matrices */
+    ierr = MatCreateVecs(st->A[0],&v,NULL);CHKERRQ(ierr);
+    ierr = VecGetType(v,&vtype);CHKERRQ(ierr);
+    ierr = MatShellSetVecType(st->Op,vtype);CHKERRQ(ierr);
+    ierr = VecDestroy(&v);CHKERRQ(ierr);
+    /* build the operator matrices */
     ierr = STComputeOperator(st);CHKERRQ(ierr);
   }
   if (Op) *Op = st->Op;
@@ -414,6 +492,7 @@ PetscErrorCode STComputeOperator(ST st)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidType(st,1);
   if (!st->opready && st->ops->computeoperator) {
+    ierr = PetscInfo(st,"Building the operator matrices\n");CHKERRQ(ierr);
     STCheckMatrices(st,1);
     if (!st->T) {
       ierr = PetscCalloc1(PetscMax(2,st->nmat),&st->T);CHKERRQ(ierr);
