@@ -1,13 +1,13 @@
 !
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !  SLEPc - Scalable Library for Eigenvalue Problem Computations
-!  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+!  Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 !
 !  This file is part of SLEPc.
 !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !
-!  Basic include file for Fortran use of the SLEPc package
+!  Used by slepcsysmod.F90 to create Fortran module file
 !
 
 #include "slepc/finclude/slepcsys.h"
@@ -20,14 +20,13 @@
 
 ! Default tolerance for the different solvers, depending on the precision
 
-      PetscReal SLEPC_DEFAULT_TOL
 #if defined(PETSC_USE_REAL_SINGLE)
-      parameter(SLEPC_DEFAULT_TOL     =  1e-6)
+      PetscReal, parameter :: SLEPC_DEFAULT_TOL =  1e-5
 #elif defined(PETSC_USE_REAL_DOUBLE)
-      parameter(SLEPC_DEFAULT_TOL     =  1e-8)
+      PetscReal, parameter :: SLEPC_DEFAULT_TOL =  1e-8
 #elif defined(PETSC_USE_REAL___FLOAT128)
-      parameter(SLEPC_DEFAULT_TOL     = 1e-16)
-#else
-      parameter(SLEPC_DEFAULT_TOL     =  1e-7)
+      PetscReal, parameter :: SLEPC_DEFAULT_TOL = 1e-16
+#elif defined(PETSC_USE_REAL___FP16)
+      PetscReal, parameter :: SLEPC_DEFAULT_TOL =  1e-2
 #endif
 
