@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -10,6 +10,12 @@
 
 #include <slepc/private/slepcimpl.h>           /*I "slepcsys.h" I*/
 
+#if defined(SLEPC_HAVE_HPDDM)
+#include <petscksp.h>
+SLEPC_EXTERN PetscErrorCode KSPCreate_HPDDM(KSP);
+SLEPC_EXTERN PetscErrorCode PCCreate_HPDDM(PC);
+#endif
+
 /*@C
     SlepcGetVersion - Gets the SLEPc version information in a string.
 
@@ -83,7 +89,6 @@ static PetscErrorCode SlepcPrintVersion(MPI_Comm comm)
 
   PetscFunctionBegin;
   ierr = SlepcGetVersion(version,256);CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"--------------------------------------------------------------------------\n");CHKERRQ(ierr);
   ierr = (*PetscHelpPrintf)(comm,"%s\n",version);CHKERRQ(ierr);
   ierr = (*PetscHelpPrintf)(comm,SLEPC_AUTHOR_INFO);CHKERRQ(ierr);
   ierr = (*PetscHelpPrintf)(comm,"See docs/manual.html for help.\n");CHKERRQ(ierr);
@@ -103,7 +108,7 @@ static PetscErrorCode SlepcPrintHelpIntro(MPI_Comm comm)
   PetscFunctionBegin;
   ierr = (*PetscHelpPrintf)(comm,"SLEPc help information includes that for the PETSc libraries, which provide\n");CHKERRQ(ierr);
   ierr = (*PetscHelpPrintf)(comm,"low-level system infrastructure and linear algebra tools.\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"--------------------------------------------------------------------------\n");CHKERRQ(ierr);
+  ierr = (*PetscHelpPrintf)(comm,"----------------------------------------\n");CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -123,9 +128,9 @@ static PetscErrorCode SlepcLoadDynamicLibrary(const char *name,PetscBool *found)
 
   PetscFunctionBegin;
   ierr = PetscStrcpy(libs,SLEPC_LIB_DIR);CHKERRQ(ierr);
-  ierr = PetscStrcat(libs,"/libslepc");CHKERRQ(ierr);
-  ierr = PetscStrcat(libs,name);CHKERRQ(ierr);
-  ierr = PetscDLLibraryRetrieve(PETSC_COMM_WORLD,libs,dlib,1024,found);CHKERRQ(ierr);
+  ierr = PetscStrlcat(libs,"/libslepc",sizeof(libs));CHKERRQ(ierr);
+  ierr = PetscStrlcat(libs,name,sizeof(libs));CHKERRQ(ierr);
+  ierr = PetscDLLibraryRetrieve(PETSC_COMM_WORLD,libs,dlib,sizeof(dlib),found);CHKERRQ(ierr);
   if (*found) {
     ierr = PetscDLLibraryAppend(PETSC_COMM_WORLD,&PetscDLLibrariesLoaded,dlib);CHKERRQ(ierr);
   }
@@ -200,6 +205,11 @@ PetscErrorCode SlepcInitialize_DynamicLibraries(void)
   ierr = MFNInitializePackage();CHKERRQ(ierr);
   ierr = LMEInitializePackage();CHKERRQ(ierr);
 #endif
+
+#if defined(SLEPC_HAVE_HPDDM)
+  ierr = KSPRegister(KSPHPDDM,KSPCreate_HPDDM);CHKERRQ(ierr);
+  ierr = PCRegister(PCHPDDM,PCCreate_HPDDM);CHKERRQ(ierr);
+#endif
   PetscFunctionReturn(0);
 }
 
@@ -221,9 +231,9 @@ PetscErrorCode SlepcCitationsInitialize()
   ierr = PetscCitationsRegister("@TechReport{slepc-manual,\n"
     "   author = \"J. E. Roman and C. Campos and E. Romero and A. Tomas\",\n"
     "   title = \"{SLEPc} Users Manual\",\n"
-    "   number = \"DSIC-II/24/02 - Revision 3.12\",\n"
+    "   number = \"DSIC-II/24/02 - Revision 3.14\",\n"
     "   institution = \"D. Sistemes Inform\\`atics i Computaci\\'o, Universitat Polit\\`ecnica de Val\\`encia\",\n"
-    "   year = \"2019\"\n"
+    "   year = \"2020\"\n"
     "}\n",NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -268,11 +278,6 @@ PetscErrorCode SlepcInitialize(int *argc,char ***args,const char file[],const ch
   /* Load the dynamic libraries (on machines that support them), this registers all the solvers etc. */
   ierr = SlepcInitialize_DynamicLibraries();CHKERRQ(ierr);
 
-#if defined(PETSC_HAVE_DRAND48)
-  /* work-around for Cygwin drand48() initialization bug */
-  srand48(0);
-#endif
-
   SlepcInitializeCalled = PETSC_TRUE;
   ierr = PetscInfo(0,"SLEPc successfully started\n");CHKERRQ(ierr);
   PetscFunctionReturn(0);
